(function () {
/**
 * almond 0.2.0 Copyright (c) 2011, The Dojo Foundation All Rights Reserved.
 * Available via the MIT or new BSD license.
 * see: http://github.com/jrburke/almond for details
 */
//Going sloppy to avoid 'use strict' string cost, but strict practices should
//be followed.
/*jslint sloppy: true */
/*global setTimeout: false */

var requirejs, require, define;
(function (undef) {
    var main, req, makeMap, handlers,
        defined = {},
        waiting = {},
        config = {},
        defining = {},
        aps = [].slice;

    /**
     * Given a relative module name, like ./something, normalize it to
     * a real name that can be mapped to a path.
     * @param {String} name the relative name
     * @param {String} baseName a real name that the name arg is relative
     * to.
     * @returns {String} normalized name
     */
    function normalize(name, baseName) {
        var nameParts, nameSegment, mapValue, foundMap,
            foundI, foundStarMap, starI, i, j, part,
            baseParts = baseName && baseName.split("/"),
            map = config.map,
            starMap = (map && map['*']) || {};

        //Adjust any relative paths.
        if (name && name.charAt(0) === ".") {
            //If have a base name, try to normalize against it,
            //otherwise, assume it is a top-level require that will
            //be relative to baseUrl in the end.
            if (baseName) {
                //Convert baseName to array, and lop off the last part,
                //so that . matches that "directory" and not name of the baseName's
                //module. For instance, baseName of "one/two/three", maps to
                //"one/two/three.js", but we want the directory, "one/two" for
                //this normalization.
                baseParts = baseParts.slice(0, baseParts.length - 1);

                name = baseParts.concat(name.split("/"));

                //start trimDots
                for (i = 0; i < name.length; i += 1) {
                    part = name[i];
                    if (part === ".") {
                        name.splice(i, 1);
                        i -= 1;
                    } else if (part === "..") {
                        if (i === 1 && (name[2] === '..' || name[0] === '..')) {
                            //End of the line. Keep at least one non-dot
                            //path segment at the front so it can be mapped
                            //correctly to disk. Otherwise, there is likely
                            //no path mapping for a path starting with '..'.
                            //This can still fail, but catches the most reasonable
                            //uses of ..
                            break;
                        } else if (i > 0) {
                            name.splice(i - 1, 2);
                            i -= 2;
                        }
                    }
                }
                //end trimDots

                name = name.join("/");
            }
        }

        //Apply map config if available.
        if ((baseParts || starMap) && map) {
            nameParts = name.split('/');

            for (i = nameParts.length; i > 0; i -= 1) {
                nameSegment = nameParts.slice(0, i).join("/");

                if (baseParts) {
                    //Find the longest baseName segment match in the config.
                    //So, do joins on the biggest to smallest lengths of baseParts.
                    for (j = baseParts.length; j > 0; j -= 1) {
                        mapValue = map[baseParts.slice(0, j).join('/')];

                        //baseName segment has  config, find if it has one for
                        //this name.
                        if (mapValue) {
                            mapValue = mapValue[nameSegment];
                            if (mapValue) {
                                //Match, update name to the new value.
                                foundMap = mapValue;
                                foundI = i;
                                break;
                            }
                        }
                    }
                }

                if (foundMap) {
                    break;
                }

                //Check for a star map match, but just hold on to it,
                //if there is a shorter segment match later in a matching
                //config, then favor over this star map.
                if (!foundStarMap && starMap && starMap[nameSegment]) {
                    foundStarMap = starMap[nameSegment];
                    starI = i;
                }
            }

            if (!foundMap && foundStarMap) {
                foundMap = foundStarMap;
                foundI = starI;
            }

            if (foundMap) {
                nameParts.splice(0, foundI, foundMap);
                name = nameParts.join('/');
            }
        }

        return name;
    }

    function makeRequire(relName, forceSync) {
        return function () {
            //A version of a require function that passes a moduleName
            //value for items that may need to
            //look up paths relative to the moduleName
            return req.apply(undef, aps.call(arguments, 0).concat([relName, forceSync]));
        };
    }

    function makeNormalize(relName) {
        return function (name) {
            return normalize(name, relName);
        };
    }

    function makeLoad(depName) {
        return function (value) {
            defined[depName] = value;
        };
    }

    function callDep(name) {
        if (waiting.hasOwnProperty(name)) {
            var args = waiting[name];
            delete waiting[name];
            defining[name] = true;
            main.apply(undef, args);
        }

        if (!defined.hasOwnProperty(name) && !defining.hasOwnProperty(name)) {
            throw new Error('No ' + name);
        }
        return defined[name];
    }

    //Turns a plugin!resource to [plugin, resource]
    //with the plugin being undefined if the name
    //did not have a plugin prefix.
    function splitPrefix(name) {
        var prefix,
            index = name ? name.indexOf('!') : -1;
        if (index > -1) {
            prefix = name.substring(0, index);
            name = name.substring(index + 1, name.length);
        }
        return [prefix, name];
    }

    function onResourceLoad(name, defined, deps){
        if(requirejs.onResourceLoad && name){
            requirejs.onResourceLoad({defined:defined}, {id:name}, deps);
        }
    }

    /**
     * Makes a name map, normalizing the name, and using a plugin
     * for normalization if necessary. Grabs a ref to plugin
     * too, as an optimization.
     */
    makeMap = function (name, relName) {
        var plugin,
            parts = splitPrefix(name),
            prefix = parts[0];

        name = parts[1];

        if (prefix) {
            prefix = normalize(prefix, relName);
            plugin = callDep(prefix);
        }

        //Normalize according
        if (prefix) {
            if (plugin && plugin.normalize) {
                name = plugin.normalize(name, makeNormalize(relName));
            } else {
                name = normalize(name, relName);
            }
        } else {
            name = normalize(name, relName);
            parts = splitPrefix(name);
            prefix = parts[0];
            name = parts[1];
            if (prefix) {
                plugin = callDep(prefix);
            }
        }

        //Using ridiculous property names for space reasons
        return {
            f: prefix ? prefix + '!' + name : name, //fullName
            n: name,
            pr: prefix,
            p: plugin
        };
    };

    function makeConfig(name) {
        return function () {
            return (config && config.config && config.config[name]) || {};
        };
    }

    handlers = {
        require: function (name) {
            return makeRequire(name);
        },
        exports: function (name) {
            var e = defined[name];
            if (typeof e !== 'undefined') {
                return e;
            } else {
                return (defined[name] = {});
            }
        },
        module: function (name) {
            return {
                id: name,
                uri: '',
                exports: defined[name],
                config: makeConfig(name)
            };
        }
    };

    main = function (name, deps, callback, relName) {
        var cjsModule, depName, ret, map, i,
            args = [],
            usingExports;

        //Use name if no relName
        relName = relName || name;

        //Call the callback to define the module, if necessary.
        if (typeof callback === 'function') {

            //Pull out the defined dependencies and pass the ordered
            //values to the callback.
            //Default to [require, exports, module] if no deps
            deps = !deps.length && callback.length ? ['require', 'exports', 'module'] : deps;
            for (i = 0; i < deps.length; i += 1) {
                map = makeMap(deps[i], relName);
                depName = map.f;

                //Fast path CommonJS standard dependencies.
                if (depName === "require") {
                    args[i] = handlers.require(name);
                } else if (depName === "exports") {
                    //CommonJS module spec 1.1
                    args[i] = handlers.exports(name);
                    usingExports = true;
                } else if (depName === "module") {
                    //CommonJS module spec 1.1
                    cjsModule = args[i] = handlers.module(name);
                } else if (defined.hasOwnProperty(depName) ||
                           waiting.hasOwnProperty(depName) ||
                           defining.hasOwnProperty(depName)) {
                    args[i] = callDep(depName);
                } else if (map.p) {
                    map.p.load(map.n, makeRequire(relName, true), makeLoad(depName), {});
                    args[i] = defined[depName];
                } else {
                    throw new Error(name + ' missing ' + depName);
                }
            }

            ret = callback.apply(defined[name], args);

            if (name) {
                //If setting exports via "module" is in play,
                //favor that over return value and exports. After that,
                //favor a non-undefined return value over exports use.
                if (cjsModule && cjsModule.exports !== undef &&
                        cjsModule.exports !== defined[name]) {
                    defined[name] = cjsModule.exports;
                } else if (ret !== undef || !usingExports) {
                    //Use the return value from the function.
                    defined[name] = ret;
                }
            }
        } else if (name) {
            //May just be an object definition for the module. Only
            //worry about defining if have a module name.
            defined[name] = callback;
        }

        onResourceLoad(name, defined, args);
    };

    requirejs = require = req = function (deps, callback, relName, forceSync, alt) {
        if (typeof deps === "string") {
            if (handlers[deps]) {
                //callback in this case is really relName
                return handlers[deps](callback);
            }
            //Just return the module wanted. In this scenario, the
            //deps arg is the module name, and second arg (if passed)
            //is just the relName.
            //Normalize module name, if it contains . or ..
            return callDep(makeMap(deps, callback).f);
        } else if (!deps.splice) {
            //deps is a config object, not an array.
            config = deps;
            if (callback.splice) {
                //callback is an array, which means it is a dependency list.
                //Adjust args if there are dependencies
                deps = callback;
                callback = relName;
                relName = null;
            } else {
                deps = undef;
            }
        }

        //Support require(['a'])
        callback = callback || function () {};

        //If relName is a function, it is an errback handler,
        //so remove it.
        if (typeof relName === 'function') {
            relName = forceSync;
            forceSync = alt;
        }

        //Simulate async callback;
        if (forceSync) {
            main(undef, deps, callback, relName);
        } else {
            setTimeout(function () {
                main(undef, deps, callback, relName);
            }, 15);
        }

        return req;
    };

    /**
     * Just drops the config on the floor, but returns req in case
     * the config return value is used.
     */
    req.config = function (cfg) {
        config = cfg;
        return req;
    };

    define = function (name, deps, callback) {

        //This module may not have dependencies
        if (!deps.splice) {
            //deps is not an array, so probably means
            //an object literal or factory function for
            //the value. Adjust args.
            callback = deps;
            deps = [];
        }

        waiting[name] = [name, deps, callback];
    };

    define.amd = {
        jQuery: true
    };
}());

define("../Scripts/require/almond-custom", function(){});

define('lib/pagelayout',[],function(){var o=function(o){o.layout()},n=function(o){o.enabled||(o.options.onMobileLayout=function(){$(".hero-unit").addClass("h-big-top-margin")},o.options.onTabletLayout=function(){$(".hero-unit").addClass("h-big-top-margin")},o.options.onDesktopLayout=function(){$(".hero-unit").removeClass("h-big-top-margin")},o.layout())},t=function(o){o.enabled||o.layout()};return{offcanvasLayout:n,flyoutLayout:t,togglelayout:o}});
var q=null;window.PR_SHOULD_USE_CONTINUATION=!0,function(){function e(e){function t(e){var t=e.charCodeAt(0);if(92!==t)return t;var n=e.charAt(1);return(t=d[n])?t:n>="0"&&"7">=n?parseInt(e.substring(1),8):"u"===n||"x"===n?parseInt(e.substring(2),16):e.charCodeAt(1)}function n(e){return 32>e?(16>e?"\\x0":"\\x")+e.toString(16):(e=String.fromCharCode(e),("\\"===e||"-"===e||"["===e||"]"===e)&&(e="\\"+e),e)}function r(e){for(var r=e.substring(1,e.length-1).match(/\\u[\dA-Fa-f]{4}|\\x[\dA-Fa-f]{2}|\\[0-3][0-7]{0,2}|\\[0-7]{1,2}|\\[\S\s]|[^\\]/g),e=[],a=[],s="^"===r[0],i=s?1:0,o=r.length;o>i;++i){var l=r[i];if(/\\[bdsw]/i.test(l))e.push(l);else{var u,l=t(l);o>i+2&&"-"===r[i+1]?(u=t(r[i+2]),i+=2):u=l,a.push([l,u]),65>u||l>122||(65>u||l>90||a.push([32|Math.max(65,l),32|Math.min(u,90)]),97>u||l>122||a.push([-33&Math.max(97,l),-33&Math.min(u,122)]))}}for(a.sort(function(e,t){return e[0]-t[0]||t[1]-e[1]}),r=[],l=[0/0,0/0],i=0;i<a.length;++i)o=a[i],o[0]<=l[1]+1?l[1]=Math.max(l[1],o[1]):r.push(l=o);for(a=["["],s&&a.push("^"),a.push.apply(a,e),i=0;i<r.length;++i)o=r[i],a.push(n(o[0])),o[1]>o[0]&&(o[1]+1>o[0]&&a.push("-"),a.push(n(o[1])));return a.push("]"),a.join("")}function a(e){for(var t=e.source.match(/\[(?:[^\\\]]|\\[\S\s])*]|\\u[\dA-Fa-f]{4}|\\x[\dA-Fa-f]{2}|\\\d+|\\[^\dux]|\(\?[!:=]|[()^]|[^()[\\^]+/g),n=t.length,a=[],o=0,l=0;n>o;++o){var u=t[o];"("===u?++l:"\\"===u.charAt(0)&&(u=+u.substring(1))&&l>=u&&(a[u]=-1)}for(o=1;o<a.length;++o)-1===a[o]&&(a[o]=++s);for(l=o=0;n>o;++o)u=t[o],"("===u?(++l,void 0===a[l]&&(t[o]="(?:")):"\\"===u.charAt(0)&&(u=+u.substring(1))&&l>=u&&(t[o]="\\"+a[l]);for(l=o=0;n>o;++o)"^"===t[o]&&"^"!==t[o+1]&&(t[o]="");if(e.ignoreCase&&i)for(o=0;n>o;++o)u=t[o],e=u.charAt(0),u.length>=2&&"["===e?t[o]=r(u):"\\"!==e&&(t[o]=u.replace(/[A-Za-z]/g,function(e){return e=e.charCodeAt(0),"["+String.fromCharCode(-33&e,32|e)+"]"}));return t.join("")}for(var s=0,i=!1,o=!1,l=0,u=e.length;u>l;++l){var c=e[l];if(c.ignoreCase)o=!0;else if(/[a-z]/i.test(c.source.replace(/\\u[\da-f]{4}|\\x[\da-f]{2}|\\[^UXux]/gi,""))){i=!0,o=!1;break}}for(var d={b:8,t:9,n:10,v:11,f:12,r:13},p=[],l=0,u=e.length;u>l;++l){if(c=e[l],c.global||c.multiline)throw Error(""+c);p.push("(?:"+a(c)+")")}return RegExp(p.join("|"),o?"gi":"g")}function t(e){function t(e){switch(e.nodeType){case 1:if(r.test(e.className))break;for(var n=e.firstChild;n;n=n.nextSibling)t(n);n=e.nodeName,("BR"===n||"LI"===n)&&(a[o]="\n",i[o<<1]=s++,i[1|o++<<1]=e);break;case 3:case 4:n=e.nodeValue,n.length&&(n=l?n.replace(/\r\n?/g,"\n"):n.replace(/[\t\n\r ]+/g," "),a[o]=n,i[o<<1]=s,s+=n.length,i[1|o++<<1]=e)}}var n,r=/(?:^|\s)nocode(?:\s|$)/,a=[],s=0,i=[],o=0;e.currentStyle?n=e.currentStyle.whiteSpace:window.getComputedStyle&&(n=document.defaultView.getComputedStyle(e,q).getPropertyValue("white-space"));var l=n&&"pre"===n.substring(0,3);return t(e),{a:a.join("").replace(/\n$/,""),c:i}}function n(e,t,n,r){t&&(e={a:t,d:e},n(e),r.push.apply(r,e.e))}function r(t,r){function a(e){for(var t=e.d,u=[t,"pln"],c=0,d=e.a.match(s)||[],p={},f=0,h=d.length;h>f;++f){var g,m=d[f],y=p[m],v=void 0;if("string"==typeof y)g=!1;else{var w=i[m.charAt(0)];if(w)v=m.match(w[1]),y=w[0];else{for(g=0;l>g;++g)if(w=r[g],v=m.match(w[1])){y=w[0];break}v||(y="pln")}!(g=y.length>=5&&"lang-"===y.substring(0,5))||v&&"string"==typeof v[1]||(g=!1,y="src"),g||(p[m]=y)}if(w=c,c+=m.length,g){g=v[1];var b=m.indexOf(g),S=b+g.length;v[2]&&(S=m.length-v[2].length,b=S-g.length),y=y.substring(5),n(t+w,m.substring(0,b),a,u),n(t+w+b,g,o(y,g),u),n(t+w+S,m.substring(S),a,u)}else u.push(t+w,y)}e.e=u}var s,i={};!function(){for(var n=t.concat(r),a=[],o={},l=0,u=n.length;u>l;++l){var c=n[l],d=c[3];if(d)for(var p=d.length;--p>=0;)i[d.charAt(p)]=c;c=c[1],d=""+c,o.hasOwnProperty(d)||(a.push(c),o[d]=q)}a.push(/[\S\s]/),s=e(a)}();var l=r.length;return a}function a(e){var t=[],n=[];e.tripleQuotedStrings?t.push(["str",/^(?:'''(?:[^'\\]|\\[\S\s]|''?(?=[^']))*(?:'''|$)|"""(?:[^"\\]|\\[\S\s]|""?(?=[^"]))*(?:"""|$)|'(?:[^'\\]|\\[\S\s])*(?:'|$)|"(?:[^"\\]|\\[\S\s])*(?:"|$))/,q,"'\""]):e.multiLineStrings?t.push(["str",/^(?:'(?:[^'\\]|\\[\S\s])*(?:'|$)|"(?:[^"\\]|\\[\S\s])*(?:"|$)|`(?:[^\\`]|\\[\S\s])*(?:`|$))/,q,"'\"`"]):t.push(["str",/^(?:'(?:[^\n\r'\\]|\\.)*(?:'|$)|"(?:[^\n\r"\\]|\\.)*(?:"|$))/,q,"\"'"]),e.verbatimStrings&&n.push(["str",/^@"(?:[^"]|"")*(?:"|$)/,q]);var a=e.hashComments;return a&&(e.cStyleComments?(a>1?t.push(["com",/^#(?:##(?:[^#]|#(?!##))*(?:###|$)|.*)/,q,"#"]):t.push(["com",/^#(?:(?:define|elif|else|endif|error|ifdef|include|ifndef|line|pragma|undef|warning)\b|[^\n\r]*)/,q,"#"]),n.push(["str",/^<(?:(?:(?:\.\.\/)*|\/?)(?:[\w-]+(?:\/[\w-]+)+)?[\w-]+\.h|[a-z]\w*)>/,q])):t.push(["com",/^#[^\n\r]*/,q,"#"])),e.cStyleComments&&(n.push(["com",/^\/\/[^\n\r]*/,q]),n.push(["com",/^\/\*[\S\s]*?(?:\*\/|$)/,q])),e.regexLiterals&&n.push(["lang-regex",/^(?:^^\.?|[!+-]|!=|!==|#|%|%=|&|&&|&&=|&=|\(|\*|\*=|\+=|,|-=|->|\/|\/=|:|::|;|<|<<|<<=|<=|=|==|===|>|>=|>>|>>=|>>>|>>>=|[?@[^]|\^=|\^\^|\^\^=|{|\||\|=|\|\||\|\|=|~|break|case|continue|delete|do|else|finally|instanceof|return|throw|try|typeof)\s*(\/(?=[^*/])(?:[^/[\\]|\\[\S\s]|\[(?:[^\\\]]|\\[\S\s])*(?:]|$))+\/)/]),(a=e.types)&&n.push(["typ",a]),e=(""+e.keywords).replace(/^ | $/g,""),e.length&&n.push(["kwd",RegExp("^(?:"+e.replace(/[\s,]+/g,"|")+")\\b"),q]),t.push(["pln",/^\s+/,q," \r\n	 "]),n.push(["lit",/^@[$_a-z][\w$@]*/i,q],["typ",/^(?:[@_]?[A-Z]+[a-z][\w$@]*|\w+_t\b)/,q],["pln",/^[$_a-z][\w$@]*/i,q],["lit",/^(?:0x[\da-f]+|(?:\d(?:_\d+)*\d*(?:\.\d*)?|\.\d\+)(?:e[+-]?\d+)?)[a-z]*/i,q,"0123456789"],["pln",/^\\[\S\s]?/,q],["pun",/^.[^\s\w"-$'./@\\`]*/,q]),r(t,n)}function s(e,t){function n(e){switch(e.nodeType){case 1:if(s.test(e.className))break;if("BR"===e.nodeName)r(e),e.parentNode&&e.parentNode.removeChild(e);else for(e=e.firstChild;e;e=e.nextSibling)n(e);break;case 3:case 4:if(l){var t=e.nodeValue,a=t.match(i);if(a){var u=t.substring(0,a.index);e.nodeValue=u,(t=t.substring(a.index+a[0].length))&&e.parentNode.insertBefore(o.createTextNode(t),e.nextSibling),r(e),u||e.parentNode.removeChild(e)}}}}function r(e){function t(e,n){var r=n?e.cloneNode(!1):e,a=e.parentNode;if(a){var a=t(a,1),s=e.nextSibling;a.appendChild(r);for(var i=s;i;i=s)s=i.nextSibling,a.appendChild(i)}return r}for(;!e.nextSibling;)if(e=e.parentNode,!e)return;for(var n,e=t(e.nextSibling,0);(n=e.parentNode)&&1===n.nodeType;)e=n;u.push(e)}var a,s=/(?:^|\s)nocode(?:\s|$)/,i=/\r\n?|\n/,o=e.ownerDocument;e.currentStyle?a=e.currentStyle.whiteSpace:window.getComputedStyle&&(a=o.defaultView.getComputedStyle(e,q).getPropertyValue("white-space"));var l=a&&"pre"===a.substring(0,3);for(a=o.createElement("LI");e.firstChild;)a.appendChild(e.firstChild);for(var u=[a],c=0;c<u.length;++c)n(u[c]);t===(0|t)&&u[0].setAttribute("value",t);var d=o.createElement("OL");d.className="linenums";for(var p=Math.max(0,0|t-1)||0,c=0,f=u.length;f>c;++c)a=u[c],a.className="L"+(c+p)%10,a.firstChild||a.appendChild(o.createTextNode(" ")),d.appendChild(a);e.appendChild(d)}function i(e,t){for(var n=t.length;--n>=0;){var r=t[n];w.hasOwnProperty(r)?window.console&&console.warn("cannot override language handler %s",r):w[r]=e}}function o(e,t){return e&&w.hasOwnProperty(e)||(e=/^\s*</.test(t)?"default-markup":"default-code"),w[e]}function l(e){var n=e.g;try{var r=t(e.h),a=r.a;e.a=a,e.c=r.c,e.d=0,o(n,a)(e);var s=/\bMSIE\b/.test(navigator.userAgent),n=/\n/g,i=e.a,l=i.length,r=0,u=e.c,c=u.length,a=0,d=e.e,p=d.length,e=0;d[p]=l;var f,h;for(h=f=0;p>h;)d[h]!==d[h+2]?(d[f++]=d[h++],d[f++]=d[h++]):h+=2;for(p=f,h=f=0;p>h;){for(var g=d[h],m=d[h+1],y=h+2;p>=y+2&&d[y+1]===m;)y+=2;d[f++]=g,d[f++]=m,h=y}for(d.length=f;c>a;){var v,w=u[a+2]||l,b=d[e+2]||l,y=Math.min(w,b),S=u[a+1];if(1!==S.nodeType&&(v=i.substring(r,y))){s&&(v=v.replace(n,"\r")),S.nodeValue=v;var x=S.ownerDocument,C=x.createElement("SPAN");C.className=d[e+1];var N=S.parentNode;N.replaceChild(C,S),C.appendChild(S),w>r&&(u[a+1]=S=x.createTextNode(i.substring(y,w)),N.insertBefore(S,C.nextSibling))}r=y,r>=w&&(a+=2),r>=b&&(e+=2)}}catch(k){"console"in window&&console.log(k&&k.stack?k.stack:k)}}var u=["break,continue,do,else,for,if,return,while"],c=[[u,"auto,case,char,const,default,double,enum,extern,float,goto,int,long,register,short,signed,sizeof,static,struct,switch,typedef,union,unsigned,void,volatile"],"catch,class,delete,false,import,new,operator,private,protected,public,this,throw,true,try,typeof"],d=[c,"alignof,align_union,asm,axiom,bool,concept,concept_map,const_cast,constexpr,decltype,dynamic_cast,explicit,export,friend,inline,late_check,mutable,namespace,nullptr,reinterpret_cast,static_assert,static_cast,template,typeid,typename,using,virtual,where"],p=[c,"abstract,boolean,byte,extends,final,finally,implements,import,instanceof,null,native,package,strictfp,super,synchronized,throws,transient"],f=[p,"as,base,by,checked,decimal,delegate,descending,dynamic,event,fixed,foreach,from,group,implicit,in,interface,internal,into,is,lock,object,out,override,orderby,params,partial,readonly,ref,sbyte,sealed,stackalloc,string,select,uint,ulong,unchecked,unsafe,ushort,var"],c=[c,"debugger,eval,export,function,get,null,set,undefined,var,with,Infinity,NaN"],h=[u,"and,as,assert,class,def,del,elif,except,exec,finally,from,global,import,in,is,lambda,nonlocal,not,or,pass,print,raise,try,with,yield,False,True,None"],g=[u,"alias,and,begin,case,class,def,defined,elsif,end,ensure,false,in,module,next,nil,not,or,redo,rescue,retry,self,super,then,true,undef,unless,until,when,yield,BEGIN,END"],u=[u,"case,done,elif,esac,eval,fi,function,in,local,set,then,until"],m=/^(DIR|FILE|vector|(de|priority_)?queue|list|stack|(const_)?iterator|(multi)?(set|map)|bitset|u?(int|float)\d*)/,y=/\S/,v=a({keywords:[d,f,c,"caller,delete,die,do,dump,elsif,eval,exit,foreach,for,goto,if,import,last,local,my,next,no,our,print,package,redo,require,sub,undef,unless,until,use,wantarray,while,BEGIN,END"+h,g,u],hashComments:!0,cStyleComments:!0,multiLineStrings:!0,regexLiterals:!0}),w={};i(v,["default-code"]),i(r([],[["pln",/^[^<?]+/],["dec",/^<!\w[^>]*(?:>|$)/],["com",/^<\!--[\S\s]*?(?:--\>|$)/],["lang-",/^<\?([\S\s]+?)(?:\?>|$)/],["lang-",/^<%([\S\s]+?)(?:%>|$)/],["pun",/^(?:<[%?]|[%?]>)/],["lang-",/^<xmp\b[^>]*>([\S\s]+?)<\/xmp\b[^>]*>/i],["lang-js",/^<script\b[^>]*>([\S\s]*?)(<\/script\b[^>]*>)/i],["lang-css",/^<style\b[^>]*>([\S\s]*?)(<\/style\b[^>]*>)/i],["lang-in.tag",/^(<\/?[a-z][^<>]*>)/i]]),["default-markup","htm","html","mxml","xhtml","xml","xsl"]),i(r([["pln",/^\s+/,q," 	\r\n"],["atv",/^(?:"[^"]*"?|'[^']*'?)/,q,"\"'"]],[["tag",/^^<\/?[a-z](?:[\w-.:]*\w)?|\/?>$/i],["atn",/^(?!style[\s=]|on)[a-z](?:[\w:-]*\w)?/i],["lang-uq.val",/^=\s*([^\s"'>]*(?:[^\s"'/>]|\/(?=\s)))/],["pun",/^[/<->]+/],["lang-js",/^on\w+\s*=\s*"([^"]+)"/i],["lang-js",/^on\w+\s*=\s*'([^']+)'/i],["lang-js",/^on\w+\s*=\s*([^\s"'>]+)/i],["lang-css",/^style\s*=\s*"([^"]+)"/i],["lang-css",/^style\s*=\s*'([^']+)'/i],["lang-css",/^style\s*=\s*([^\s"'>]+)/i]]),["in.tag"]),i(r([],[["atv",/^[\S\s]+/]]),["uq.val"]),i(a({keywords:d,hashComments:!0,cStyleComments:!0,types:m}),["c","cc","cpp","cxx","cyc","m"]),i(a({keywords:"null,true,false"}),["json"]),i(a({keywords:f,hashComments:!0,cStyleComments:!0,verbatimStrings:!0,types:m}),["cs"]),i(a({keywords:p,cStyleComments:!0}),["java"]),i(a({keywords:u,hashComments:!0,multiLineStrings:!0}),["bsh","csh","sh"]),i(a({keywords:h,hashComments:!0,multiLineStrings:!0,tripleQuotedStrings:!0}),["cv","py"]),i(a({keywords:"caller,delete,die,do,dump,elsif,eval,exit,foreach,for,goto,if,import,last,local,my,next,no,our,print,package,redo,require,sub,undef,unless,until,use,wantarray,while,BEGIN,END",hashComments:!0,multiLineStrings:!0,regexLiterals:!0}),["perl","pl","pm"]),i(a({keywords:g,hashComments:!0,multiLineStrings:!0,regexLiterals:!0}),["rb"]),i(a({keywords:c,cStyleComments:!0,regexLiterals:!0}),["js"]),i(a({keywords:"all,and,by,catch,class,else,extends,false,finally,for,if,in,is,isnt,loop,new,no,not,null,of,off,on,or,return,super,then,true,try,unless,until,when,while,yes",hashComments:3,cStyleComments:!0,multilineStrings:!0,tripleQuotedStrings:!0,regexLiterals:!0}),["coffee"]),i(r([],[["str",/^[\S\s]+/]]),["regex"]),window.prettyPrintOne=function(e,t,n){var r=document.createElement("PRE");return r.innerHTML=e,n&&s(r,n),l({g:t,i:n,h:r}),r.innerHTML},window.prettyPrint=function(e){function t(){for(var n=window.PR_SHOULD_USE_CONTINUATION?u.now()+250:1/0;d<r.length&&u.now()<n;d++){var a=r[d],i=a.className;if(i.indexOf("prettyprint")>=0){var o,f,i=i.match(p);if(f=!i){f=a;for(var h=void 0,g=f.firstChild;g;g=g.nextSibling)var m=g.nodeType,h=1===m?h?f:g:3===m?y.test(g.nodeValue)?f:h:h;f=(o=h===f?void 0:h)&&"CODE"===o.tagName}for(f&&(i=o.className.match(p)),i&&(i=i[1]),f=!1,h=a.parentNode;h;h=h.parentNode)if(("pre"===h.tagName||"code"===h.tagName||"xmp"===h.tagName)&&h.className&&h.className.indexOf("prettyprint")>=0){f=!0;break}f||((f=(f=a.className.match(/\blinenums\b(?::(\d+))?/))?f[1]&&f[1].length?+f[1]:!0:!1)&&s(a,f),c={g:i,h:a,i:f},l(c))}}d<r.length?setTimeout(t,250):e&&e()}for(var n=[document.getElementsByTagName("pre"),document.getElementsByTagName("code"),document.getElementsByTagName("xmp")],r=[],a=0;a<n.length;++a)for(var i=0,o=n[a].length;o>i;++i)r.push(n[a][i]);var n=q,u=Date;u.now||(u={now:function(){return+new Date}});var c,d=0,p=/\blang(?:uage)?-([\w.]+)(?!\S)/;t()},window.PR={createSimpleLexer:r,registerLangHandler:i,sourceDecorator:a,PR_ATTRIB_NAME:"atn",PR_ATTRIB_VALUE:"atv",PR_COMMENT:"com",PR_DECLARATION:"dec",PR_KEYWORD:"kwd",PR_LITERAL:"lit",PR_NOCODE:"nocode",PR_PLAIN:"pln",PR_PUNCTUATION:"pun",PR_SOURCE:"src",PR_STRING:"str",PR_TAG:"tag",PR_TYPE:"typ"}}();
define("lib/prettify", function(){});

define('durandal/system',["require","jquery"],function(e,t){function n(e){var t="[object "+e+"]";i["is"+e]=function(e){return s.call(e)==t}}var i,o=!1,a=Object.keys,r=Object.prototype.hasOwnProperty,s=Object.prototype.toString,l=!1,c=Array.isArray,u=Array.prototype.slice;if(Function.prototype.bind&&("object"==typeof console||"function"==typeof console)&&"object"==typeof console.log)try{["log","info","warn","error","assert","dir","clear","profile","profileEnd"].forEach(function(e){console[e]=this.call(console[e],console)},Function.prototype.bind)}catch(d){l=!0}e.on&&e.on("moduleLoaded",function(e,t){i.setModuleId(e,t)}),"undefined"!=typeof requirejs&&(requirejs.onResourceLoad=function(e,t){i.setModuleId(e.defined[t.id],t.id)});var f=function(){},p=function(){try{if("undefined"!=typeof console&&"function"==typeof console.log)if(window.opera)for(var e=0;e<arguments.length;)console.log("Item "+(e+1)+": "+arguments[e]),e++;else 1==u.call(arguments).length&&"string"==typeof u.call(arguments)[0]?console.log(u.call(arguments).toString()):console.log.apply(console,u.call(arguments));else Function.prototype.bind&&!l||"undefined"==typeof console||"object"!=typeof console.log||Function.prototype.call.call(console.log,console,u.call(arguments))}catch(t){}},v=function(e){if(e instanceof Error)throw e;throw new Error(e)};i={version:"2.0.0",noop:f,getModuleId:function(e){return e?"function"==typeof e?e.prototype.__moduleId__:"string"==typeof e?null:e.__moduleId__:null},setModuleId:function(e,t){return e?"function"==typeof e?(e.prototype.__moduleId__=t,void 0):("string"!=typeof e&&(e.__moduleId__=t),void 0):void 0},resolveObject:function(e){return i.isFunction(e)?new e:e},debug:function(e){return 1==arguments.length&&(o=e,o?(this.log=p,this.error=v,this.log("Debug:Enabled")):(this.log("Debug:Disabled"),this.log=f,this.error=f)),o},log:f,error:f,assert:function(e,t){e||i.error(new Error(t||"Assert:Failed"))},defer:function(e){return t.Deferred(e)},guid:function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){var t=0|16*Math.random(),n="x"==e?t:8|3&t;return n.toString(16)})},acquire:function(){var t,n=arguments[0],o=!1;return i.isArray(n)?(t=n,o=!0):t=u.call(arguments,0),this.defer(function(n){e(t,function(){var e=arguments;setTimeout(function(){e.length>1||o?n.resolve(u.call(e,0)):n.resolve(e[0])},1)},function(e){n.reject(e)})}).promise()},extend:function(e){for(var t=u.call(arguments,1),n=0;n<t.length;n++){var i=t[n];if(i)for(var o in i)e[o]=i[o]}return e},wait:function(e){return i.defer(function(t){setTimeout(t.resolve,e)}).promise()}},i.keys=a||function(e){if(e!==Object(e))throw new TypeError("Invalid object");var t=[];for(var n in e)r.call(e,n)&&(t[t.length]=n);return t},i.isElement=function(e){return!(!e||1!==e.nodeType)},i.isArray=c||function(e){return"[object Array]"==s.call(e)},i.isObject=function(e){return e===Object(e)},i.isBoolean=function(e){return"boolean"==typeof e},i.isPromise=function(e){return e&&i.isFunction(e.then)};for(var g=["Arguments","Function","String","Number","Date","RegExp"],h=0;h<g.length;h++)n(g[h]);return i});
define('durandal/viewEngine',["durandal/system","jquery"],function(e,t){var n;return n=t.parseHTML?function(e){return t.parseHTML(e)}:function(e){return t(e).get()},{viewExtension:".html",viewPlugin:"text",isViewUrl:function(e){return-1!==e.indexOf(this.viewExtension,e.length-this.viewExtension.length)},convertViewUrlToViewId:function(e){return e.substring(0,e.length-this.viewExtension.length)},convertViewIdToRequirePath:function(e){return this.viewPlugin+"!"+e+this.viewExtension},parseMarkup:n,processMarkup:function(e){var t=this.parseMarkup(e);return this.ensureSingleElement(t)},ensureSingleElement:function(e){if(1==e.length)return e[0];for(var n=[],i=0;i<e.length;i++){var o=e[i];if(8!=o.nodeType){if(3==o.nodeType){var a=/\S/.test(o.nodeValue);if(!a)continue}n.push(o)}}return n.length>1?t(n).wrapAll('<div class="durandal-wrapper"></div>').parent().get(0):n[0]},createView:function(t){var n=this,i=this.convertViewIdToRequirePath(t);return e.defer(function(o){e.acquire(i).then(function(e){var i=n.processMarkup(e);i.setAttribute("data-view",t),o.resolve(i)}).fail(function(e){n.createFallbackView(t,i,e).then(function(e){e.setAttribute("data-view",t),o.resolve(e)})})}).promise()},createFallbackView:function(t,n){var i=this,o='View Not Found. Searched for "'+t+'" via path "'+n+'".';return e.defer(function(e){e.resolve(i.processMarkup('<div class="durandal-view-404">'+o+"</div>"))}).promise()}}});
define('durandal/viewLocator',["durandal/system","durandal/viewEngine"],function(e,t){function n(e,t){for(var n=0;n<e.length;n++){var i=e[n],o=i.getAttribute("data-view");if(o==t)return i}}function i(e){return(e+"").replace(/([\\\.\+\*\?\[\^\]\$\(\)\{\}\=\!\<\>\|\:])/g,"\\$1")}return{useConvention:function(e,t,n){e=e||"viewmodels",t=t||"views",n=n||t;var o=new RegExp(i(e),"gi");this.convertModuleIdToViewId=function(e){return e.replace(o,t)},this.translateViewIdToArea=function(e,t){return t&&"partial"!=t?n+"/"+t+"/"+e:n+"/"+e}},locateViewForObject:function(t,n,i){var o;if(t.getView&&(o=t.getView()))return this.locateView(o,n,i);if(t.viewUrl)return this.locateView(t.viewUrl,n,i);var a=e.getModuleId(t);return a?this.locateView(this.convertModuleIdToViewId(a),n,i):this.locateView(this.determineFallbackViewId(t),n,i)},convertModuleIdToViewId:function(e){return e},determineFallbackViewId:function(e){var t=/function (.{1,})\(/,n=t.exec(e.constructor.toString()),i=n&&n.length>1?n[1]:"";return"views/"+i},translateViewIdToArea:function(e){return e},locateView:function(i,o,a){if("string"==typeof i){var r;if(r=t.isViewUrl(i)?t.convertViewUrlToViewId(i):i,o&&(r=this.translateViewIdToArea(r,o)),a){var s=n(a,r);if(s)return e.defer(function(e){e.resolve(s)}).promise()}return t.createView(r)}return e.defer(function(e){e.resolve(i)}).promise()}}});
define('durandal/binder',["durandal/system","knockout"],function(e,t){function n(t){return void 0===t?{applyBindings:!0}:e.isBoolean(t)?{applyBindings:t}:(void 0===t.applyBindings&&(t.applyBindings=!0),t)}function a(a,c,u,p){if(!c||!u)return i.throwOnErrors?e.error(o):e.log(o,c,p),void 0;if(!c.getAttribute)return i.throwOnErrors?e.error(r):e.log(r,c,p),void 0;var d=c.getAttribute("data-view");try{var f;return a&&a.binding&&(f=a.binding(c)),f=n(f),i.binding(p,c,f),f.applyBindings?(e.log("Binding",d,p),t.applyBindings(u,c)):a&&t.utils.domData.set(c,l,{$data:a}),i.bindingComplete(p,c,f),a&&a.bindingComplete&&a.bindingComplete(c),t.utils.domData.set(c,s,f),f}catch(v){v.message=v.message+";\nView: "+d+";\nModuleId: "+e.getModuleId(p),i.throwOnErrors?e.error(v):e.log(v.message)}}var i,o="Insufficient Information to Bind",r="Unexpected View Type",s="durandal-binding-instruction",l="__ko_bindingContext__";return i={binding:e.noop,bindingComplete:e.noop,throwOnErrors:!1,getBindingInstruction:function(e){return t.utils.domData.get(e,s)},bindContext:function(e,t,n){return n&&e&&(e=e.createChildContext(n)),a(n,t,e,n||(e?e.$data:null))},bind:function(e,t){return a(e,t,e,e)}}});
define('durandal/activator',["durandal/system","knockout"],function(e,t){function a(e){return void 0==e&&(e={}),e.closeOnDeactivate||(e.closeOnDeactivate=c.defaults.closeOnDeactivate),e.beforeActivate||(e.beforeActivate=c.defaults.beforeActivate),e.afterDeactivate||(e.afterDeactivate=c.defaults.afterDeactivate),e.affirmations||(e.affirmations=c.defaults.affirmations),e.interpretResponse||(e.interpretResponse=c.defaults.interpretResponse),e.areSameItem||(e.areSameItem=c.defaults.areSameItem),e}function n(t,a,n){return e.isArray(n)?t[a].apply(t,n):t[a](n)}function o(t,a,n,o,i){if(t&&t.deactivate){e.log("Deactivating",t);var r;try{r=t.deactivate(a)}catch(s){return e.error(s),o.resolve(!1),void 0}r&&r.then?r.then(function(){n.afterDeactivate(t,a,i),o.resolve(!0)},function(t){e.log(t),o.resolve(!1)}):(n.afterDeactivate(t,a,i),o.resolve(!0))}else t&&n.afterDeactivate(t,a,i),o.resolve(!0)}function i(t,a,o,i){if(t)if(t.activate){e.log("Activating",t);var r;try{r=n(t,"activate",i)}catch(s){return e.error(s),o(!1),void 0}r&&r.then?r.then(function(){a(t),o(!0)},function(t){e.log(t),o(!1)}):(a(t),o(!0))}else a(t),o(!0);else o(!0)}function r(t,a,n){return n.lifecycleData=null,e.defer(function(o){if(t&&t.canDeactivate){var i;try{i=t.canDeactivate(a)}catch(r){return e.error(r),o.resolve(!1),void 0}i.then?i.then(function(e){n.lifecycleData=e,o.resolve(n.interpretResponse(e))},function(t){e.error(t),o.resolve(!1)}):(n.lifecycleData=i,o.resolve(n.interpretResponse(i)))}else o.resolve(!0)}).promise()}function s(t,a,o,i){return o.lifecycleData=null,e.defer(function(r){if(t==a())return r.resolve(!0),void 0;if(t&&t.canActivate){var s;try{s=n(t,"canActivate",i)}catch(l){return e.error(l),r.resolve(!1),void 0}s.then?s.then(function(e){o.lifecycleData=e,r.resolve(o.interpretResponse(e))},function(t){e.error(t),r.resolve(!1)}):(o.lifecycleData=s,r.resolve(o.interpretResponse(s)))}else r.resolve(!0)}).promise()}function l(n,l){var c,u=t.observable(null);l=a(l);var p=t.computed({read:function(){return u()},write:function(e){p.viaSetter=!0,p.activateItem(e)}});return p.__activator__=!0,p.settings=l,l.activator=p,p.isActivating=t.observable(!1),p.canDeactivateItem=function(e,t){return r(e,t,l)},p.deactivateItem=function(t,a){return e.defer(function(e){p.canDeactivateItem(t,a).then(function(n){n?o(t,a,l,e,u):(p.notifySubscribers(),e.resolve(!1))})}).promise()},p.canActivateItem=function(e,t){return s(e,u,l,t)},p.activateItem=function(t,a){var n=p.viaSetter;return p.viaSetter=!1,e.defer(function(r){if(p.isActivating())return r.resolve(!1),void 0;p.isActivating(!0);var s=u();return l.areSameItem(s,t,c,a)?(p.isActivating(!1),r.resolve(!0),void 0):(p.canDeactivateItem(s,l.closeOnDeactivate).then(function(f){f?p.canActivateItem(t,a).then(function(f){f?e.defer(function(e){o(s,l.closeOnDeactivate,l,e)}).promise().then(function(){t=l.beforeActivate(t,a),i(t,u,function(e){c=a,p.isActivating(!1),r.resolve(e)},a)}):(n&&p.notifySubscribers(),p.isActivating(!1),r.resolve(!1))}):(n&&p.notifySubscribers(),p.isActivating(!1),r.resolve(!1))}),void 0)}).promise()},p.canActivate=function(){var e;return n?(e=n,n=!1):e=p(),p.canActivateItem(e)},p.activate=function(){var e;return n?(e=n,n=!1):e=p(),p.activateItem(e)},p.canDeactivate=function(e){return p.canDeactivateItem(p(),e)},p.deactivate=function(e){return p.deactivateItem(p(),e)},p.includeIn=function(e){e.canActivate=function(){return p.canActivate()},e.activate=function(){return p.activate()},e.canDeactivate=function(e){return p.canDeactivate(e)},e.deactivate=function(e){return p.deactivate(e)}},l.includeIn?p.includeIn(l.includeIn):n&&p.activate(),p.forItems=function(t){l.closeOnDeactivate=!1,l.determineNextItemToActivate=function(e,t){var a=t-1;return-1==a&&e.length>1?e[1]:a>-1&&a<e.length-1?e[a]:null},l.beforeActivate=function(e){var a=p();if(e){var n=t.indexOf(e);-1==n?t.push(e):e=t()[n]}else e=l.determineNextItemToActivate(t,a?t.indexOf(a):0);return e},l.afterDeactivate=function(e,a){a&&t.remove(e)};var a=p.canDeactivate;p.canDeactivate=function(n){return n?e.defer(function(e){function a(){for(var t=0;t<i.length;t++)if(!i[t])return e.resolve(!1),void 0;e.resolve(!0)}for(var o=t(),i=[],r=0;r<o.length;r++)p.canDeactivateItem(o[r],n).then(function(e){i.push(e),i.length==o.length&&a()})}).promise():a()};var n=p.deactivate;return p.deactivate=function(a){return a?e.defer(function(e){function n(n){p.deactivateItem(n,a).then(function(){i++,t.remove(n),i==r&&e.resolve()})}for(var o=t(),i=0,r=o.length,s=0;r>s;s++)n(o[s])}).promise():n()},p},p}var c,u={closeOnDeactivate:!0,affirmations:["yes","ok","true"],interpretResponse:function(a){return e.isObject(a)&&(a=a.can||!1),e.isString(a)?-1!==t.utils.arrayIndexOf(this.affirmations,a.toLowerCase()):a},areSameItem:function(e,t){return e==t},beforeActivate:function(e){return e},afterDeactivate:function(e,t,a){t&&a&&a(null)}};return c={defaults:u,create:l,isActivator:function(e){return e&&e.__activator__}}});
define('durandal/composition',["durandal/system","durandal/viewLocator","durandal/binder","durandal/viewEngine","durandal/activator","jquery","knockout"],function(e,t,n,i,a,o,r){function s(e){for(var t=[],n={childElements:t,activeView:null},i=r.virtualElements.firstChild(e);i;)1==i.nodeType&&(t.push(i),i.getAttribute(g)&&(n.activeView=i)),i=r.virtualElements.nextSibling(i);return n.activeView||(n.activeView=t[0]),n}function l(){b--,0===b&&setTimeout(function(){for(var e=y.length;e--;)y[e]();y=[]},1)}function c(t,n,i){if(i)n();else if(t.activate&&t.model&&t.model.activate){var a;a=e.isArray(t.activationData)?t.model.activate.apply(t.model,t.activationData):t.model.activate(t.activationData),a&&a.then?a.then(n):a||void 0===a?n():l()}else n()}function u(){var t=this;t.activeView&&t.activeView.removeAttribute(g),t.child&&(t.model&&t.model.attached&&(t.composingNewView||t.alwaysTriggerAttach)&&t.model.attached(t.child,t.parent,t),t.attached&&t.attached(t.child,t.parent,t),t.child.setAttribute(g,!0),t.composingNewView&&t.model&&(t.model.compositionComplete&&h.current.complete(function(){t.model.compositionComplete(t.child,t.parent,t)}),t.model.detached&&r.utils.domNodeDisposal.addDisposeCallback(t.child,function(){t.model.detached(t.child,t.parent,t)})),t.compositionComplete&&h.current.complete(function(){t.compositionComplete(t.child,t.parent,t)})),l(),t.triggerAttach=e.noop}function d(t){if(e.isString(t.transition)){if(t.activeView){if(t.activeView==t.child)return!1;if(!t.child)return!0;if(t.skipTransitionOnSameViewId){var n=t.activeView.getAttribute("data-view"),i=t.child.getAttribute("data-view");return n!=i}}return!0}return!1}function p(e){for(var t=0,n=e.length,i=[];n>t;t++){var a=e[t].cloneNode(!0);i.push(a)}return i}function f(e){var t=p(e.parts),n=h.getParts(t),i=h.getParts(e.child);for(var a in n)o(i[a]).replaceWith(n[a])}function v(t){var n,i,a=r.virtualElements.childNodes(t);if(!e.isArray(a)){var o=[];for(n=0,i=a.length;i>n;n++)o[n]=a[n];a=o}for(n=1,i=a.length;i>n;n++)r.removeNode(a[n])}var h,m={},g="data-active-view",y=[],b=0,S="durandal-composition-data",w="data-part",x="["+w+"]",T=["model","view","transition","area","strategy","activationData"],C={complete:function(e){y.push(e)}};return h={convertTransitionToModuleId:function(e){return"transitions/"+e},defaultTransitionName:null,current:C,addBindingHandler:function(e,t,n){var i,a,o="composition-handler-"+e;t=t||r.bindingHandlers[e],n=n||function(){return void 0},a=r.bindingHandlers[e]={init:function(e,i,a,s,l){var c={trigger:r.observable(null)};return h.current.complete(function(){t.init&&t.init(e,i,a,s,l),t.update&&(r.utils.domData.set(e,o,t),c.trigger("trigger"))}),r.utils.domData.set(e,o,c),n(e,i,a,s,l)},update:function(e,t,n,i,a){var s=r.utils.domData.get(e,o);return s.update?s.update(e,t,n,i,a):(s.trigger(),void 0)}};for(i in t)"init"!==i&&"update"!==i&&(a[i]=t[i])},getParts:function(t){var n={};e.isArray(t)||(t=[t]);for(var i=0;i<t.length;i++){var a=t[i];if(a.getAttribute){var r=a.getAttribute(w);r&&(n[r]=a);for(var s=o(x,a).not(o("[data-bind] "+x,a)),l=0;l<s.length;l++){var c=s.get(l);n[c.getAttribute(w)]=c}}}return n},cloneNodes:p,finalize:function(t){if(t.transition=t.transition||this.defaultTransitionName,t.child||t.activeView)if(d(t)){var i=this.convertTransitionToModuleId(t.transition);e.acquire(i).then(function(e){t.transition=e,e(t).then(function(){if(t.cacheViews){if(t.activeView){var e=n.getBindingInstruction(t.activeView);void 0==e.cacheViews||e.cacheViews||r.removeNode(t.activeView)}}else t.child?v(t.parent):r.virtualElements.emptyNode(t.parent);t.triggerAttach()})}).fail(function(t){e.error("Failed to load transition ("+i+"). Details: "+t.message)})}else{if(t.child!=t.activeView){if(t.cacheViews&&t.activeView){var a=n.getBindingInstruction(t.activeView);void 0==a.cacheViews||a.cacheViews?o(t.activeView).hide():r.removeNode(t.activeView)}t.child?(t.cacheViews||v(t.parent),o(t.child).show()):t.cacheViews||r.virtualElements.emptyNode(t.parent)}t.triggerAttach()}else t.cacheViews||r.virtualElements.emptyNode(t.parent),t.triggerAttach()},bindAndShow:function(e,t,a){t.child=e,t.composingNewView=t.cacheViews?-1==r.utils.arrayIndexOf(t.viewElements,e):!0,c(t,function(){if(t.binding&&t.binding(t.child,t.parent,t),t.preserveContext&&t.bindingContext)t.composingNewView&&(t.parts&&f(t),o(e).hide(),r.virtualElements.prepend(t.parent,e),n.bindContext(t.bindingContext,e,t.model));else if(e){var a=t.model||m,s=r.dataFor(e);if(s!=a){if(!t.composingNewView)return o(e).remove(),i.createView(e.getAttribute("data-view")).then(function(e){h.bindAndShow(e,t,!0)}),void 0;t.parts&&f(t),o(e).hide(),r.virtualElements.prepend(t.parent,e),n.bind(a,e)}}h.finalize(t)},a)},defaultStrategy:function(e){return t.locateViewForObject(e.model,e.area,e.viewElements)},getSettings:function(t){var n,o=t(),s=r.utils.unwrapObservable(o)||{},l=a.isActivator(o);if(e.isString(s))return s=i.isViewUrl(s)?{view:s}:{model:s,activate:!0};if(n=e.getModuleId(s))return s={model:s,activate:!0};!l&&s.model&&(l=a.isActivator(s.model));for(var c in s)s[c]=-1!=r.utils.arrayIndexOf(T,c)?r.utils.unwrapObservable(s[c]):s[c];return l?s.activate=!1:void 0===s.activate&&(s.activate=!0),s},executeStrategy:function(e){e.strategy(e).then(function(t){h.bindAndShow(t,e)})},inject:function(n){return n.model?n.view?(t.locateView(n.view,n.area,n.viewElements).then(function(e){h.bindAndShow(e,n)}),void 0):(n.strategy||(n.strategy=this.defaultStrategy),e.isString(n.strategy)?e.acquire(n.strategy).then(function(e){n.strategy=e,h.executeStrategy(n)}).fail(function(t){e.error("Failed to load view strategy ("+n.strategy+"). Details: "+t.message)}):this.executeStrategy(n),void 0):(this.bindAndShow(null,n),void 0)},compose:function(n,i,a,o){b++,o||(i=h.getSettings(function(){return i},n));var r=s(n);i.activeView=r.activeView,i.parent=n,i.triggerAttach=u,i.bindingContext=a,i.cacheViews&&!i.viewElements&&(i.viewElements=r.childElements),i.model?e.isString(i.model)?e.acquire(i.model).then(function(t){i.model=e.resolveObject(t),h.inject(i)}).fail(function(t){e.error("Failed to load composed module ("+i.model+"). Details: "+t.message)}):h.inject(i):i.view?(i.area=i.area||"partial",i.preserveContext=!0,t.locateView(i.view,i.area,i.viewElements).then(function(e){h.bindAndShow(e,i)})):this.bindAndShow(null,i)}},r.bindingHandlers.compose={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,a,o){var s=h.getSettings(t,e);if(s.mode){var l=r.utils.domData.get(e,S);if(!l){var c=r.virtualElements.childNodes(e);l={},"inline"===s.mode?l.view=i.ensureSingleElement(c):"templated"===s.mode&&(l.parts=p(c)),r.virtualElements.emptyNode(e),r.utils.domData.set(e,S,l)}"inline"===s.mode?s.view=l.view.cloneNode(!0):"templated"===s.mode&&(s.parts=l.parts),s.preserveContext=!0}h.compose(e,s,o,!0)}},r.virtualElements.allowedBindings.compose=!0,h});
define('durandal/events',["durandal/system"],function(e){var t=/\s+/,n=function(){},i=function(e,t){this.owner=e,this.events=t};return i.prototype.then=function(e,t){return this.callback=e||this.callback,this.context=t||this.context,this.callback?(this.owner.on(this.events,this.callback,this.context),this):this},i.prototype.on=i.prototype.then,i.prototype.off=function(){return this.owner.off(this.events,this.callback,this.context),this},n.prototype.on=function(e,n,a){var o,r,s;if(n){for(o=this.callbacks||(this.callbacks={}),e=e.split(t);r=e.shift();)s=o[r]||(o[r]=[]),s.push(n,a);return this}return new i(this,e)},n.prototype.off=function(n,i,a){var o,r,s,l;if(!(r=this.callbacks))return this;if(!(n||i||a))return delete this.callbacks,this;for(n=n?n.split(t):e.keys(r);o=n.shift();)if((s=r[o])&&(i||a))for(l=s.length-2;l>=0;l-=2)i&&s[l]!==i||a&&s[l+1]!==a||s.splice(l,2);else delete r[o];return this},n.prototype.trigger=function(e){var n,i,a,o,r,s,l,c;if(!(i=this.callbacks))return this;for(c=[],e=e.split(t),o=1,r=arguments.length;r>o;o++)c[o-1]=arguments[o];for(;n=e.shift();){if((l=i.all)&&(l=l.slice()),(a=i[n])&&(a=a.slice()),a)for(o=0,r=a.length;r>o;o+=2)a[o].apply(a[o+1]||this,c);if(l)for(s=[n].concat(c),o=0,r=l.length;r>o;o+=2)l[o].apply(l[o+1]||this,s)}return this},n.prototype.proxy=function(e){var t=this;return function(n){t.trigger(e,n)}},n.includeIn=function(e){e.on=n.prototype.on,e.off=n.prototype.off,e.trigger=n.prototype.trigger,e.proxy=n.prototype.proxy},n});
define('durandal/app',["durandal/system","durandal/viewEngine","durandal/composition","durandal/events","jquery"],function(e,t,a,n,i){function o(){return e.defer(function(t){return 0==s.length?(t.resolve(),void 0):(e.acquire(s).then(function(a){for(var n=0;n<a.length;n++){var i=a[n];if(i.install){var o=l[n];e.isObject(o)||(o={}),i.install(o),e.log("Plugin:Installed "+s[n])}else e.log("Plugin:Loaded "+s[n])}t.resolve()}).fail(function(t){e.error("Failed to load plugin(s). Details: "+t.message)}),void 0)}).promise()}var r,s=[],l=[];return r={title:"Application",configurePlugins:function(t,a){var n=e.keys(t);a=a||"plugins/",-1===a.indexOf("/",a.length-1)&&(a+="/");for(var i=0;i<n.length;i++){var o=n[i];s.push(a+o),l.push(t[o])}},start:function(){return e.log("Application:Starting"),this.title&&(document.title=this.title),e.defer(function(t){i(function(){o().then(function(){t.resolve(),e.log("Application:Started")})})}).promise()},setRoot:function(n,i,o){var r,s={activate:!0,transition:i};r=!o||e.isString(o)?document.getElementById(o||"applicationHost"):o,e.isString(n)?t.isViewUrl(n)?s.view=n:s.model=n:s.model=n,a.compose(r,s)}},n.includeIn(r),r});
requirejs.config({baseUrl:"../App",paths:{text:"../Scripts/require/text",durandal:"../Scripts/durandal/js",plugins:"../Scripts/durandal/js/plugins",transitions:"../Scripts/durandal/js/transitions",lib:"lib"},shim:{"lib/prettify":{}}}),define("jquery",[],function(){return jQuery}),define("knockout",ko),define('main',["durandal/app","durandal/system","durandal/viewLocator"],function(e,t,n){t.debug(!0),e.title="Stashy, responsive components",e.configurePlugins({router:!0,dialog:!0,widget:{kinds:["expander"]}}),e.start().then(function(){n.useConvention(),e.setRoot("viewmodels/shell","entrance")})});
define('viewmodels/about/about',["durandal/app"],function(){return{activate:function(){ga("send","pageview")}}});
define('plugins/history',["durandal/system","jquery"],function(e,t){function n(e,t,n){if(n){var a=e.href.replace(/(javascript:|#).*$/,"");e.replace(a+"#"+t)}else e.hash="#"+t}var a=/^[#\/]|\s+$/g,i=/^\/+|\/+$/g,o=/msie [\w.]+/,r=/\/$/,s={interval:50,active:!1};return"undefined"!=typeof window&&(s.location=window.location,s.history=window.history),s.getHash=function(e){var t=(e||s).location.href.match(/#(.*)$/);return t?t[1]:""},s.getFragment=function(e,t){if(null==e)if(s._hasPushState||!s._wantsHashChange||t){e=s.location.pathname;var n=s.root.replace(r,"");e.indexOf(n)||(e=e.substr(n.length))}else e=s.getHash();return e.replace(a,"")},s.activate=function(n){s.active&&e.error("History has already been activated."),s.active=!0,s.options=e.extend({},{root:"/"},s.options,n),s.root=s.options.root,s._wantsHashChange=s.options.hashChange!==!1,s._wantsPushState=!!s.options.pushState,s._hasPushState=!!(s.options.pushState&&s.history&&s.history.pushState);var r=s.getFragment(),l=document.documentMode,c=o.exec(navigator.userAgent.toLowerCase())&&(!l||7>=l);s.root=("/"+s.root+"/").replace(i,"/"),c&&s._wantsHashChange&&(s.iframe=t('<iframe src="javascript:0" tabindex="-1" />').hide().appendTo("body")[0].contentWindow,s.navigate(r,!1)),s._hasPushState?t(window).on("popstate",s.checkUrl):s._wantsHashChange&&"onhashchange"in window&&!c?t(window).on("hashchange",s.checkUrl):s._wantsHashChange&&(s._checkUrlInterval=setInterval(s.checkUrl,s.interval)),s.fragment=r;var u=s.location,d=u.pathname.replace(/[^\/]$/,"$&/")===s.root;if(s._wantsHashChange&&s._wantsPushState){if(!s._hasPushState&&!d)return s.fragment=s.getFragment(null,!0),s.location.replace(s.root+s.location.search+"#"+s.fragment),!0;s._hasPushState&&d&&u.hash&&(this.fragment=s.getHash().replace(a,""),this.history.replaceState({},document.title,s.root+s.fragment+u.search))}return s.options.silent?void 0:s.loadUrl()},s.deactivate=function(){t(window).off("popstate",s.checkUrl).off("hashchange",s.checkUrl),clearInterval(s._checkUrlInterval),s.active=!1},s.checkUrl=function(){var e=s.getFragment();return e===s.fragment&&s.iframe&&(e=s.getFragment(s.getHash(s.iframe))),e===s.fragment?!1:(s.iframe&&s.navigate(e,!1),s.loadUrl(),void 0)},s.loadUrl=function(e){var t=s.fragment=s.getFragment(e);return s.options.routeHandler?s.options.routeHandler(t):!1},s.navigate=function(t,a){if(!s.active)return!1;if(void 0===a?a={trigger:!0}:e.isBoolean(a)&&(a={trigger:a}),t=s.getFragment(t||""),s.fragment!==t){s.fragment=t;var i=s.root+t;if(s._hasPushState)s.history[a.replace?"replaceState":"pushState"]({},document.title,i);else{if(!s._wantsHashChange)return s.location.assign(i);n(s.location,t,a.replace),s.iframe&&t!==s.getFragment(s.getHash(s.iframe))&&(a.replace||s.iframe.document.open().close(),n(s.iframe.location,t,a.replace))}return a.trigger?s.loadUrl(t):void 0}},s.navigateBack=function(){s.history.back()},s});
define('plugins/router',["durandal/system","durandal/app","durandal/activator","durandal/events","durandal/composition","plugins/history","knockout","jquery"],function(e,t,n,a,i,o,r,s){function l(e){return e=e.replace(m,"\\$&").replace(v,"(?:$1)?").replace(h,function(e,t){return t?e:"([^/]+)"}).replace(g,"(.*?)"),new RegExp("^"+e+"$")}function c(e){var t=e.indexOf(":"),n=t>0?t-1:e.length;return e.substring(0,n)}function u(e,t){return-1!==e.indexOf(t,e.length-t.length)}function d(e,t){if(!e||!t)return!1;if(e.length!=t.length)return!1;for(var n=0,a=e.length;a>n;n++)if(e[n]!=t[n])return!1;return!0}var f,p,v=/\((.*?)\)/g,h=/(\(\?)?:\w+/g,g=/\*\w+/g,m=/[\-{}\[\]+?.,\\\^$|#\s]/g,y=/\/$/,b=function(){function i(e){return e.router&&e.router.parent==R}function s(e){D&&D.config.isActive&&D.config.isActive(e)}function v(t,n){e.log("Navigation Complete",t,n);var a=e.getModuleId(_);a&&R.trigger("router:navigation:from:"+a),_=t,s(!1),D=n,s(!0);var o=e.getModuleId(_);o&&R.trigger("router:navigation:to:"+o),i(t)||R.updateDocumentTitle(t,n),p.explicitNavigation=!1,p.navigatingBack=!1,R.trigger("router:navigation:complete",t,n,R)}function h(t,n){e.log("Navigation Cancelled"),R.activeInstruction(D),D&&R.navigate(D.fragment,!1),N(!1),p.explicitNavigation=!1,p.navigatingBack=!1,R.trigger("router:navigation:cancelled",t,n,R)}function g(t){e.log("Navigation Redirecting"),N(!1),p.explicitNavigation=!1,p.navigatingBack=!1,R.navigate(t,{trigger:!0,replace:!0})}function m(t,n,a){p.navigatingBack=!p.explicitNavigation&&_!=a.fragment,R.trigger("router:route:activating",n,a,R),t.activateItem(n,a.params).then(function(e){if(e){var o=_;v(n,a),i(n)&&T({router:n.router,fragment:a.fragment,queryString:a.queryString}),o==n&&(R.attached(),R.compositionComplete())}else t.settings.lifecycleData&&t.settings.lifecycleData.redirect?g(t.settings.lifecycleData.redirect):h(n,a);f&&(f.resolve(),f=null)}).fail(function(t){e.error(t)})}function w(t,n,a){var i=R.guardRoute(n,a);i?i.then?i.then(function(i){i?e.isString(i)?g(i):m(t,n,a):h(n,a)}):e.isString(i)?g(i):m(t,n,a):h(n,a)}function S(e,t,n){R.guardRoute?w(e,t,n):m(e,t,n)}function x(e){return D&&D.config.moduleId==e.config.moduleId&&_&&(_.canReuseForRoute&&_.canReuseForRoute.apply(_,e.params)||!_.canReuseForRoute&&_.router&&_.router.loadUrl)}function k(){if(!N()){var t=P.shift();if(P=[],t){if(t.router){var a=t.fragment;return t.queryString&&(a+="?"+t.queryString),t.router.loadUrl(a),void 0}N(!0),R.activeInstruction(t),x(t)?S(n.create(),_,t):e.acquire(t.config.moduleId).then(function(n){var a=e.resolveObject(n);S(O,a,t)}).fail(function(n){e.error("Failed to load routed module ("+t.config.moduleId+"). Details: "+n.message)})}}}function T(e){P.unshift(e),k()}function C(e,t,n){for(var a=e.exec(t).slice(1),i=0;i<a.length;i++){var o=a[i];a[i]=o?decodeURIComponent(o):null}var r=R.parseQueryString(n);return r&&a.push(r),{params:a,queryParams:r}}function I(t){R.trigger("router:route:before-config",t,R),e.isRegExp(t)?t.routePattern=t.route:(t.title=t.title||R.convertRouteToTitle(t.route),t.moduleId=t.moduleId||R.convertRouteToModuleId(t.route),t.hash=t.hash||R.convertRouteToHash(t.route),t.routePattern=l(t.route)),t.isActive=t.isActive||r.observable(!1),R.trigger("router:route:after-config",t,R),R.routes.push(t),R.route(t.routePattern,function(e,n){var a=C(t.routePattern,e,n);T({fragment:e,queryString:n,config:t,params:a.params,queryParams:a.queryParams})})}function A(t){if(e.isArray(t.route))for(var n=t.isActive||r.observable(!1),a=0,i=t.route.length;i>a;a++){var o=e.extend({},t);o.route=t.route[a],o.isActive=n,a>0&&delete o.nav,I(o)}else I(t);return R}var _,D,P=[],N=r.observable(!1),O=n.create(),R={handlers:[],routes:[],navigationModel:r.observableArray([]),activeItem:O,isNavigating:r.computed(function(){var e=O(),t=N(),n=e&&e.router&&e.router!=R&&e.router.isNavigating()?!0:!1;return t||n}),activeInstruction:r.observable(null),__router__:!0};return a.includeIn(R),O.settings.areSameItem=function(e,t,n,a){return e==t?d(n,a):!1},R.parseQueryString=function(e){var t,n;if(!e)return null;if(n=e.split("&"),0==n.length)return null;t={};for(var a=0;a<n.length;a++){var i=n[a];if(""!==i){var o=i.split("=");t[o[0]]=o[1]&&decodeURIComponent(o[1].replace(/\+/g," "))}}return t},R.route=function(e,t){R.handlers.push({routePattern:e,callback:t})},R.loadUrl=function(t){var n=R.handlers,a=null,i=t,r=t.indexOf("?");if(-1!=r&&(i=t.substring(0,r),a=t.substr(r+1)),R.relativeToParentRouter){var s=this.parent.activeInstruction();i=s.params.join("/"),i&&"/"==i.charAt(0)&&(i=i.substr(1)),i||(i=""),i=i.replace("//","/").replace("//","/")}i=i.replace(y,"");for(var l=0;l<n.length;l++){var c=n[l];if(c.routePattern.test(i))return c.callback(i,a),!0}return e.log("Route Not Found"),R.trigger("router:route:not-found",t,R),D&&o.navigate(D.fragment,{trigger:!1,replace:!0}),p.explicitNavigation=!1,p.navigatingBack=!1,!1},R.updateDocumentTitle=function(e,n){n.config.title?document.title=t.title?n.config.title+" | "+t.title:n.config.title:t.title&&(document.title=t.title)},R.navigate=function(e,t){return e&&-1!=e.indexOf("://")?(window.location.href=e,!0):(p.explicitNavigation=!0,o.navigate(e,t))},R.navigateBack=function(){o.navigateBack()},R.attached=function(){R.trigger("router:navigation:attached",_,D,R)},R.compositionComplete=function(){N(!1),R.trigger("router:navigation:composition-complete",_,D,R),k()},R.convertRouteToHash=function(e){if(R.relativeToParentRouter){var t=R.parent.activeInstruction(),n=t.config.hash+"/"+e;return o._hasPushState&&(n="/"+n),n=n.replace("//","/").replace("//","/")}return o._hasPushState?e:"#"+e},R.convertRouteToModuleId=function(e){return c(e)},R.convertRouteToTitle=function(e){var t=c(e);return t.substring(0,1).toUpperCase()+t.substring(1)},R.map=function(t,n){if(e.isArray(t)){for(var a=0;a<t.length;a++)R.map(t[a]);return R}return e.isString(t)||e.isRegExp(t)?(n?e.isString(n)&&(n={moduleId:n}):n={},n.route=t):n=t,A(n)},R.buildNavigationModel=function(t){for(var n=[],a=R.routes,i=t||100,o=0;o<a.length;o++){var r=a[o];r.nav&&(e.isNumber(r.nav)||(r.nav=++i),n.push(r))}return n.sort(function(e,t){return e.nav-t.nav}),R.navigationModel(n),R},R.mapUnknownRoutes=function(t,n){var a="*catchall",i=l(a);return R.route(i,function(r,s){var l=C(i,r,s),c={fragment:r,queryString:s,config:{route:a,routePattern:i},params:l.params,queryParams:l.queryParams};if(t)if(e.isString(t))c.config.moduleId=t,n&&o.navigate(n,{trigger:!1,replace:!0});else if(e.isFunction(t)){var u=t(c);if(u&&u.then)return u.then(function(){R.trigger("router:route:before-config",c.config,R),R.trigger("router:route:after-config",c.config,R),T(c)}),void 0}else c.config=t,c.config.route=a,c.config.routePattern=i;else c.config.moduleId=r;R.trigger("router:route:before-config",c.config,R),R.trigger("router:route:after-config",c.config,R),T(c)}),R},R.reset=function(){return D=_=void 0,R.handlers=[],R.routes=[],R.off(),delete R.options,R},R.makeRelative=function(t){return e.isString(t)&&(t={moduleId:t,route:t}),t.moduleId&&!u(t.moduleId,"/")&&(t.moduleId+="/"),t.route&&!u(t.route,"/")&&(t.route+="/"),t.fromParent&&(R.relativeToParentRouter=!0),R.on("router:route:before-config").then(function(e){t.moduleId&&(e.moduleId=t.moduleId+e.moduleId),t.route&&(e.route=""===e.route?t.route.substring(0,t.route.length-1):t.route+e.route)}),R},R.createChildRouter=function(){var e=b();return e.parent=R,e},R};return p=b(),p.explicitNavigation=!1,p.navigatingBack=!1,p.targetIsThisWindow=function(e){var t=s(e.target).attr("target");return!t||t===window.name||"_self"===t||"top"===t&&window===window.top?!0:!1},p.activate=function(t){return e.defer(function(n){if(f=n,p.options=e.extend({routeHandler:p.loadUrl},p.options,t),o.activate(p.options),o._hasPushState)for(var a=p.routes,i=a.length;i--;){var r=a[i];r.hash=r.hash.replace("#","")}s(document).delegate("a","click",function(e){if(o._hasPushState){if(!e.altKey&&!e.ctrlKey&&!e.metaKey&&!e.shiftKey&&p.targetIsThisWindow(e)){var t=s(this).attr("href");t&&"#"!==t.charAt(0)&&!/^[a-z]+:/i.test(t)&&(p.explicitNavigation=!0,e.preventDefault(),o.navigate(t))}}else p.explicitNavigation=!0}),o.options.silent&&f&&(f.resolve(),f=null)}).promise()},p.deactivate=function(){o.deactivate()},p.install=function(){r.bindingHandlers.router={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,a,o){var s=r.utils.unwrapObservable(t())||{};if(s.__router__)s={model:s.activeItem(),attached:s.attached,compositionComplete:s.compositionComplete,activate:!1};else{var l=r.utils.unwrapObservable(s.router||a.router)||p;s.model=l.activeItem(),s.attached=l.attached,s.compositionComplete=l.compositionComplete,s.activate=!1}i.compose(e,s,o)}},r.virtualElements.allowedBindings.router=!0},p});
define('viewmodels/common/additional',["durandal/app","durandal/system","plugins/router"],function(e,t,n){var r=[{name:"OffCanvas",route:"/offcanvas"},{name:"Flyout",route:"/flyout"},{name:"Sticky",route:"/sticky"}],a=[{name:"FocalPoint",route:"/focalpoint"},{name:"ElasticVideo",route:"/elasticvideo"}],s=[{name:"Toggle",route:"/toggle"}],i=[{name:"Slider",route:"/slider"},{name:"Refresh",route:"/refresh"},{name:"Loader",route:"/loader"},{name:"ShowMeMore",route:"/showmemore"},{name:"ElasticText",route:"/elastictext"},{name:"List",route:"/list"},{name:"Table",route:"/table"},{name:"Notify",route:"/notify"}];return{layouts:r,navigation:s,media:a,misc:i,router:n}});
define('viewmodels/common/menu',["durandal/app","durandal/system","plugins/router"],function(e,t,n){var r={focalpoint:[{name:"Description",route:"/focalpoint/description"},{name:"HTML",route:"/focalpoint/html"},{name:"JavaScript",route:"/focalpoint/javascript"},{name:"Playground",route:"/focalpoint/playground"},{name:"Dependencies",route:"/focalpoint/dependencies"}],offcanvas:[{name:"Description",route:"/offcanvas/description"},{name:"HTML",route:"/offcanvas/html"},{name:"JavaScript",route:"/offcanvas/javascript"},{name:"Dependencies",route:"/offcanvas/dependencies"}],toggle:[{name:"Description",route:"/toggle/description"},{name:"HTML",route:"/toggle/html"},{name:"JavaScript",route:"/toggle/javascript"},{name:"Dependencies",route:"/toggle/dependencies"}],loader:[{name:"Description",route:"/loader/description"},{name:"HTML",route:"/loader/html"},{name:"JavaScript",route:"/loader/javascript"},{name:"Playground",route:"/loader/playground"},{name:"Dependencies",route:"/loader/dependencies"}],showmemore:[{name:"Description",route:"/showmemore/description"},{name:"HTML",route:"/showmemore/html"},{name:"JavaScript",route:"/showmemore/javascript"},{name:"Playground",route:"/showmemore/playground"},{name:"Dependencies",route:"/showmemore/dependencies"}],sticky:[{name:"Description",route:"/sticky/description"},{name:"HTML",route:"/sticky/html"},{name:"JavaScript",route:"/sticky/javascript"},{name:"Dependencies",route:"/sticky/dependencies"}],slider:[{name:"Description",route:"/slider/description"},{name:"HTML",route:"/slider/html"},{name:"JavaScript",route:"/slider/javascript"},{name:"Playground",route:"/slider/playground"},{name:"Dependencies",route:"/slider/dependencies"}],refresh:[{name:"Description",route:"/refresh/description"},{name:"HTML",route:"/refresh/html"},{name:"JavaScript",route:"/refresh/javascript"},{name:"Playground",route:"/refresh/playground"},{name:"Dependencies",route:"/refresh/dependencies"}],elasticvideo:[{name:"Description",route:"/elasticvideo/description"},{name:"JavaScript",route:"/elasticvideo/javascript"},{name:"Playground",route:"/elasticvideo/playground"},{name:"Dependencies",route:"/elasticvideo/dependencies"}],elastictext:[{name:"Description",route:"/elastictext/description"},{name:"JavaScript",route:"/elastictext/javascript"},{name:"Playground",route:"/elastictext/playground"},{name:"Dependencies",route:"/elastictext/dependencies"}],list:[{name:"Description",route:"/list/description"},{name:"HTML",route:"/list/html"},{name:"Playground",route:"/list/playground"},{name:"Dependencies",route:"/list/dependencies"}],notify:[{name:"Description",route:"/notify/description"},{name:"JavaScript",route:"/notify/javascript"},{name:"Playground",route:"/notify/playground"},{name:"Dependencies",route:"/notify/dependencies"}],home:[{name:"What is this?",route:"/home/whatisthis"},{name:"Components inside this library",route:"/home/components"},{name:"Standalone samples",route:"/home/samples"},{name:"Dependencies",route:"/home/dependencies"}]},a=null;return{binding:function(){this.menulinks=r[n.activeInstruction().config.settings.activemenu]},menulinks:a,router:n}});
define('viewmodels/elastictext/elastictext',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var n,a=ko.observable(),r=ko.observableArray(["","0.1","0.2","0.3","0.4","0.5","0.6","0.7","0.8","0.9","1","1.1","1.2","1.3","1.4","1.5","1.6","1.7","1.8","1.9","2.0"]),i=ko.observableArray(["","10px","12px","14px","16px","18px","20px","22px","24px","26px","28px","30px","32px","34px","36px","38px","40px","42px","44px","46px","48px","50px","52px","54px","56px","58px","60px"]),o=ko.observable({ratio:"",minsize:"",maxsize:""}),s=function(e){var t=""==e.ratio?null:parseFloat(e.ratio),n=""==e.minsize?null:e.minsize,a=""==e.maxsize?null:e.maxsize;Stashy.ElasticText("#samplep").on(t,n,a)};return{compositionComplete:function(){var e=this;n=Stashy.OffCanvas("#elastictext",{enableTouch:!0}),t.offcanvasLayout(n),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:a,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#elastictext #"+t.hash)),ga("send","pageview")},adaptHeader:function(){Stashy.ElasticText(".hero-unit h1").on(.6,"40px")},availableSizes:i,availableRatios:r,samplep:o,sampleOn:s}});
define('viewmodels/elasticvideo/elasticvideo',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var n,a=ko.observable();return{compositionComplete:function(){var e=this;n=Stashy.OffCanvas("#elasticvideo",{enableTouch:!0}),t.offcanvasLayout(n),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash),Stashy.ElasticVideo("iframe,object,embed").on()},activePage:a,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#elasticvideo #"+t.hash)),ga("send","pageview")}}});
define('viewmodels/flyout/flyout',["durandal/app","lib/pagelayout","lib/prettify","plugins/router"],function(e,t,n,a){var r,i=ko.observable(),o=ko.observable(!1);return{compositionComplete:function(){var e=this;r=Stashy.Flyout("#flyout",{slideType:"reveal",enableTouch:!0}),t.flyoutLayout(r),o(!0),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:i,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#flyout #"+t.hash)),ga("send","pageview")},fladdvisible:o,router:a}});
define('viewmodels/focalpoint/focalpoint',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var n,a=ko.observable(),r=ko.observableArray(["up-1","up-2","up-3","up-4","up-5","up-6","down-1","down-2","down-3","down-4","down-5","down-6","right-1","right-2","right-3","right-4","right-5","right-6","left-1","left-2","left-3","left-4","left-5","left-6"]),i=ko.observable({pointA:"",pointB:"",image:"#image-1"}),o=ko.observable({pointA:"",pointB:"",image:"#image-2"}),s=ko.observable({pointA:"",pointB:"",image:"#image-3"}),l=ko.observable({pointA:"",pointB:"",image:"#image-4",customimage:ko.observable("http://t2.gstatic.com/images?q=tbn:ANd9GcQh6lYnW0E-HTU0WtfJV0cl1UZVS2Ng0D03lu4lIHCOMdVS90SLeg")}),u=function(e){Stashy.FocalPoint(e.image).on(e.pointA,e.pointB)},c=function(e){Stashy.FocalPoint(e.image).off()},p=function(e){Stashy.FocalPoint(e.image).update(e.pointA,e.pointB)},d=function(){Stashy.FocalPoint("#sample-1").off(),Stashy.FocalPoint("#sample-2").off()};return{compositionComplete:function(){var e=this;n=Stashy.OffCanvas("#focalpoint",{enableTouch:!0}),t.offcanvasLayout(n),prettyPrint(),Stashy.FocalPoint("#sample-1").on("top-3","right-3"),Stashy.FocalPoint("#sample-2").on("top-2","right-2"),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:a,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#focalpoint #"+t.hash)),ga("send","pageview")},sample1:i,sample2:o,sample3:s,sample4:l,sampleOn:u,sampleOff:c,sampleUpdate:p,samplesOff:d,availablePoints:r}});
define('viewmodels/header',["plugins/router","lib/pagelayout"],function(e,t){var n;return{attached:function(){n=Stashy.Toggle(null,{fixed:!0}),t.togglelayout(n)},router:e,navigate:function(t,n){e.navigate(n.target.attributes.href.value)}}});
define('viewmodels/home/home',["durandal/app","lib/pagelayout","plugins/router"],function(e,t,n){var a,r=ko.observable();return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#home",{enableTouch:!0}),t.offcanvasLayout(a),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:r,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#home #"+t.hash)),ga("send","pageview")},router:n}});
define('viewmodels/list/list',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){for(var n,a=ko.observable(),i=ko.observableArray(),r=0;10>r;r++)i().push({imgsrc:"http://www.eurocosm.com/Application/images/Reproduction-Tiles/Victorian-tiles-Red-6-6-lg.jpg",imgalt:"Alternative Text",title:"List item title",description:"Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis sit amet tellus velit, ut semper neque"});return{compositionComplete:function(){var e=this;n=Stashy.OffCanvas("#list",{enableTouch:!0}),t.offcanvasLayout(n),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:a,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#list #"+t.hash)),ga("send","pageview")},sampleData:i}});
define('viewmodels/loader/loader',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var a,n=ko.observable(),o=ko.observable({target:"body",position:"",offset:"2em",color:"#000",insertiontype:""});return loaderOn=function(){Stashy.Loader(o().target).on(o().position,o().offset,o().color,o().insertiontype)},loaderOff=function(){Stashy.Loader().off()},{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#loader",{enableTouch:!0}),t.offcanvasLayout(a),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:n,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#loader #"+t.hash)),ga("send","pageview")},parameters:o,loaderOn:loaderOn,loaderOff:loaderOff}});
define('viewmodels/notfound/notfound',["durandal/app","lib/pagelayout"],function(e,t){var a;return{compositionComplete:function(){a=Stashy.OffCanvas("#notfound",{enableTouch:!0}),t.offcanvasLayout(a)},activate:function(){ga("send","pageview")}}});
define('viewmodels/notify/notify',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var n,a=ko.observable(),o={title:ko.observable(),titleSize:ko.observable(),contentType:ko.observable(),content:ko.observable(),style:ko.observable(),animDuration:ko.observable(),closeArea:ko.observable(),radius:ko.observable(!0),positionX:ko.observable(),positionY:ko.observable(),component:ko.observable("toast"),activeDuration:ko.observable()};return{compositionComplete:function(){var e=this;n=Stashy.OffCanvas("#notify",{enableTouch:!0}),t.offcanvasLayout(n),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:a,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#notify #"+t.hash)),ga("send","pageview")},options:o,showNotification:function(){try{"toast"==this.options.component()?Stashy.Notify({title:this.options.title(),content:this.options.content(),titleSize:parseInt(this.options.titleSize()),style:this.options.style(),contentType:this.options.contentType(),animDuration:this.options.animDuration(),closeArea:this.options.closeArea(),activeDuration:this.options.activeDuration()}).toast(this.options.positionX(),this.options.positionY(),this.options.radius()?!0:!1):"bar"==this.options.component()?Stashy.Notify({title:this.options.title(),content:this.options.content(),titleSize:parseInt(this.options.titleSize()),style:this.options.style(),contentType:this.options.contentType(),animDuration:this.options.animDuration(),closeArea:this.options.closeArea(),activeDuration:this.options.activeDuration()}).bar(this.options.positionY()):Stashy.Notify({title:this.options.title(),content:this.options.content(),titleSize:parseInt(this.options.titleSize()),style:this.options.style(),contentType:this.options.contentType(),animDuration:this.options.animDuration(),closeArea:this.options.closeArea(),activeDuration:this.options.activeDuration()}).panel(this.options.positionX())}catch(e){Stashy.Notify({title:"You have errors!!",titleSize:4,content:e.message,style:"error"}).toast("right","top",!0)}}}});
define('viewmodels/offcanvas/offcanvas',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var a,n=ko.observable();return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#offcanvas",{enableTouch:!0}),t.offcanvasLayout(a),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:n,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#offcanvas #"+t.hash)),ga("send","pageview")}}});
define('viewmodels/refresh/refresh',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var a,n=ko.observable();return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#refresh",{enableTouch:!1}),t.offcanvasLayout(a),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash),Stashy.Refresh("#playground-refresh",{breakpoint:80,onRelease:function(){var e=this;setTimeout(function(){var t=new Image;t.onload=function(){document.getElementById("random-image").src=this.src,e.slideUp(),Stashy.Utils.ScrollTo("#refresh #playground")},t.src="http://lorempixel.com/800/600/?"+(new Date).getTime()},1e3)}}).on()},activePage:n,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#refresh #"+t.hash)),ga("send","pageview")},scrollToBody:function(){Stashy.Utils.ScrollTo("body")},scrollToPlayground:function(){Stashy.Utils.ScrollTo("#playground")}}});
define('viewmodels/shell',["plugins/router"],function(e){return{attached:function(){setTimeout(function(){$("footer").css("display","block")},1e3)},scrollup:function(){Stashy.Utils.ScrollTo("body")},router:e,activate:function(){return e.map([{route:["","home/(:page)"],moduleId:"viewmodels/home/home",title:"Home",nav:!0,settings:{activemenu:"home"}},{route:"about",moduleId:"viewmodels/about/about",title:"About",nav:!0},{route:"offcanvas(/:page)",moduleId:"viewmodels/offcanvas/offcanvas",title:"OffCanvas",nav:!1,settings:{activemenu:"offcanvas"}},{route:"flyout(/:page)",moduleId:"viewmodels/flyout/flyout",title:"Flyout",nav:!1,settings:{activemenu:"flyout"}},{route:"toggle(/:page)",moduleId:"viewmodels/toggle/toggle",title:"Toggle",nav:!1,settings:{activemenu:"toggle"}},{route:"showmemore(/:page)",moduleId:"viewmodels/showmemore/showmemore",title:"ShowMeMore",nav:!1,settings:{activemenu:"showmemore"}},{route:"focalpoint(/:page)",moduleId:"viewmodels/focalpoint/focalpoint",title:"FocalPoint",nav:!1,settings:{activemenu:"focalpoint"}},{route:"loader(/:page)",moduleId:"viewmodels/loader/loader",title:"Loader",nav:!1,settings:{activemenu:"loader"}},{route:"slider(/:page)",moduleId:"viewmodels/slider/slider",title:"Slider",nav:!1,settings:{activemenu:"slider"}},{route:"sticky(/:page)",moduleId:"viewmodels/sticky/sticky",title:"Sticky",nav:!1,settings:{activemenu:"sticky"}},{route:"refresh(/:page)",moduleId:"viewmodels/refresh/refresh",title:"Refresh",nav:!1,settings:{activemenu:"refresh"}},{route:"elasticvideo(/:page)",moduleId:"viewmodels/elasticvideo/elasticvideo",title:"ElasticVideo",nav:!1,settings:{activemenu:"elasticvideo"}},{route:"elastictext(/:page)",moduleId:"viewmodels/elastictext/elastictext",title:"ElasticText",nav:!1,settings:{activemenu:"elastictext"}},{route:"list(/:page)",moduleId:"viewmodels/list/list",title:"List",nav:!1,settings:{activemenu:"list"}},{route:"table(/:page)",moduleId:"viewmodels/table/table",title:"Table",nav:!1,settings:{activemenu:"table"}},{route:"notify(/:page)",moduleId:"viewmodels/notify/notify",title:"Notify",nav:!1,settings:{activemenu:"notify"}},{route:"notfound",moduleId:"viewmodels/notfound/notfound",title:"Page not found",nav:!1}]),e.buildNavigationModel(),e.mapUnknownRoutes("viewmodels/notfound/notfound","notfound"),e.activate({pushState:!0})}}});
define('viewmodels/showmemore/showmemore',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){for(var a,o=ko.observable(),n=ko.observable(),i=ko.observable(),s=[],r=[],l={title:"Lorem ipsum",description:"Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus"},u=0;15>u;u++)s.push(l),r.push(l);var c=function(e,t){var a=-1!=t.target.attributes["data-target"].value.indexOf("sections-sample");Stashy.ShowMeMore(t.target.attributes["data-target"].value,{linkClass:"btn btn-inverse",linkText:"Show more ...",howMany:a?parseInt(n()):parseInt(i())}).on(),a?n(""):i("")},p=function(e,t){Stashy.ShowMeMore(t.target.attributes["data-target"].value).off()};return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#showmemore",{enableTouch:!0}),t.offcanvasLayout(a),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:o,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#showmemore #"+t.hash)),ga("send","pageview")},items1:s,items2:r,showmemoreOn:c,showmemoreOff:p,sectionhowmany:n,listhowmany:i}});
define('viewmodels/slider/slider',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var a,o=ko.observable();return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#slider",{enableTouch:!0}),t.offcanvasLayout(a),prettyPrint(),Stashy.Slider("#sl1",{enableTouch:!0,autoSlide:!0}).on(),Stashy.Slider("#sl2",{enableControls:!1,enableIndicators:!1,enableTouch:!0}).on(),Stashy.Slider("#sl3",{enableControls:!1,enableIndicators:!1,enableTouch:!0,autoSlide:!1}).on(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:o,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#slider #"+t.hash)),ga("send","pageview")}}});
define('viewmodels/sticky/sticky',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var a,o=ko.observable();return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#sticky",{enableTouch:!0}),t.offcanvasLayout(a),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:o,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#sticky #"+t.hash)),ga("send","pageview")}}});
define('viewmodels/table/table',["durandal/app","lib/pagelayout","lib/prettify","plugins/router"],function(e,t,a,o){var n,i=ko.observable(),s=ko.observable(!1);return{compositionComplete:function(){var e=this;n=Stashy.Flyout("#table",{slideType:"reveal",enableTouch:!0}),t.flyoutLayout(n),s(!0),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash),Stashy.Table("#laptops-styled",{idprefix:"sp1-",notSelectable:"not-selectable",menuClass:"btn btn-primary"}).on(),Stashy.Table("#laptops-default",{idprefix:"sp2-",notSelectable:"not-selectable"}).on(),$(".st-table-menu-container").first().css("top","-5em"),$("#laptops-styled thead tr th").css("text-align","left")},activePage:i,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#table #"+t.hash)),ga("send","pageview")},fladdvisible:s,router:o}});
define('viewmodels/toggle/toggle',["durandal/app","lib/pagelayout","lib/prettify"],function(e,t){var a,o=ko.observable();return{compositionComplete:function(){var e=this;a=Stashy.OffCanvas("#toggle",{enableTouch:!0}),t.offcanvasLayout(a),prettyPrint(),Stashy.Utils.ScrollTo("#"+e.hash)},activePage:o,activate:function(e){var t=this;void 0!=e&&(t.hash=e,Stashy.Utils.ScrollTo("#toggle #"+t.hash)),ga("send","pageview")}}});
define('text',{load: function(id){throw new Error("Dynamic load not allowed: " + id);}});
define('text!views/about/about.html',[],function () { return '<div id="about" class="container-fluid">\r\n    <div class="row-fluid">\r\n        <div class="span6">\r\n            <div class="about-content badge-strawberry">\r\n                <h1><i class="icon-user"></i>Who am I?</h1>\r\n                <p class="lead">My name is Yago and I am a Spanish developer and passionate about web design and programming</p>     \r\n            </div>                                                \r\n            <div class="about-content badge-strawberry" style="margin-top:-5px;">\r\n                <h1><i class="icon-eye-open"></i>What i like to do?</h1>\r\n                <p class="lead">I like to learn and explore new technologies and development environments . I also like to take a look at new and amazing projects to see how they evolve</p>                      \r\n            </div>                        \r\n        </div>\r\n        <div class="span6">\r\n            <div class="about-content badge-info">\r\n                <h1><i class="icon-comments"></i>How can you contact me?</h1>\r\n                <ul class="unstyled">\r\n                    <li><a href="https://github.com/yagopv" target="_blank"><i class="icon-github"></i>Github</a></li>\r\n                    <li><a href="https://twitter.com/yperezva" target="_blank"><i class="icon-twitter-sign"></i>Twitter</a></li>\r\n                    <li><a href="https://www.facebook.com/yago.perezvazquez" target="_blank"><i class="icon-facebook-sign"></i>Facebook</a>                        </li>           <li><a href="http://es.linkedin.com/pub/yago-p%C3%A9rez-v%C3%A1zquez/45/453/381" target="_blank"><i class="icon-linkedin-sign"></i>LinkedIn</a></li>\r\n                </ul>                                            \r\n            </div>        \r\n            <div class="about-content badge-info" style="margin-top:-5px;">\r\n                <h1><i class="icon-cloud"></i>Where I am?</h1>\r\n                <p class="lead">in a galaxy far, far away...</p>                \r\n            </div>                    \r\n        </div>            \r\n    </div>\r\n</div>';});

define('text!views/common/additional.html',[],function () { return '<h2>Layouts</h2>\r\n<div class="subnav">\r\n    <ul class="nav nav-pills nav-stacked" data-bind="foreach : layouts">\r\n        <li><a data-bind="attr : { href : $parent.router.convertRouteToHash(route) }, text : name"></a></li>\r\n    </ul>\r\n</div>\r\n\r\n<h2>Navigation</h2>\r\n<div class="subnav">\r\n    <ul class="nav nav-pills nav-stacked" data-bind="foreach : navigation">\r\n        <li><a data-bind="attr : { href : $parent.router.convertRouteToHash(route)}, text : name"></a></li>\r\n    </ul>\r\n</div>\r\n\r\n<h2>Media</h2>\r\n<div class="subnav">\r\n    <ul class="nav nav-pills nav-stacked" data-bind="foreach : media">\r\n        <li><a data-bind="attr : { href : $parent.router.convertRouteToHash(route)}, text : name"></a></li>\r\n    </ul>\r\n</div>\r\n\r\n<h2>Miscellaneous</h2>\r\n<div class="subnav">\r\n    <ul class="nav nav-pills nav-stacked" data-bind="foreach : misc">\r\n        <li><a data-bind="attr : { href : $parent.router.convertRouteToHash(route)}, text : name"></a></li>\r\n    </ul>\r\n</div>';});

define('text!views/common/menu.html',[],function () { return '<h2>Menu</h2>\r\n<div class="subnav">\r\n    <ul class="nav nav-pills nav-stacked" data-bind="foreach : menulinks">\r\n        <li><a data-bind="attr : { href : $parent.router.convertRouteToHash(route) }, text : name"></a></li>\r\n    </ul>\r\n</div>';});

define('text!views/elastictext/elastictext.html',[],function () { return '<div id="elastictext" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'elastictext/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/elastictext/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-pink h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-pink h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n\r\n<div>    \r\n    <div class="hero-unit badge-pink h-big-top-margin h-inverse-color">\r\n        <h1>ElasticText</h1>\r\n        <p class="lead h-big-top-margin">Adapt text to any screen size</p>\r\n        <a class="btn badge-pink-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n        <a class="btn badge-pink-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>This component provide the benefit to adapt font-size CSS property to different screen sizes.</p>\r\n        <p>The goal is not to be used for each and every one of the html tags of your page, you have CSS for that, but to adapt different parts such as titles or a subtitles on a page header.</p>\r\n        <p>Better than explaining it, we can start adapting the "ElasticText" header at the top of this page for example. So, start adapting it by pressing the following button:</p>\r\n        <p>\r\n            <a href="#" class="btn btn-large badge-pink" data-bind="click : adaptHeader">Adapt header text</a>\r\n        </p>\r\n        <p>Now, take a look to the header text and shrink your browser window to see the text changing its size.</p>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.ElasticText(selector)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>none</td>\r\n                    <td>CSS selector for selecting the different tags you want to adapt</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>    \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on(ratio,minfontsize,maxfontsize)</strong></td>\r\n                    <td>Start adapting text sizes</td>\r\n                </tr>\r\n                <tr>                                        \r\n                    <td colspan="2">\r\n                        <p><strong>ratio</strong>. Being the default 1, if you increment or decrement the value the text resize will be more aggressive or less. Play with it in the playground and see the behaviour</p>\r\n                        <p><strong>minfontsize</strong>. Minimum font-size of the resized text (for example "15px")</p>\r\n                        <p><strong>maxfontsize</strong>. Maximum font-size of the resized text (for example "30px")</p>\r\n                        <p>All this parameters are optional</p>\r\n                    </td>\r\n                </tr>\t                \r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Samples</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.ElasticText(".hero-unit h1").on(0.6,"40px");\r\nStashy.ElasticText("h2,h3").on(0.8,"20px","50px");\r\nStashy.ElasticText("p").on();\r\n</pre>\r\n    </section>\r\n    \r\n    <section id="playground">\r\n        <div class="page-header">                        \r\n           <h1>Playground</h1>\t\t\t\t\t\t\r\n        </div>\r\n        <div data-bind="with : samplep">\r\n            <form class="well form-inline h-top-margin">\r\n                <div class="alert badge-pink">\t\t\t\t\t\t\t\t\t\r\n                    <strong class="lead">Play!!</strong> with the different values to resize the paragraph\r\n                </div>\r\n                <select class="ratio input-small" placeholder="pointA" data-bind="value : ratio, options : $parent.availableRatios" style="height:30px;"></select>\r\n                <select class="minsize input-small" placeholder="pointB" data-bind="value : minsize, options : $parent.availableSizes" style="height:30px;"></select>\r\n                <select class="maxsize input-small" placeholder="pointB" data-bind="value : maxsize, options : $parent.availableSizes" style="height:30px;"></select>                \r\n                <a class="playground-on btn badge-pink" style="margin-top:0 !important" data-bind="click : $parent.sampleOn">on</a>\r\n            </form>                                 \r\n            <p id="samplep">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam mauris lorem, vulputate nec euismod quis, luctus vitae augue. Maecenas velit tellus, mollis id molestie eget, pulvinar eu neque. Etiam elementum, velit nec vulputate laoreet, nisi est pulvinar arcu, eu blandit leo lorem in mi. Mauris pharetra risus laoreet quam bibendum rutrum. Nulla facilisi. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; In hac habitasse platea dictumst. Phasellus ultricies neque erat, at tempus nunc lobortis quis. Fusce eu leo faucibus, fringilla ante vestibulum, eleifend ante. Suspendisse tincidunt tortor lorem. Nullam eleifend, nulla quis ultricies tincidunt, erat enim blandit odio, id porttitor velit magna eget metus.</p>\r\n        </div>        \r\n    </section>\t   \r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\r\n        <p class="lead">JS</p>\r\n        <p>There is a dependency with Stashy.Events because ElasticText is binding the resize of the window with the debouncedresize custom event defined there.</p>\r\n        <div class="h-top-margin">\r\n            <span class="badge badge-info">jQuery.js</span>\r\n            <span class="badge badge-pink">Stashy.Events.js</span>\r\n            <span class="badge badge-pink">Stashy.ElasticText.js</span>\r\n        </div>\t        \r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/elasticvideo/elasticvideo.html',[],function () { return '<div id="elasticvideo" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'elasticvideo/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/elasticvideo/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-violet h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-violet h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n\r\n<div>    \r\n    <div class="hero-unit badge-violet h-big-top-margin h-inverse-color">\r\n        <h1>ElasticVideo</h1>\r\n        <p class="lead h-big-top-margin">Adapt videos to any screen size</p>\r\n        <a class="btn badge-violet-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n        <a class="btn badge-violet-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>The new HTML5 &ltvideo&gt tag is very easy to make responsive. You only have to adjust its width to max-size : 100% and height : auto and you are done. But, did you ever try to do the same with iframes, objects, ... etc?. These type of tags are the ones we use to embed videos from external sites like Youtube, Vimeo, ... It´s difficult to style them.</p>\r\n        <p>This component try to help you making your videos responsive.</p>\r\n        <p>In the playground section you can check some samples.</p>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.ElasticVideo(selector)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>none</td>\r\n                    <td>CSS selector for your videos. Select the iframe, object or embed. In the Stashy.ElasticVideos.css stylesheet its included the proper styles for the &ltvideo&gt so you don´t need to call the constructor for this type of videos.</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>    \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on()</strong></td>\r\n                    <td>Start making your video responsive</td>\r\n                </tr>\r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.ElasticVideo("iframe,object,embed").on();</pre>\r\n    </section>\r\n    <section id="playground">\r\n        <div class="page-header">                        \r\n           <h1>Playground</h1>\t\t\t\t\t\t\r\n        </div>\r\n        \r\n      <div class="alert badge-violet">\r\n          <h2>Shrink your browser window and see the videos adapting its size</h2>\r\n          <p>You can try with any type of video vendors but is possible the component don´t work wth all of them. Youtube, DailyMotion, Vimeo and HTML5 videos are supported like you can check in these samples.</p>\r\n      </div>\r\n      \r\n\t  <h2>Youtube video with the new iframe code</h2>\r\n\t  <iframe width="853" height="480" src="http://www.youtube.com/embed/jhyANGHDDH8" frameborder="0" allowfullscreen></iframe>\r\n\r\n\t  <h2>Youtube video with the old object code</h2>\r\n<object width="560" height="315"><param name="movie" value="http://www.youtube.com/v/fnaojlfdUbs?hl=es_ES&amp;version=3"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/fnaojlfdUbs?hl=es_ES&amp;version=3" type="application/x-shockwave-flash" width="560" height="315" allowscriptaccess="always" allowfullscreen="true"></embed></object>\r\n\t\t\r\n\t  <h2>HTML5 using &ltvideo&gt tag</h2>\r\n\t  <p>Note that is no needed using Stashy.ElasticVideo.js with the video tag. Is enough with Stashy.ElasticVideo.css or even styling yourself using max-width:100% and height:auto;</p>\r\n\t   <video id=\'video\'\r\n\t\t  controls preload=\'none\' \r\n\t\t  poster="http://media.w3.org/2010/05/sintel/poster.png">\r\n\t\t  <source id=\'mp4\'\r\n\t\t\tsrc="http://media.w3.org/2010/05/sintel/trailer.mp4"\r\n\t\t\ttype=\'video/mp4\'>\r\n\t\t  <source id=\'webm\'\r\n\t\t\tsrc="http://media.w3.org/2010/05/sintel/trailer.webm"\r\n\t\t\ttype=\'video/webm\'>\r\n\t\t  <source id=\'ogv\'\r\n\t\t\tsrc="http://media.w3.org/2010/05/sintel/trailer.ogv"\r\n\t\t\ttype=\'video/ogg\'>\r\n\t\t  <p>Your user agent does not support the HTML5 Video element.</p>\r\n\t\t</video>\r\n\t\t\r\n\t  <h2>Vimeo video using iframe</h2>\r\n\t  <iframe src="http://player.vimeo.com/video/34656502" width="500" height="281" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>\r\n\t   <h2>DailyMotion  video using iframe</h2>\r\n\t   <iframe frameborder="0" width="480" height="270" src="http://www.dailymotion.com/embed/video/xcr9r8"></iframe>\r\n    </section>\t   \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\r\n        \r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-violet">Stashy.ElasticVideo.less</span>\r\n        \r\n        <p class="lead">JS</p>     \r\n        <div class="h-top-margin">\r\n            <span class="badge badge-info">jQuery.js</span>\r\n            <span class="badge badge-violet">Stashy.ElasticVideo.js</span>            \r\n        </div>\t        \r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/flyout/flyout.html',[],function () { return '<div id="flyout" class="st-flyout">\r\n    <div class="st-flyout-container">\r\n\t    <div class="st-flyout-menu" data-bind="compose : \'viewmodels/common/additional\',visible : fladdvisible"></div>\r\n\t    <div class="st-flyout-main">\t\t\r\n            <div id="menu" data-bind="compose : \'flyout/menu.html\'"></div>   \r\n            <div id="content" data-bind="compose : \'flyout/main.html\'"></div>\t\t\t\t\t\t                        \r\n        </div>                 \r\n    </div>\t\t\t\t\t\t\r\n</div>';});

define('text!views/flyout/main.html',[],function () { return '<div>\r\n    <div class="hero-unit badge-info h-inverse-color" style="margin-top:30px;">\r\n        <h1>Flyout</h1>\r\n        <p class="lead h-big-top-margin">Hide your navigation options or wathever you want in a nice left panel</p>\r\n        <a class="btn badge-info-light btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t<a class="btn badge-info-light btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>  \t\r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>\r\n        <p>This component renders a left side menu like the one we can see in a lot of mobile applications.</p>\r\n        <p>In this page we can see the behaviour of the layout clicking in the button at the top left corner close to the navigation options.</p>                   </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n<pre class="prettyprint linenums">\r\n&ltdiv class="st-flyout"&gt\r\n    &ltdiv class="st-flyout-container"&gt\r\n        &ltdiv class="st-flyout-menu"&gt\r\n            ... Menu content ...\r\n        &lt/div&gt\r\n        &ltdiv class="st-flyout-main"&gt\r\n            ... Content ...\r\n            &lta href="#" class="st-flyout-toggle"&gt&lt/a&gt\r\n            ... Place the toggle button wherever you want ...\r\n            ... More content ...\r\n        &lt/div&gt\r\n    &lt/div&gt\r\n&lt/div&gt</pre>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Flyout(selector, options)\r\n</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>.st-flyout</td>\r\n                    <td>CSS selector for your flyout</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>\r\n                    <td>You can pass the options to the flyout instance</td>\r\n                </tr>\t\t\t\t\t\t\t\t\t\t\r\n            </tbody>\r\n        </table>    \r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>slideType</strong></td>\r\n                    <td>string</td>\r\n                    <td>push</td>\r\n                    <td>You can choose between "push" or "reveal" in order to show the panel</td>\r\n                </tr> \r\n                <tr>\r\n                    <td><strong>closeOnClickOutside</strong></td>\r\n                    <td>bool</td>\r\n                    <td>true</td>\r\n                    <td>Close Flyout panel on click outside the toggle button (.st-flyout-toggle)</td>\r\n                </tr>                   \r\n                <tr>\r\n                    <td><strong>enableTouch</strong></td>\r\n                    <td>bool</td>\r\n                    <td>false</td>\r\n                    <td>If touch is enabled and the device is touch capable, then you can swipe to reveal the left menu. The touch behaviour is controlled by Hammer.js so you need to add a reference to jquery.hammer.js. Get it in the <a href="http://eightmedia.github.io/hammer.js/" target="_blank">project site</a> or in the <a href="https://github.com/yagopv/Stashy/tree/master/dist/js" target="_blank">dist folder</a> of the Stashy Github project</td>\r\n                </tr>                   \r\n            </tbody>\r\n        </table> \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>layout()</strong></td>\r\n                    <td>Starts flyout layout</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>open()</strong></td>\r\n                    <td>Reveal or push menu panel</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>close()</strong></td>\r\n                    <td>Close menu panel</td>\r\n                </tr>                                \r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar flyout = new Stashy.Flyout().layout();</pre>\t\t\r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-info">Stashy.Flyout.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> \r\n        <span class="badge badge-info">jquery.hammer.js (if touch enabled)</span> \r\n        <span class="badge badge-info">Stashy.Flyout.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\r\n</div>\t\t                    \r\n    ';});

define('text!views/flyout/menu.html',[],function () { return '<div class="subnav" style="margin-top:0 !important;">\r\n    <ul class="nav nav-pills">\r\n        <li><a href="#" class="st-flyout-toggle"><i class="icon-reorder icon-large"></i></a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/flyout/description\') }">Description</a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/flyout/html\') }">HTML</a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/flyout/javascript\') }">Javascript</a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/flyout/dependencies\') }">Dependencies</a></li>\r\n    </ul>\r\n</div>\t ';});

define('text!views/focalpoint/focalpoint.html',[],function () { return '<div id="focalpoint" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'focalpoint/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/focalpoint/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn btn-warning h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn btn-warning h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\t\r\n    <div class="hero-unit badge-orange h-big-top-margin h-inverse-color">\r\n        <h1>FocalPoint</h1>\r\n        <p class="lead h-big-top-margin">Beautiful responsive images</p>\r\n        <a class="btn btn-large badge-orange-dark h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n         <a class="btn btn-large badge-orange-dark h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                  \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>The FocalPoint component acts like a helper for displaying responsive images.</p>\r\n        <p>FocalPoint is inspired in this <a href="https://github.com/adamdbradley/focal-point" target="_blank">awesome project</a> on Github from <a href="https://twitter.com/adamdbradley" target="_blank">Adam Bradley</a>. You can read more about focal points <a href="http://www.cdnconnect.com/docs/focal-point-css/pure-html-css-responsive-high-resolution-images-solution" target="_blank">in the project docs</a> or <a href="http://designshack.net/articles/css/focal-point-intelligent-cropping-of-responsive-images/" target="_blank">in this article</a>. I think reading these links give an overview of what this technique is for.</p>\r\n        <p>In general, when we use this component, we divide the image in a virtual grid of 12x12 as shown below.</p>\r\n        <img id="sample-1" class="h-top-margin" src="http://www.finditshareit.com/wp-content/uploads/2012/12/focalpoint-5.jpg" alt="the focal point grid"/>\r\n        <p>In the picture, you can see that the image is focusing 3-cell up and 3 to the right. The focal point emphasize the man\'s face when the image is displayed on small screen sizes and as we increase the size of the image will be displayed complete.</p>\t\t\t\t\t\t\t\r\n        <p>When using this component, you have to specify the offset defining the focal point on the image always starting from the middle of the grid. For example, you can set the offset using <span class="badge badge-orange">top-6</span> and <span class="badge badge-orange">right-6</span> CSS classes in order to crop the image to the top-right corner. Same using <span class="badge badge-orange">down-6</span>  <span class="badge badge-orange">left-6</span> for the bottom-left corner. It\'s really easy to use.</p>\r\n        <p>The following image represents how to set the focal point to <span class="badge badge-orange">top-2</span> <span class="badge badge-orange">right-2</span> focusing in the important part of it ;)</p>\r\n        <img id="sample-2" class="h-top-margin" src="http://designshack.net/wp-content/uploads/focalpoint-8.jpg" alt="focal point working"/>\r\n        <p>Now, resize your browser window to see how the image above set it\'s focus at the specified point on smaller screen sizes.</p>\r\n        <p>And now, being in a smaller screen size under 768px, click the following button to set the focal point off and see the difference.</p>\r\n        <a id="samples-off" class="btn btn-warning" href="#" data-bind="click : samplesOff">Set focal points on images above to off</a>\r\n        <p>You can play with this component in the <a href="#playground">playground</a> below using the provided images or your own ones.</p>\r\n        <div class="alert alert-block alert-warning h-top-margin">\r\n           <h2 class="reset-margin">Hey !!</h2>\r\n            <p class="reset-margin">This is not server-side technology!! ... so the image sizes on page load will be the same as the original ones. If your problem is bandwidth and serving responsive images in differents sizes then this is not your component. The only way for doing that is using server side technology, multiple images with a plugin or any specialized cloud service.</p>\r\n            <br/>\r\n            <p class="reset-margin">Said that, you can use this component in a lot of places for displaying your images pretty, because i\'m sure you are not using several different sized images in all your sites ;)</p>\r\n        </div>                                                                        \t\t\t\t\t\t\t\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                                             </div>\r\n        <p>Pretty easy ... you are going to need the image tag (With id or class if you want to select it using css selectors) and it\'s done.</p>                            \r\n<pre class="prettyprint linenums">\r\n&ltimg id="optional id" class="optional class" src="yourImage" alt="your image description" /&gt\r\n</pre>\t\r\n    </section>\r\n\r\n   <section id="javascript">\r\n    <div class="page-header">                        \r\n       <h1>Javascript</h1>\t\t\t\t\t\t\r\n    </div>\t\t\t\r\n    <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.FocalPoint(selector)</pre>\t\t\t\t\t\t\t\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>CSS selector. Select images for being cropped on smaller screen sizes. If you leave the selector blank, by default FocalPoint is going to take all &ltimg /&gt tags in the page.</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>    \t\t\t\t\t\r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on(pointA,pointB)</strong></td>\r\n                    <td>Initializes FocalPoint. Using the selector passed in the constructor, this method will crop all the images matching it with the points specified in the parameters</td>\r\n                </tr>\r\n                <tr>                                        \r\n                    <td colspan="2">\r\n                        <p><em>pointA</em> and <em>pointB</em> may be set up with these class names:</p>\t\t\t\t\t\t\t\t\t\t\t\r\n                        <p>&nbsp;&nbsp;<strong>"up-1" to "up-6"</strong>. Up offset from center virtual grid</p>\r\n                        <p>&nbsp;&nbsp;<strong>"down-1" to "down-6"</strong>. Down offset from center virtual grid</p>\r\n                        <p>&nbsp;&nbsp;<strong>"left-1" to "left-6"</strong>. Left offset from center virtual grid</p>\r\n                        <p>&nbsp;&nbsp;<strong>"right-1" to "right-6"</strong>. Right offset from center virtual grid</p>\r\n                    </td>\r\n                </tr>\t\t\t\t\t\t\t\t\t\r\n                <tr>\r\n                    <td><strong>update(pointA,pointB)</strong></td>\r\n                    <td>Update FocalPoint images with new points specified in the parameters</td>\r\n                </tr>\r\n                <tr>                                        \r\n                    <td colspan="2">\r\n                        <p><em>pointA</em> and <em>pointB</em> may be setted up with these values:</p>\t\t\t\t\t\t\t\t\t\t\t\r\n                        <p>&nbsp;&nbsp;<strong>"up-1" to "up-6"</strong>. Up offset from center virtual grid</p>\r\n                        <p>&nbsp;&nbsp;<strong>"down-1" to "down-6"</strong>. Down offset from center virtual grid</p>\r\n                        <p>&nbsp;&nbsp;<strong>"left-1" to "left-6"</strong>. Left offset from center virtual grid</p>\r\n                        <p>&nbsp;&nbsp;<strong>"right-1" to "right-6"</strong>. Right offset from center virtual grid</p>\r\n                    </td>\r\n                </tr>\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\r\n                <tr>\r\n                    <td><strong>off()</strong></td>\r\n                    <td>Restarts image to the original state.</td>\r\n                </tr>\t\t\t\t\t\t\t\t\t\r\n            </tbody>\r\n        </table> \t\r\n        <div class="alert alert-block alert-warning h-top-margin">\r\n           <h2 class="reset-margin">Hey !!</h2>\r\n            <p class="reset-margin">If you don\'t set the points, then the image will be cropped using the center point of the grid.</p>\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\r\n        </div>\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar fp = Stashy.FocalPoint("selector");\r\nfp.on("up-3","right-3");\r\nfp.update("down-3","left-3");\r\nfp.off();</pre>\r\n    </section>\r\n    \r\n    <section id="playground">\r\n        <div class="page-header">                        \r\n           <h1>Playground</h1>\t\t\t\t\t\t\r\n        </div>\r\n        <p>Select different focal points for the images</p>\t\t\t\t\t\t\t\r\n        <div data-bind="with : sample1">\r\n            <form class="well form-inline h-top-margin">\r\n                <div class="alert alert-warning">\t\t\t\t\t\t\t\t\t\r\n                    <strong class="lead">Play!!</strong> with this dangerous tiger by trying to focus his head\r\n                </div>\r\n                <select class="pointA input-small" placeholder="pointA" data-bind="value : pointA, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <select class="pointB input-small" placeholder="pointB" data-bind="value : pointB, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <a class="playground-on btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleOn">on</a>\r\n                <a class="playground-update btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleUpdate">update</a>\r\n                <a  class="playground-off btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleOff">off</a>\r\n            </form>                                 \r\n            <img id="image-1" src="http://3.bp.blogspot.com/-7Ax-QneMofY/TwwhpyyNazI/AAAAAAAAAdA/Ms_lJ9kkeKo/s1600/Tiger.jpg" alt="image-1" />\r\n        </div>\r\n        \r\n        <div data-bind="with : sample2">\r\n            <form class="well form-inline h-top-margin">\t\t\t\t\t\t\t\t\r\n                <div class="alert alert-warning">\t\t\t\t\t\t\t\t\t\r\n                    <strong class="lead">Play!!</strong> with this lot of people. When setting the focal point and resizing, you will see a couple of them dissapear\r\n                </div>\t\t\t\t\t\t\t\t\r\n                <select class="pointA input-small" placeholder="pointA" data-bind="value : pointA, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <select class="pointB input-small" placeholder="pointB" data-bind="value : pointB, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <a class="playground-on btn btn-warning" style="margin-top:0 !important" data-bind="click : $root.sampleOn">on</a>\r\n                <a class="playground-update btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleUpdate">update</a>\r\n                <a  class="playground-off btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleOff">off</a>\r\n            </form>                                           \r\n            <img id="image-2" src="http://www.against-the-grain.com/wp-content/uploads/2013/03/people-crowds-webpages.scu_.edu_.jpg" alt="image" />\r\n        </div>\r\n        \r\n        <div data-bind="with : sample3">\t\t\t\t\t\t\t\t\t\t\t\t\t\t\r\n            <form class="well form-inline h-top-margin">\t\t\t\t\t\t\t\t\r\n                <div class="alert alert-warning">\t\t\t\t\t\t\t\t\t\r\n                    <strong class="lead">Portrait!!</strong> images will be detected and different set of CSS classes will be applied\r\n                </div>\t                \r\n                <select class="pointA input-small" placeholder="pointA" data-bind="value : pointA, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <select class="pointB input-small" placeholder="pointB" data-bind="value : pointB, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <a class="playground-on btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleOn">on</a>\r\n                <a class="playground-update btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleUpdate">update</a>\r\n                <a  class="playground-off btn btn-warning" style="margin-top:0 !important" data-bind="click : $parent.sampleOff">off</a>\r\n            </form>\r\n            <img id="image-3" src="http://hulubei.net/tudor/photography/photos/E/i/Eiffel-Tower-2-1000x1500.jpg" alt="image" />\r\n        </div>\r\n        \r\n        <div data-bind="with : sample4">\r\n            <form class="well form-inline h-top-margin">\t\t\t\t\t\t\t\t\r\n                <div class="alert alert-warning">\r\n                    <strong class="lead">Custom!!</strong> image. Enter any url representing an image and play with it\r\n                </div>\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t                \r\n                <input type="text" class="custom-image-input input-xlarge h-top-margin" placeholder="enter your custom image url" data-bind="value : customimage"/>                \r\n                <select class="pointA input-small h-top-margin" placeholder="pointA" data-bind="value : pointA, options : $parent.availablePoints" style="height:30px;"></select>\r\n                <select class="pointB input-small h-top-margin" placeholder="pointB" data-bind="value : pointB, options : $parent.availablePoints"></select>\r\n                <a class="playground-on btn btn-warning h-top-margin" style="margin-top:30px !important;" data-bind="click : $parent.sampleOn">on</a>\r\n                <a class="playground-update btn btn-warning h-top-margin" style="margin-top:30px !important;" data-bind="click : $parent.sampleUpdate">update</a>\r\n                <a  class="playground-off btn btn-warning h-top-margin" style="margin-top:30px !important;" data-bind="click : $parent.sampleOff" >off</a>\r\n            </form>                                          \r\n            <img id="image-4" class="custom-image-img" data-bind="attr : {src : customimage }" alt="custom image" />            \r\n        </div>\t\t\t\t\t\t\t\r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-warning">Stashy.FocalPoint.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> <span class="badge badge-warning">Stashy.FocalPoint.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/header.html',[],function () { return '<div id="menu" class="st-toggle"> \r\n    <div class="st-toggle-brand">\r\n        <a href="#" data-bind="click : navigate ,attr: { href: router.convertRouteToHash(\'/\' + router.navigationModel()[0].route) }, text : \'Stashy\'">\r\n            <i class="icon-home"></i>\r\n        </a>\r\n    </div>                \r\n    <a href="#" class="st-toggle-menu-link">\r\n        <i class="icon-reorder icon-large"></i>\r\n    </a>\r\n    <nav class="st-toggle-navigation">\r\n        <ul data-bind="foreach: router.navigationModel()">\r\n            <li>\r\n                <a data-bind="click : $parent.navigate, attr: { href: $parent.router.convertRouteToHash(\'/\' + route) }, text: title"></a>\r\n            </li>            \r\n        </ul>\r\n    </nav>\r\n</div>';});

define('text!views/home/home.html',[],function () { return '<div id="home" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'home/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/home/main.html',[],function () { return '<div id="offcanvas-navigation" >\r\n    <a href="#" class="showmenubutton btn btn-primary h-add-padding"><i class="icon-reorder icon-large"></i></a>\r\n    <a href="#" class="showadditionalbutton btn btn-primary h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>  \r\n</div>\r\n\r\n<div class="hero-unit badge-primary h-big-top-margin h-inverse-color">\r\n    <h1>Stashy</h1>\r\n    <p class="lead h-big-top-margin">A collection of components for doing responsive things</p>\t\t\t\t\t\t\t\r\n    <a class="btn btn-primary btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\r\n    <a class="btn btn-primary btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>\r\n</div> \r\n\r\n<section id="whatisthis">\r\n    <div class="page-header">\r\n        <h1>What is this ?</h1>\r\n    </div>                        \r\n    <p>Stashy is a library aiming to help you with your responsive designs. Inside, you\'ll find layouts and utilities that might just be useful to you.</p>\r\n    <p>Components in this library are mainly focussed on layouts, so you\'ll have to style them properly yourself for the look and feel you are after. For example, this site uses the awesome <a href="http://getbootstrap.com" target="_blank">Bootstrap</a> plus some personal CSS. </p>\r\n    <p>All the pages on this site were built using Stashy, so you can check what you can do with these components by going around the docs. </p>\r\n</section>   \r\n\r\n<section id="components">\r\n    <div class="page-header">\r\n        <h1>Components inside this library</h1>                        \r\n    </div>\r\n    <div class="component">\r\n        <h3>OffCanvas</h3>\r\n        <p>Offcanvas layouts have the ability to adapt to any screen size by hiding / showing panels when reaching certain break points.</p>\r\n        <p>This page, and most in these docs are offcanvas layouts, so resize your browser to see them in action. In small sizes, click the &nbsp; <i class="icon-reorder"></i> &nbsp;  buttons for showing side  panels.</p>\r\n        <a class="btn btn-large btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/offcanvas\')}" >Go to OffCanvas docs</a>                            \r\n    </div>\r\n    <div class="component">\r\n        <h3>Flyout</h3>\r\n        <p>This component allows you to create a left menu showing and hiding its content on user interactions.</p>\r\n        <p>You can see this component in web and mobile applications like the Facebook and Google ones.</p>                            \r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/flyout\')}">Go to Flyout docs</a>                                                \r\n    </div>\r\n    <div class="component">\r\n        <h3>Sticky</h3>\r\n        <p>Stick your footer always at bottom.</p>        \r\n        <a class="btn btn-large btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/sticky\')}">Go to Sticky docs</a>                                                \r\n    </div>\r\n    <div class="component">\r\n        <h3>Focal Point</h3>\r\n        <p>Cropping images at client side inspired in the focal point technique.</p>\r\n        <a class="btn btn-large  btn-primary"  href="#" data-bind="attr : { href : router.convertRouteToHash(\'/focalpoint\')}">Go to FocalPoint docs</a>                                                                 \r\n    </div>\t        \r\n    <div class="component">\r\n        <h3>Toogle Menu</h3>\r\n        <p>Top menu showing all its links in large screens and hiding them on smaller ones for showing a button to slide the  menu down.</p>\r\n        <p>Menu at the top of this page is a sample of Toggle using Stashy. Resize your browser window to see it in action.</p>\r\n        <a class="btn btn-large  btn-primary"  href="#" data-bind="attr : { href : router.convertRouteToHash(\'/toggle\')}">Go to Toggle docs</a>                                                                 \r\n    </div>\r\n    <div class="component">\r\n        <h3>Slider</h3>\r\n        <p>This componet allow to create touch enabled sliding layouts or carousels</p>\r\n        <a class="btn btn-large  btn-primary h-top-margin" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/slider\')}">Go to Slider docs</a>\r\n    </div>    \r\n    <div class="component">\r\n        <h3>ShowMeMore</h3>\r\n        <p>This utility allow hiding list items and showing a "Show more" button.</p>\r\n        <a class="btn btn-large  btn-primary h-top-margin" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/showmemore\')}">Go to ShowMeMore docs</a>\r\n    </div>\r\n    <div class="component">\r\n        <h3>Loader</h3>\r\n        <p>Nice loader for your responsive designs inspired in the Windows 8 / Windows Phone one.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/loader\')}">Go to Loader docs</a>                                                                 \r\n    </div>\t\r\n    <div class="component">\r\n        <h3>Refresh</h3>\r\n        <p>Touch enabled pull to refresh control.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/refresh\')}">Go to Refresh docs</a>                                                                 \r\n    </div>\t\t\r\n    <div class="component">\r\n        <h3>ElasticText</h3>\r\n        <p>Adapt text to any screen size.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/elastictext\')}">Go to ElasticText docs</a>                                                                 \r\n    </div>\t\t\r\n    <div class="component">\r\n        <h3>ElasticVideo</h3>\r\n        <p>Adapt videos to any screen size.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/elasticvideo\')}">Go to ElasticVideo docs</a>                                                                 \r\n    </div>\t\r\n    <div class="component">\r\n        <h3>List</h3>\r\n        <p>Beautiful responsive List for any device.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/list\')}">Go to List docs</a>\r\n    </div>  \r\n    <div class="component">\r\n        <h3>Table</h3>\r\n        <p>Responsive tables with priority columns.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/table\')}">Go to Table docs</a>\r\n    </div>     \r\n    <div class="component">\r\n        <h3>Notify</h3>\r\n        <p>Notifications using toasts, panels and bars.</p>\r\n        <a class="btn btn-large  btn-primary" href="#" data-bind="attr : { href : router.convertRouteToHash(\'/notify\')}">Go to Notify docs</a>\r\n    </div>      \r\n</section>\r\n\r\n<section id="samples">\r\n    <div class="page-header">                        \r\n       <h1>Standalone samples</h1>\t\t\t\t\t\t\r\n    </div>\t\t\t\t\t\r\n    <p>You can check each component across the docs, but it´s easy to get started by simply checking the standalone samples in the Github Project.</p>\r\n    <a class="btn btn-large  btn-primary" target="_blank" href="https://github.com/yagopv/Stashy/tree/master/tests/components">Check it!!</a>                                               \r\n</section>                               \r\n\r\n<section id="dependencies">\r\n    <div class="page-header">                        \r\n       <h1>Dependencies</h1>\t\t\t\t\t\t\r\n    </div>\t\t\t\t\t\r\n    <p>For using the whole library, you need to add the Stashy files you´ll find in the <a href="https://github.com/yagopv/Stashy/tree/master/dist" target="_blank">dist folder</a> of the Github project.</p>\r\n    <p>If you want to use specific components, you need to include only the CSS and JavaScript required for those components so you have to build the specific less files and add the required JavaScript ones.</p>\r\n    <p>You´ll find this dependencies in the component doc pages.</p>\r\n</section>                               ';});

define('text!views/list/list.html',[],function () { return '<div id="list" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'list/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/list/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-list h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-list h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>    \r\n    <div class="hero-unit badge-list h-big-top-margin">\r\n        <h1>List</h1>\r\n        <p class="lead h-big-top-margin">Render beautiful responsive Lists</p>\r\n        <a class="btn badge-list-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\r\n        <a class="btn badge-list-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>          \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>This component can render responsive Lists ready for adapt its container width.</p>\r\n        <p>You can render a full width list or add a little padding and rounded corners to it.</p>\r\n        <p>You can choose as well to render the List in two columns for higher widths.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n<pre class="prettyprint linenums">\r\n&ltul class="st-list [st-inset] [st-double]"&gt\r\n    &ltli&gt\r\n        &lta href="#"&gt\r\n            &ltdiv class="st-list-img"&gt\r\n                &ltimg src="imageSrc" alt="imageText" /&gt\r\n            &lt/div&gt\r\n            &ltdiv class="st-list-content"&gt\r\n                &lth4 class="st-list-title"&gtTitle&lt/h4&gt\r\n                &ltp class="st-list-summary"&gtDescription (Hidden on mobile)&lt/p&gt\r\n            &lt/div&gt\r\n        &lt/a&gt\r\n    &lt/li&gt\r\n    ... More list items ...\r\n&lt/ul&gt\r\n</pre>        \r\n    </section>\r\n    \r\n   <section id="playground">\r\n         <div class="page-header">\r\n           <h1>Playground</h1>\r\n        </div>\r\n        <p>Lists will fill the width of the parent container.</p>\r\n        <p>If you add the <span class="badge badge-list">st-inset</span> class to the List, a little padding and rounded corners will be included.</p>\r\n        <p>When using <span class="badge badge-list">st-double class</span>,  a two-columns List will be rendered at higher widths.</p>        \r\n        <br/>\r\n        <h3>Full width List. Two columns in higher widths.</h3>\r\n        <br/>\r\n        <ul class="st-list st-double" data-bind="foreach : sampleData">\r\n        \t<li>\r\n    \t\t\t<a href="#">\r\n    \t\t\t\t<div class="st-list-img">\r\n    \t\t\t\t\t<img data-bind="attr : {src : imgsrc, alt : imgalt}" />\r\n    \t\t\t\t</div>\r\n    \t\t\t\t<div class="st-list-content">\r\n\t\t    \t\t\t<h3 class="st-list-title reset" data-bind="text : title"></h3>\r\n\t\t\t\t    \t<p class="st-list-summary reset" data-bind="text : description"></p>\r\n    \t    \t\t</div>\r\n\t    \t\t</a>\r\n    \t\t</li>\r\n        </ul>\r\n        <br/>\r\n        <h3 style="clear:left;padding-top:3%;">Inset width List. Two columns in higher widths.</h3>\r\n        <br/>\r\n        <ul class="st-list st-double st-inset" data-bind="foreach : sampleData">\r\n            <li>\r\n    \t\t\t<a href="#">\r\n    \t\t\t\t<div class="st-list-img">\r\n    \t\t\t\t\t<img data-bind="attr : {src : imgsrc, alt : imgalt}" />\r\n    \t\t\t\t</div>\r\n    \t\t\t\t<div class="st-list-content">\r\n\t\t    \t\t\t<h3 class="st-list-title reset" data-bind="text : title"></h3>\r\n\t\t\t\t    \t<p class="st-list-summary reset" data-bind="text : description"></p>\r\n    \t    \t\t</div>\r\n\t    \t\t</a>\r\n    \t\t</li>\r\n        </ul>   \r\n        <br/>           \r\n        <h3>One column, full width List.</h3>        \r\n        <br/>\r\n        <ul class="st-list" data-bind="foreach : sampleData">\r\n            <li>\r\n        \t\t<a href="#">\r\n    \t\t\t\t<div class="st-list-img">\r\n    \t\t\t\t\t<img data-bind="attr : {src : imgsrc, alt : imgalt}" />\r\n    \t\t\t\t</div>\r\n    \t\t\t\t<div class="st-list-content">\r\n\t\t    \t\t\t<h3 class="st-list-title reset" data-bind="text : title"></h3>\r\n\t\t\t\t    \t<p class="st-list-summary reset" data-bind="text : description"></p>\r\n    \t    \t\t</div>\r\n\t    \t\t</a>\r\n    \t\t</li>\r\n        </ul>\r\n        <br/>           \r\n        <h3>One column, inset List.</h3>\r\n        <br/>\r\n        <ul class="st-list st-inset" data-bind="foreach : sampleData">\r\n            <li>\r\n            \t<a href="#">\r\n    \t\t\t\t<div class="st-list-img">\r\n    \t\t\t\t\t<img data-bind="attr : {src : imgsrc, alt : imgalt}" />\r\n    \t\t\t\t</div>\r\n    \t\t\t\t<div class="st-list-content">\r\n\t\t    \t\t\t<h3 class="st-list-title reset" data-bind="text : title"></h3>\r\n\t\t\t\t    \t<p class="st-list-summary reset" data-bind="text : description"></p>\r\n    \t    \t\t</div>\r\n\t    \t\t</a>\r\n    \t\t</li>\r\n        </ul>          \r\n   </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-list">Stashy.List.less</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>   ';});

define('text!views/loader/loader.html',[],function () { return '<div id="loader" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'loader/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/loader/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-banana h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-banana h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\t\r\n    <div class="hero-unit badge-banana h-big-top-margin">\r\n        <h1>Loader</h1>\r\n        <p class="lead h-big-top-margin">Nice loader based in CSS3 transitions and animations</p>\r\n        <a class="btn badge-banana-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\r\n        <a class="btn badge-banana-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>          \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>I always liked the Windows 8 / Window Phone loader. I think it fits very good in responsive designs so just added it to Stashy. The loader works using CSS3 transitions and animations so only modern browsers could show it properly.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n        <p>Not required any HTML. The loader will be generated dynamically using JavaScript.</p>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Loader(target)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>target</strong></td>\r\n                    <td>string</td>\r\n                    <td>Select the element node where the loader will be appended to</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>         \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on(position,offset,color, insertiontype)</strong></td>                    \r\n                    <td>Create and show the loader</td>\r\n                </tr>\r\n                <tr>\r\n                    <td colspan=2>                        \r\n                        <p>\r\n                            <strong>position:</strong> Can choose "absolute", "relative", "fixed", "static"\r\n                        </p>                        \r\n                        <p>\r\n                            <strong>offset:</strong> Offset from the chosen target (e.g. "20px" or "2em" ...)\r\n                        </p>\r\n                        <p>\r\n                            <strong>color:</strong> Color you want to use (e.g. #000)\r\n                        </p>\r\n                        <p>\r\n                            <strong>insertiontype:</strong> "prepend" for adding the loader like first child or "append" for last child\r\n                        </p>\r\n                    </td>    \r\n                </tr>\r\n                <tr>\r\n                    <td><strong>off()</strong></td>\r\n                    <td>Destroy and hide the loader</td>\r\n                </tr>                                        \r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar loader = Stashy.Loader("#page").on("relative","2em","#000","prepend");\r\nloader.off();\r\n</pre>\r\n    </section>\r\n   <section id="playground">\r\n         <div class="page-header">\r\n           <h1>Playground</h1>\r\n        </div>\r\n    <p>Choose your options or leave defaults included and click the button for showing the loader</p>\t\t\t\t\t\t\t\r\n    <form class="well form-horizontal h-top-margin" data-bind="with : parameters">\r\n      <div class="control-group">\r\n        <label class="control-label" for="inputTarget">Target</label>\r\n        <div class="controls">\r\n            <input type="text" id="inputTarget" data-bind="value : target" placeholder="CSS selector for the target" />\r\n        </div>\r\n      </div>                              \r\n      <div class="control-group">\r\n        <label class="control-label" for="selectPosition">Position</label>\r\n        <div class="controls">\r\n            <select id="selectPosition" data-bind="value : position">\r\n              <option>fixed</option>              \r\n              <option>absolute</option>\r\n              <option>relative</option>\r\n              <option>static</option>                           </select>                                  \r\n        </div>\r\n      </div>                              \r\n      <div class="control-group">\r\n        <label class="control-label" for="inputOffset">Offset</label>\r\n        <div class="controls">\r\n            <input type="text" id="inputOffset" data-bind="value : offset" placeholder="Offset from target" />\r\n        </div>\r\n      </div>\r\n      <div class="control-group">\r\n        <label class="control-label" for="inputColor">Color</label>\r\n        <div class="controls">\r\n            <input type="text" id="inputColor" data-bind="value : color" placeholder="Choose the loader color">\r\n        </div>\r\n      </div>\r\n      <div class="control-group">\r\n        <label class="control-label" for="selectInsertionType">Insertion type</label>\r\n        <div class="controls">\r\n            <select id="selectInsertionType" data-bind="value : insertiontype">\r\n              <option>prepend</option>\r\n              <option>append</option>                             \r\n            </select>                                    \r\n        </div>\r\n      </div>\r\n      <div class="h-align-inline">\r\n        <a id="playground-on" class="btn btn-inverse reset-margin" data-bind="click : loaderOn">on</a>\r\n        <a id="playground-off" class="btn btn-inverse reset-margin" data-bind="click : loaderOff">off</a>                                    \r\n      </div>\r\n    </form>                                \r\n   </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-banana">Stashy.Loader.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> <span class="badge badge-banana">Stashy.Loader.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>   ';});

define('text!views/notfound/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn btn-danger h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n</div>\r\n\r\n<div>\t\r\n    <div class="hero-unit badge-important h-big-top-margin h-inverse-color">\r\n        <h1><i class="icon-exclamation-sign icon-large"></i>Page not found</h1>\r\n        <p class="lead h-big-top-margin">You have a wrong address and this site do not contains any page with this url</p>\r\n        <p class="h-big-top-margin">Try with any of the links provided in the sidebar to go and check Stashy components. You can always download or go to Github and check the project as well if is this what you are looking for</p>        \r\n        <a class="btn badge-danger-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n        <a class="btn badge-danger-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                \r\n    </div>\r\n</div>';});

define('text!views/notfound/notfound.html',[],function () { return '<div id="notfound" class="st-offcanvas no-additional">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'notfound/main.html\'"></div>\r\n</div>';});

define('text!views/notify/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-notify h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-notify h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\t\r\n    <div class="hero-unit badge-notify h-big-top-margin">\r\n        <h1>Notify</h1>\r\n        <p class="lead h-big-top-margin">Notications using toasts, bars and panels</p>\r\n        <a class="btn badge-notify-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\r\n        <a class="btn badge-notify-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>          \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>Most applications need to communicate info (errors, warnings, ...)  to the end user. With Notify you can do it in a unobstrusive and responsive way.</p>\r\n        <p>There are three type of notifications included with this component:</p>\r\n        <p><span class="badge badge-notify">toast</span>  Opened in the corner you choose and 40% width.</p>\r\n        <p><span class="badge badge-notify">bar</span>  Opened top or bottom and full width.</p>\r\n        <p><span class="badge badge-notify">panel</span>  Opened left or right and full height.</p>\r\n    </section>    \r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Notify(userOptions)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>userOptions</strong></td>\r\n                    <td>object</td>\r\n                    <td>The init  options for each instance of Notify. Take a look to the userOptions table and explore the available stuff</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>\r\n        <h2>The userOptions object</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>    \t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>target</strong></td>\r\n                    <td>string</td>\r\n                    <td>body</td>\r\n                    <td>The element target container, by default the "body" of the page</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>title</strong></td>\r\n                    <td>string</td>\r\n                    <td>empty string</td>\r\n                    <td>The element title</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>titleSize</strong></td>\r\n                    <td>int</td>\r\n                    <td>3</td>\r\n                    <td>Enter whatever value in the range 1..6.The title will be an HTML heading. This number will provide the heading size (h<span class="badge badge-notify">1</span>, h<span class="badge badge-notify">2</span>, h<span class="badge badge-notify">3</span>, ...)</td>\r\n                </tr>                                \r\n                <tr>\r\n                    <td><strong>contentType</strong></td>\r\n                    <td>string</td>\r\n                    <td>text</td>\r\n                    <td>\r\n                        <p class="reset">It can be "inline" or "selector".</p>\r\n                        <p>If you select "inline", then the content property should be simple text or inline html</p>\r\n                        <p>On the other side, if you select "selector", you can provide any CSS selector to choose what to include in the notification.</p>\r\n                        <p>If your option is "selector" remember you can add the <span class="badge badge-notify">st-notify-content</span> class to the content box you are going to include in the notification in order to hide it.</p>\r\n                    </td>\r\n                </tr> \r\n                <tr>\r\n                    <td><strong>content</strong></td>\r\n                    <td>string</td>\r\n                    <td>empty string</td>\r\n                    <td>Simple text, inline html or a CSS selector</td>\r\n                </tr>                \r\n                <tr>\r\n                    <td><strong>style</strong></td>\r\n                    <td>string</td>\r\n                    <td>default</td>\r\n                    <td>Changes the color of the notification. The allowed styles are "default", "error", "info", "success" and "warning"</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>animDuration</strong></td>\r\n                    <td>string</td>\r\n                    <td>fast</td>\r\n                    <td>"fast" or "slow" for a 1 sec or 2 sec animations</td>\r\n                </tr>    \r\n                <tr>\r\n                    <td><strong>closeArea</strong></td>\r\n                    <td>string</td>\r\n                    <td>button</td>\r\n                    <td>\r\n                        <p class="reset">If you select "button" then a close button will be added to notification.</p>\r\n                        <p>If you choose "element" then the element itself will be clickable to closing it.</p>\r\n                    </td>\r\n                </tr>                  \r\n                <tr>\r\n                    <td><strong>activeDuration</strong></td>\r\n                    <td>int</td>\r\n                    <td>0</td>\r\n                    <td>How long to display the notification for in milliseconds, zero will leave the notification displayed until the user closes manually.</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>           \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>toast(positionX, positionY,radius)</strong></td>                    \r\n                    <td>Create a <span class="badge badge-notify">toast</span> style notification</td>\r\n                </tr>\r\n                <tr>\r\n                    <td colspan=2>                        \r\n                        <p>\r\n                            <strong>positionX:</strong> "right" or "left"\r\n                        </p>                        \r\n                        <p>\r\n                            <strong>positionY:</strong> "top" or "bottom"\r\n                        </p>\r\n                        <p>\r\n                            <strong>radius:</strong> Select <em>true</em> if you like rounded corners\r\n                        </p>\r\n                    </td>    \r\n                </tr>\r\n                <tr>\r\n                    <td><strong>bar(positionY)</strong></td>\r\n                    <td>Creates a <span class="badge badge-notify">bar</span> style notification</td>\r\n                </tr>\r\n                <tr>\r\n                    <td colspan=2>\r\n                        <p>\r\n                            <strong>positionY:</strong> "top" or "bottom"\r\n                        </p>                      \r\n                    </td>                     \r\n                </tr>                                        \r\n                <tr>\r\n                    <td><strong>panel(positionX)</strong></td>\r\n                    <td>Creates a <span class="badge badge-notify">panel</span> style notification</td>\r\n                </tr>\r\n                <tr>\r\n                    <td colspan=2>                        \r\n                        <p>\r\n                            <strong>positionX:</strong> "right" or "left"\r\n                        </p>                        \r\n                    </td>                     \r\n                </tr>                                                        \r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Notify({\r\n    title : "My toast",\r\n    content : "Toast style notification",\r\n    titleSize : 4,\r\n    style : "success",\r\n    contentType : "text",\r\n    animDuration : "fast",\r\n    closeArea : "element"\r\n}).toast("right", "bottom", true);\r\n\r\nStashy.Notify({\r\n    title : "My bar",\r\n    content : "<em>Bar style notification</em>",\r\n    titleSize : 1,\r\n    style : "info",\r\n    contentType : "html",\r\n    animDuration : "slow",\r\n    closeArea : "button"\r\n}).bar("top");\r\n\r\nStashy.Notify({\r\n    title : "My panel",\r\n    content : "#whatever-element-in-the-page",\r\n    titleSize : 2,\r\n    style : "default",\r\n    contentType : "html",\r\n    animDuration : "fast",\r\n    closeArea : "button",\r\n    activeDuration : 5000\r\n}).panel("right");\r\n</pre>\r\n    </section>\r\n   <section id="playground">\r\n         <div class="page-header">\r\n           <h1>Playground</h1>\r\n        </div>\r\n    <p>Ok, let´s go with the important part, so start choosing your options ans see what Notify can do for you :)</p>    \r\n    <form class="well form-horizontal h-top-margin" data-bind="with : options, submit : showNotification">\r\n        <div class="control-group">\r\n            <label class="control-label" for="title">Title</label>\r\n            <div class="controls">\r\n                <input type="text" name="title" value="" placeholder="title" data-bind="value : title" />\r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="content">Content</label>\r\n            <div class="controls">\r\n                <textarea name="content" placeholder="content" data-bind="value : content"></textarea>\r\n            </div>\r\n        </div>  \r\n        <div class="control-group">\r\n            <label class="control-label" for="titleSize">Title size</label>\r\n            <div class="controls">\r\n                <select id="titleSize" data-bind="value : titleSize">\r\n                    <option value="3" selected="selected">Select the title size</option>\r\n                    <option value="1">1</option>\r\n                    <option value="2">2</option>\r\n                    <option value="3">3</option>\r\n                    <option value="4">4</option>\r\n                    <option value="5">5</option>\r\n                    <option value="6">6</option>\r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="contentType">Content type</label>\r\n            <div class="controls">\r\n                <select id="contentType" data-bind="value : contentType">\r\n                    <option value="inline" selected="selected">Select the content type</option>\r\n                    <option value="inline">inline</option>\r\n                    <option value="selector">selector</option>                    \r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="style">Style</label>\r\n            <div class="controls">\r\n                <select id="style" data-bind="value : style">\r\n                    <option value="default" selected="selected">Select style</option>\r\n                    <option value="default">default</option>\r\n                    <option value="error">error</option>\r\n                    <option value="info">info</option>                    \r\n                    <option value="warning">warning</option>                    \r\n                    <option value="success">success</option>                                        \r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="animDuration">Animation duration</label>\r\n            <div class="controls">\r\n                <select id="animDuration" data-bind="value : animDuration">\r\n                    <option value="fast" selected="selected">animation duration</option>\r\n                    <option value="slow">slow</option>\r\n                    <option value="fast">fast</option>                                                    \r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="closeArea">Close area</label>\r\n            <div class="controls">\r\n                <select id="closeArea" data-bind="value : closeArea">\r\n                    <option value="button" selected="selected">close area</option>\r\n                    <option value="button">button</option>\r\n                    <option value="element">element</option>                          \r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="positionX">Close area</label>\r\n            <div class="controls">\r\n                <select id="positionX" data-bind="value : positionX">\r\n                    <option value="right" selected="selected">positionX</option>\r\n                    <option value="left">left</option>\r\n                    <option value="right">right</option>                          \r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="positionY">Position Y</label>\r\n            <div class="controls">\r\n                <select id="positionY" data-bind="value : positionY">\r\n                    <option value="top" selected="selected">positionY</option>\r\n                    <option value="top">top</option>\r\n                    <option value="bottom">bottom</option>                          \r\n                </select>                                    \r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="activeDuration">Active duration</label>\r\n            <div class="controls">\r\n                <input type="text" name="activeDuration" value="" placeholder="active duration" data-bind="value : activeDuration" />\r\n            </div>\r\n        </div>        \r\n        <div class="control-group">            \r\n            <div class="controls">\r\n                <input type="checkbox" name="radius" value="true" data-bind="checked : radius" /> <span>add radius?</span>\r\n            </div>\r\n        </div>\r\n        <div class="control-group">\r\n            <label class="control-label" for="component">Component</label>\r\n            <div class="controls">\r\n                <input type="radio" name="component" value="toast" data-bind="checked : component" /> <span>Toast</span>\r\n                <input type="radio" name="component" value="bar" data-bind="checked : component" /> <span>Bar</span>\r\n                <input type="radio" name="component" value="panel" data-bind="checked : component" /> <span>Panel</span>\r\n            </div>\r\n        </div>\r\n        <button class="btn btn-primary" type="submit">Show notification!!</button>\r\n    </form>    \r\n   </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-notify">Stashy.Animate.less</span>\r\n        <span class="badge badge-notify">Stashy.Notify.less</span> \r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> <span class="badge badge-notify">Stashy.Notify.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>   ';});

define('text!views/notify/notify.html',[],function () { return '<div id="notify" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'notify/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/offcanvas/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn btn-danger h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn btn-danger h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n\r\n<div>\t\r\n    <div class="hero-unit badge-important h-big-top-margin h-inverse-color">\r\n        <h1>OffCanvas</h1>\r\n        <p class="lead h-big-top-margin">Create responsive pages using this awesome layout</p>\r\n        <a class="btn badge-danger-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n        <a class="btn badge-danger-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>This component is focused in creating layouts adapting to several screen sizes. The Offcanvas layout has 3 panels aligned left, center and right.</p>\r\n        <p>Left panel or <span class="badge badge-important">st-offcanvas-menu</span>, is perfect for navigation and will be showed on desktop and tablet devices size.</p>\r\n        <p>Center panel or <span class="badge badge-important">st-offcanvas-main</span>, will hold page content.</p>\r\n        <p>Right panel or <span class="badge badge-important">st-offcanvas-additional</span>, can be used for showing some complementary stuff.</p>\r\n        <p>The menu and additional panels are optional, so you can simply don\'t write the markup for any of them and the <span class="badge badge-important">st-offcanvas-main</span> panel will take the remaining width.</p>                        \r\n        <p>The Offcanvas Stashy implementation is inspired in <a href="http://jasonweaver.name/lab/offcanvas/" target="_blank">this great article</a> from Jason Weaver.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n<pre class="prettyprint linenums">\r\n&ltdiv class="st-offcanvas"&gt\r\n    &ltdiv class="st-offcanvas-menu"&gt\r\n        ... left panel, supposed to be used for menus or something like that ...\r\n        ... this panel is optional so you can simply don´t write it in your code  ...\r\n    &lt/div&gt\r\n    &ltdiv class="st-offcanvas-main"&gt\r\n        &lta href="#" class="showmenubutton"&gt&lt/a&gt\r\n        &lta href="#" class="showadditionalbutton"&gt&lt/a&gt\r\n        ... Main content ...\r\n        ... You can wrap the show menus buttons with any tag or add more of them ...\r\n    &lt/div&gt\t\t\r\n    &ltdiv  class="st-offcanvas-additional"&gt\r\n        ... another panel, to the right, for additional content ...\r\n        ... this panel is optional so you can simply don´t write it in your code  ...\r\n    &lt/div&gt\t                        \r\n&lt/div&gt</pre>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.OffCanvas(selector,options)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>.st-offcanvas</td>\r\n                    <td>CSS selector for your OffCanvas</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>\r\n                    <td>You can pass the options to the offcanvas instance</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>    \r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>onMobileLayout</strong></td>\r\n                    <td>function</td>\r\n                    <td><a href="http://api.jquery.com/jQuery.noop/" target="_blank">$.noop</a></td>\r\n                    <td>Provide any function with the actions you want perform when screen size is smaller than 769px</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>onTabletLayout</strong></td>\r\n                    <td>function</td>\r\n                    <td><a href="http://api.jquery.com/jQuery.noop/" target="_blank">$.noop</a></td>\r\n                    <td>Provide any function with the actions you want perform when screen size is between 769px and 979px</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>onDesktopLayout</strong></td>\r\n                    <td>function</td>\r\n                    <td><a href="http://api.jquery.com/jQuery.noop/" target="_blank">$.noop</a></td>\r\n                    <td>Provide any function with the actions you want perform when screen size is greater than 769px</td>\r\n                </tr>                                \r\n                <tr>\r\n                    <td><strong>useTransitions</strong></td>\r\n                    <td>boolean</td>\r\n                    <td>true</td>\r\n                    <td>Use a CSS3 transition when opening and closing panels</td>\r\n                </tr> \r\n                <tr>\r\n                    <td><strong>closeOnClickOutside</strong></td>\r\n                    <td>bool</td>\r\n                    <td>true</td>\r\n                    <td>Close OffCanvas on click outside the open and close buttons (.showmenubutton, .showadditionalbutton)</td>\r\n                </tr>                \r\n                <tr>\r\n                    <td><strong>enableTouch</strong></td>\r\n                    <td>bool</td>\r\n                    <td>false</td>\r\n                    <td>If touch is enabled and the device is touch capable, then you can swipe to push left and right panels. The touch behaviour is controlled by Hammer.js so you need to add a reference to jquery.hammer.js. Get it in the <a href="http://eightmedia.github.io/hammer.js/" target="_blank">project site</a> or in the <a href="https://github.com/yagopv/Stashy/tree/master/dist/js" target="_blank">dist folder</a> of the Stashy Github project</td>\r\n                </tr>                    \r\n            </tbody>\r\n        </table>     \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>layout()</strong></td>\r\n                    <td>Start the offcanvas layout</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>close()</strong></td>\r\n                    <td>Remove the active classes and close the panel if necessary</td>\r\n                </tr>                \r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar offcanvas = new Stashy.OffCanvas("", { \r\n    onMobileLayout : function() {\r\n    ... awesome actions in mobile screen sizes ...\r\n    },\r\n    onTabletLayout : function() {\r\n    ... awesome actions in tablet sizes ...\r\n    },                \r\n    onDesktopLayout : function() {\r\n    ... actions in desktop sizes ...\r\n    }\r\n}).layout();</pre>\r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-important">Stashy.OffCanvas.less</span>\r\n        <p class="lead">JS</p>        \r\n        <div class="h-top-margin">\r\n            <span class="badge badge-info">jQuery.js</span>\r\n            <span class="badge badge-info">jquery.hammer.js (if touch enabled)</span>\r\n            <span class="badge badge-important">Stashy.Events.js</span>\r\n            <span class="badge badge-important">Stashy.OffCanvas.js</span>            \r\n        </div>\t        \r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/offcanvas/offcanvas.html',[],function () { return '<div id="offcanvas" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'offcanvas/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/refresh/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-grass h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-grass h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\t\r\n    <div class="hero-unit badge-grass h-big-top-margin h-inverse-color">\r\n        <h1>Refresh</h1>\r\n        <p class="lead h-big-top-margin">Pull to refresh component aiming ajax content loading</p>\r\n        <a class="btn btn-large badge-grass-dark h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n         <a class="btn btn-large badge-grass-dark h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                  \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>This component is mainly focused on mobile devices. It works as well in desktop using the mouse by dragging down the container.</p>\r\n        <p>Pull to refresh controls are very useful in mobile apps because gives you the ability of quickly refresh any list, carousel or wathever with a well controlled gesture.</p>\r\n        <p>This page is wrapped with a Refresh control so you can pull down to refresh. When you release, the image in the <a href="#" data-bind="click : scrollToPlayground">playground section</a> will be refreshed.</p>\r\n        <p>The control only works if you has not scrolled the page because you´ll want the normal behaviour of scrolling down in your device.</p>\r\n        <p>So ... scroll to top and start dragging down ... :). </p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                                             \r\n        </div>                                    \r\n<pre class="prettyprint linenums">\r\n&ltdiv class="st-refresh"&gt\r\n    &ltdiv class="st-refresh-pullrefresh"&gt\r\n        &ltdiv class="message"&gt\r\n            &ltdiv class="st-refresh-icon arrow arrow-down"&gt&lt/div&gt\r\n            &ltspan data-pull="Pull to refresh !!" \r\n                    data-release="Release !!" \r\n                    data-loading="Loading..."&gt\r\n            &lt/span&gt\r\n        &lt/div&gt\r\n    &lt/div&gt\r\n    &ltdiv&gt\r\n    ... Your content here ...\r\n    &lt/div&gt\r\n&lt/div&gt\r\n</pre>\t\r\n    </section>\r\n\r\n   <section id="javascript">\r\n    <div class="page-header">                        \r\n       <h1>Javascript</h1>\t\t\t\t\t\t\r\n    </div>\t\t\t\r\n    <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Refresh(selector, options)</pre>\t\t\t\t\t\t\t\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>CSS selector. Select the Refresh container</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>\r\n                    <td>You can pass the options to the refresh instance</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>\r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>onRelease</strong></td>\r\n                    <td>function</td>\r\n                    <td><a href="http://api.jquery.com/jQuery.noop/" target="_blank">$.noop</a></td>\r\n                    <td>You need to use this function for doing something when release Refresh after dragging down. The common use is to do some ajax request and call slideUp() for hiding the Refresh control</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>breakpoint</strong></td>\r\n                    <td>int</td>\r\n                    <td>100</td>\r\n                    <td>Over this point (in px) when you release the control the onRelease() function will be called. When reaching this point as well, the text message with info in data-release will be changed. While this point is not reached, the data-pull text will be showed. Finally, after release, data-loading will be the text message in the control</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>            \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on()</strong></td>\r\n                    <td>Initializes Refresh with the options you choose</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>slideUp()</strong></td>\r\n                    <td>Hide Refresh. You have to call slur callback in order to hide the Refresh control</td>\r\n                </tr>                \r\n            </tbody>\r\n        </table>\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar refresh = Stashy.Refresh("#myrefresh", { \r\n    onRelease : function() {\r\n        var self = this;\r\n        $.getJSON("api/customers").done(function() {\r\n            self.slideUp();\r\n        });\r\n    }\r\n}).on();\t\r\n</pre>\r\n    </section>    \r\n    <section id="playground">\r\n        <div class="page-header">                        \r\n           <h1>Playground</h1>    \t\t\t\t\t\r\n        </div>\r\n        <h2>Pull to refresh</h2>\r\n        <p><a href="#" data-bind="click:scrollToBody">Scroll up</a> and start dragging down</p>\r\n\t\t<p>\r\n\t\t\t<img id="random-image" src="http://lorempixel.com/800/600/">\r\n\t\t</p>\t\t\r\n    </section>\r\n        \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p>The dependency on Hammer is mandatory because this control is working with gestures or dragging down and you will need touch support.</p>\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-grass">Stashy.Refresh.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> \r\n        <span class="badge badge-info">jquery.hammer.js</span>\r\n        <span class="badge badge-grass">Stashy.Utils.js</span> \r\n        <span class="badge badge-grass">Stashy.Modernizr.js</span> \r\n        <span class="badge badge-grass">Stashy.Refresh.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/refresh/refresh.html',[],function () { return '<div id="playground-refresh" class="st-refresh">    \r\n    <div class="st-refresh-pullrefresh">\r\n        <div class="message">\r\n            <div class="st-refresh-icon arrow arrow-down"></div>\r\n            <span data-pull="Pull to refresh !!" data-release="Release !!" data-loading="Loading..."></span>\r\n        </div>\r\n    </div>\r\n    <div>\r\n        <div id="refresh" class="st-offcanvas">\r\n            <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n            <div class="st-offcanvas-main" id="content" data-bind="compose : \'refresh/main.html\'"></div>\r\n            <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n        </div>        \r\n    </div>\r\n</div>\r\n    ';});

define('text!views/shell.html',[],function () { return '<div>\r\n    <header data-bind="compose : { model :\'viewmodels/header\'}"></header>\r\n    \r\n    <div id="page" class="page-host" data-bind="router: { transition:\'entrance\', cacheViews:true }">\r\n    </div> \r\n    \r\n    <i id="scrollup" data-bind="click : scrollup" class="icon-circle-arrow-up"></i>\r\n</div>\r\n\r\n<div class="st-sticky-push"></div>';});

define('text!views/showmemore/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn btn-inverse h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn btn-inverse h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\t\r\n    <div class="hero-unit badge-inverse h-big-top-margin h-inverse-color">\r\n        <h1>ShowMeMore</h1>\r\n        <p class="lead h-big-top-margin">Hide items ... and show a button for showing more of them</p>\r\n        <a class="btn btn-large badge-grey h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n         <a class="btn btn-large badge-grey h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>   \t                            \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>Using this component you can avoid the show long lists of items.</p>\r\n        <p>Instead you can display the number of them you choose, hiding the rest and showing a button "Show more".</p>\r\n        <p>This utility uses jQuery <span class="badge badge-inverse">:gt()</span> selector behind the scenes.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n<pre class="prettyprint linenums">\r\n//you can use simple divs ...\r\n&ltdiv id="yourId"&gt\r\n    &ltdiv class="yourClass"&gt...&lt/div&gt\t\r\n    &ltdiv class="yourClass"&gt...&lt/div&gt\t\r\n    &ltdiv class="yourClass"&gt...&lt/div&gt\t\t\r\n&lt/div&gt\r\n\r\n//... or you can do it with lists (ul, ol ...) for example \r\n\r\n&ltul id="yourId"&gt\r\n    &ltli class="yourClass"&gt...&lt/li&gt\t\r\n    &ltli class="yourClass"&gt...&lt/li&gt\t\r\n    &ltli class="yourClass"&gt...&lt/li&gt\t\t\r\n&lt/ul&gt</pre>\t\r\n    </section>\r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.ShowMeMore(selector, options)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>empty string</td>\r\n                    <td>CSS selector for the items collection. It can be a class, data attibuttes ...etc</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>\r\n                    <td>Options for the showmemore instance</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>    \r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>linkClass</strong></td>\r\n                    <td>string</td>\r\n                    <td>empty string</td>\r\n                    <td>Provide the class or classes to style the automatically generated "Show more" button</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>linkText</strong></td>\r\n                    <td>string</td>\r\n                    <td>"Show more"</td>\r\n                    <td>Text for the show me more button</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>howMany</strong></td>\r\n                    <td>integer</td>\r\n                    <td>1</td>\r\n                    <td>How many items you want to show?</td>\r\n                </tr>                                 \r\n            </tbody>\r\n        </table>   \t\t\t\t\t\t\t\r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on</strong></td>\r\n                    <td>Start hiding elements</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>off</strong></td>\r\n                    <td>End hiding elements. Show all elements again</td>\r\n                </tr>\r\n                \r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar smm = Stashy.ShowMeMore("#id .item", {\r\nlinkClass : "myClass",\r\nlinkText : "myText",\r\nhowMany : 5\r\n});\r\n// Start hiding items\r\nsmm.on();\r\n// End  hiding items\r\nsmm.off();\r\n\r\n... or you can chain methods ...\r\n\r\n// Start hiding items\r\nStashy.ShowMeMore("#id .item", {\r\nlinkClass : "myClass",\r\nlinkText : "myText",\r\nhowMany : 5\r\n}).on();\r\n\r\n// End  hiding items\r\nStashy.ShowMeMore("#id .item", {\r\nlinkClass : "myClass",\r\nlinkText : "myText",\r\nhowMany : 5\r\n}).off();</pre>\r\n    </section>\r\n    \r\n    <section id="playground">\r\n        <div class="page-header">                        \r\n           <h1>Playground</h1>\t\t\t\t\t\t\r\n        </div>\r\n        <p>Select how many items you want to display from the list below.</p>\r\n        <p>This example list is built using <span class="badge badge-inverse">&ltdiv&gt</span> boxes.</p>\r\n        \r\n        \r\n        <form class="well form-inline h-top-margin">\t\t\t\t\t\t\t\t\r\n            <input type="text" class="input-small" placeholder="How many?" data-bind="value : sectionhowmany"  style="height:30px;"/>\r\n            <a id="sections-sample-on" data-bind="click : showmemoreOn, attr : { \'data-target\' : \'#sections-sample .item\'}" class="btn btn-inverse reset-margin">on</a>\r\n            <a id="sections-sample-off" data-bind="click : showmemoreOff, attr : { \'data-target\' : \'#sections-sample .item\'}" class="btn btn-inverse reset-margin">off</a>\r\n        </form>\r\n        \r\n        <div id="sections-sample" data-bind="foreach : items1">\r\n            <div class="media item">\r\n              <a class="pull-left" href="#">\r\n                <span class="media-object label label-inverse" style="width:64px; height:64px;"></span>\r\n              </a>\r\n              <div class="media-body">\r\n                <h2 class="media-heading" data-bind="text : title"></h2>\r\n                <div class="media">\r\n                    <p data-bind="text : description"></p>\r\n                </div>\r\n              </div>\r\n            </div>\t\t\t\t\r\n        </div>\r\n        \r\n        <p>You can do the same as above but using an unordered list <span class="badge badge-inverse">&ltul&gt</span></p>\r\n        \r\n        <form class="well form-inline h-top-margin">\t\t\t\t\t\t\t\t\r\n            <input type="text" class="input-small" placeholder="How many?" data-bind="value : listhowmany"  style="height:30px;"/>\r\n            <a id="list-sample-on" data-bind="click : showmemoreOn, attr : { \'data-target\' : \'#list-sample .item\'}" class="btn btn-inverse reset-margin">on</a>\r\n            <a id="list-sample-off" data-bind="click : showmemoreOff, attr : { \'data-target\' : \'#list-sample .item\'}" class="btn btn-inverse reset-margin">off</a>\r\n        </form>\r\n        <ul id="list-sample" class="media-list" data-bind="foreach : items2">\r\n          <li class="media item">\r\n            <a class="pull-left" href="#">\r\n                <span class="media-object label label-inverse" style="width:64px; height:64px;"></span>\r\n            </a>\r\n            <div class="media-body">\r\n                <h2 class="media-heading" data-bind="text : title"></h2>\r\n                <div class="media">\r\n                    <p data-bind="text : description"></p>\r\n                </div>\r\n            </div>\r\n            </li>\t\t\t\t\t\t\r\n        </ul>\t\t\t\t\t\t\t\t\t\t\t\t\t\r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> <span class="badge badge-inverse">Stashy.ShowMeMore.js</span>\r\n    </section>\r\n</div>';});

define('text!views/showmemore/showmemore.html',[],function () { return '<div id="showmemore" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'showmemore/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/slider/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-sky h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-sky h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\t\r\n    <div class="hero-unit badge-sky h-big-top-margin h-inverse-color">\r\n        <h1>Slider</h1>\r\n        <p class="lead h-big-top-margin">Create sliding touch enabled layout and carousels</p>\r\n        <a class="btn btn-large badge-sky-dark h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n         <a class="btn btn-large badge-sky-dark h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                  \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>Sliders can be used in a lot of places in your website ... home pages, galleries, ... Here are the component you need from Stashy for  creating this type of stuff.</p>\r\n        <p>The slider presented here may be touch enabled for improve user experience in mobile devices.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                                             \r\n        </div>                                    \r\n<pre class="prettyprint linenums">\r\n&ltdiv id="sl1" class="st-slider"&gt\r\n    &ltul class="st-slider-panes"&gt\r\n        &ltli&gt\r\n            Content here (images, paragraphs, etc...). Use optionally a box with  .st-slider-content class in order to add a little padding\r\n            You can optionally add a box with .st-slider-caption class. This is useful for showing info about the content.          \r\n            &ltdiv class="st-slider-caption"&gt\r\n                &lth4&gtMy caption title&lt/h4&gt\r\n                &ltp&gtMy caption description&lt/p&gt\r\n            &lt/div&gt            \r\n        &lt/li&gt\r\n    &lt/ul&gt\r\n&lt/div&gt\r\n</pre>\t\r\n    </section>\r\n\r\n   <section id="javascript">\r\n    <div class="page-header">                        \r\n       <h1>Javascript</h1>\t\t\t\t\t\t\r\n    </div>\t\t\t\r\n    <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Slider(selector, options)</pre>\t\t\t\t\t\t\t\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>CSS selector. Select the Slider container</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>\r\n                    <td>You can pass the options to the slider instance</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>\r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>enableControls</strong></td>\r\n                    <td>bool</td>\r\n                    <td>>true</td>\r\n                    <td>Show the slider controls to permit slide panels left or right</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>enableIndicators</strong></td>\r\n                    <td>bool</td>\r\n                    <td>true</td>\r\n                    <td>Show the panel you are in</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>showOnHover</strong></td>\r\n                    <td>bool</td>\r\n                    <td>false</td>\r\n                    <td>Show all the slider enabled controls when hovering or tap</td>\r\n                </tr>                \r\n                <tr>\r\n                    <td><strong>autoSlide</strong></td>\r\n                    <td>bool</td>\r\n                    <td>true</td>\r\n                    <td>Auto slide using the duration option</td>\r\n                </tr>                                \r\n                <tr>\r\n                    <td><strong>enableTouch</strong></td>\r\n                    <td>bool</td>\r\n                    <td>false</td>\r\n                    <td>If touch is enabled, then you can swipe and drag over the panels. The touch behaviour is controlled by Hammer.js so you need to add a reference to jquery.hammer.js. Get it in the <a href="http://eightmedia.github.io/hammer.js/" target="_blank">project site</a> or in the <a href="https://github.com/yagopv/Stashy/tree/master/dist/js" target="_blank">dist folder</a> of the Stashy Github project</td>\r\n                </tr> \r\n                <tr>\r\n                    <td><strong>duration</strong></td>\r\n                    <td>int</td>\r\n                    <td>5000</td>\r\n                    <td>The duration for the auto slide option (in milliseconds)</td>\r\n                </tr>                   \r\n            </tbody>\r\n        </table>            \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on()</strong></td>\r\n                    <td>Initializes Slider with the options you choose</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>showPane(index)</strong></td>\r\n                    <td>Show the panel you choose</td>\r\n                </tr>                \r\n                <tr>                                        \r\n                    <td colspan="2">\r\n                        <p><em>index:</em>Choose panel to show (from 0 to N)</p>\r\n                    </td>\r\n                </tr>\t\t\t\t\t\t\t\t\t\r\n                <tr>\r\n                    <td><strong>next()</strong></td>\r\n                    <td>Show next panel</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>prev()</strong></td>\r\n                    <td>Show previous panel</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nsl2 = Stashy.Slider("#sl2",{showControls : false, showIndicators:false, enableTouch : true}).on();\r\n</pre>\r\n    </section>    \r\n    <section id="playground">\r\n        <div class="page-header">                        \r\n           <h1>Playground</h1>    \t\t\t\t\t\r\n        </div>\r\n        <h3>Carousel</h3>\r\n        <p>The classic carousel for showing your images. In this sample all the options are enabled so you have controls showed on hover or tap, touch enabled for drag left and right ...etc.</p>\r\n        <div id="sl1" class="st-slider h-top-margin">\r\n\t\t    <ul class="st-slider-panes">\r\n\t\t\t\t\t<li>\r\n\t\t\t\t\t\t<img src="http://stashy.blob.core.windows.net/static/Hot_car_wallpaper_2973_1024x768.jpg" />\r\n\t\t\t\t\t\t<div class="st-slider-caption">\r\n\t\t\t\t\t\t\t<h2>Lorem ipsum</h2>\r\n\t\t\t\t\t\t\t<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus varius lacus nunc. Suspendisse sit amet aliquet mi. Aliquam blandit cursus elit, ac dictum erat condimentum vel. In elementum consectetur nisl, sit amet vestibulum lectus tempor vel. Integer tempus, erat non ullamcorper suscipit</p>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</li>\r\n\t\t\t\t\t<li>\r\n\t\t\t\t\t\t<img src="http://stashy.blob.core.windows.net/static/Maserati-MC-Sport-Line-rear-maserati-wallpaper-car-wallpaper-1024x768.jpg" />\r\n\t\t\t\t\t\t<div class="st-slider-caption">\r\n\t\t\t\t\t\t\t<h2>Lorem ipsum</h2>\r\n\t\t\t\t\t\t\t<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus varius lacus nunc. Suspendisse sit amet aliquet mi. Aliquam blandit cursus elit, ac dictum erat condimentum vel. In elementum consectetur nisl, sit amet vestibulum lectus tempor vel. Integer tempus, erat non ullamcorper suscipit</p>\r\n\t\t\t\t\t\t</div>\t\t\t\t\t\t\r\n\t\t\t\t\t</li>\r\n\t\t\t\t\t<li>\r\n\t\t\t\t\t\t<img src="http://stashy.blob.core.windows.net/static/Saab_wallpapers_426.jpg" />\r\n\t\t\t\t\t\t<div class="st-slider-caption">\r\n\t\t\t\t\t\t\t<h2>Lorem ipsum</h2>\r\n\t\t\t\t\t\t\t<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus varius lacus nunc. Suspendisse sit amet aliquet mi. Aliquam blandit cursus elit, ac dictum erat condimentum vel. In elementum consectetur nisl, sit amet vestibulum lectus tempor vel. Integer tempus, erat non ullamcorper suscipit</p>\r\n\t\t\t\t\t\t</div>\t\t\t\t\t\t\r\n\t\t\t\t\t</li>\r\n\t\t\t\t\t<li>\r\n\t\t\t\t\t\t<img src="http://stashy.blob.core.windows.net/static/car-for-desktop-wallpapers.jpg" />\r\n\t\t\t\t\t\t<div class="st-slider-caption">\r\n\t\t\t\t\t\t\t<h2>Lorem ipsum</h2>\r\n\t\t\t\t\t\t\t<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus varius lacus nunc. Suspendisse sit amet aliquet mi. Aliquam blandit cursus elit, ac dictum erat condimentum vel. In elementum consectetur nisl, sit amet vestibulum lectus tempor vel. Integer tempus, erat non ullamcorper suscipit</p>\r\n\t\t\t\t\t\t</div>\t\t\t\t\t\t\r\n\t\t\t\t\t</li>\t\t\t\t\t\r\n\t\t\t\t</ul>\r\n        </div>\t\r\n        <h3 class="h-top-margin">Information panel</h3>\t\r\n        <p>Several information panels with auto slide options enabled and touch. You can drag left or right to change the panels. No controls available. Slide panels in the following widget :)</p>\r\n\t\t\t<div id="sl2" class="st-slider reset h-top-margin">\r\n\t\t\t\t<ul class="st-slider-panes">\r\n\t\t\t\t\t<li class="badge-sky h-vcenter-parent">\t\t\t\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t        <div class="st-slider-content h-vcenter-child">\r\n                            <h2>... Drag or swipe ...</h2>\r\n                            <p>add Hammer.js, enable touch and use gestures for drag or swipe panels  </p>                            \t\t            \r\n\t\t\t\t        </div>\r\n\r\n\t\t\t\t    </li>\r\n\t\t\t\t\t<li class="badge-orange h-vcenter-parent">\t\t\t\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t        <div class="st-slider-content h-vcenter-child">\r\n                            <h2>... Full screen ...</h2>\r\n                            <p>This widget can be useful for a full screen sliding carousel in mobile devices</p>\r\n                            <p>For doing this, for example, you can add the slider like your main layout, add body height and min-height to 100% and disable viewport scaling</p>\r\n                            <p><strong>&ltmeta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1, maximum-scale=1"&gt</strong></p>\r\n\t\t\t\t        </div>\r\n\t\t\t\t    </li>\r\n\t\t\t\t\t<li class="badge-info h-vcenter-parent">\t\t\t\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t        <div class="st-slider-content h-vcenter-child">\r\n                            <h2>Height is important!!</h2>\r\n                            <p>Add images with the same size</p>\r\n                            <p>When using text, is important to set the height of your slider in the main container (.st-slider)</p>\r\n                            <p>For example, this widget is set to 25em</p>\r\n\t\t\t\t        </div>\r\n\t\t\t\t    </li>\r\n\t\t\t\t\t<li class="badge-strawberry h-vcenter-parent">\t\t\t\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t        <div class="st-slider-content h-vcenter-child">\r\n                            <h2>Hey!!</h2>\r\n                            <p>Of course, you are not limited by these designs, your imagination is the limit.</p>                            \t\t                  \r\n\t\t\t\t        </div>\r\n\t\t\t\t    </li>\r\n\t\t\t\t</ul>\r\n\t\t</div>  \r\n\t\t\t<h3 class="h-top-margin">Revealing options widget</h3>\r\n\t\t\t<p>Little widget with controls and auto slide disabled. For revealing options you can drag left the widget.</p>\r\n\t\t\t<div class="row-fluid">\r\n\t\t\t    <div class="offset3 span6">\r\n\t\t\t<div id="sl3" class="st-slider reset h-top-margin">\r\n\t\t\t\t<ul class="st-slider-panes">\r\n\t\t\t\t\t<li class="badge-sky">\r\n\t\t\t\t        <div class="st-slider-content">\r\n                            <h3><i class="icon-arrow-left"></i>Drag left</h3>\r\n\t\t\t\t        </div>\r\n\t\t\t\t\t</li>\t\t\t\t    \t\t\t\t        \r\n\t\t\t\t\t<li style="background: #ccc">\t\t\t\t\t\t\t\t\t\t\t\r\n\t\t\t\t        <div class="st-slider-content">\r\n\t\t                    <a class="btn btn-primary"><i class="icon-copy"></i></a>\r\n                            <a class="btn btn-primary"><i class="icon-paste"></i></a>\r\n\t\t\t\t            <a class="btn btn-primary"><i class="icon-cut"></i></a>\r\n\t\t\t\t            <a class="btn btn-primary"><i class="icon-link"></i></a>\t\t                    \r\n\t\t\t\t        </div>\r\n\t\t\t\t    </li>\r\n\t\t\t\t</ul>\r\n\t\t    </div>               \t\t\t        \r\n        </div>\r\n    </div>                        \t\t\t\t\t\t\t    \r\n    </section>\r\n        \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-sky">Stashy.Slider.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> \r\n        <span class="badge badge-info">jquery.hammer.js (if touch enabled)</span>\r\n        <span class="badge badge-sky">Stashy.Utils.js</span> \r\n        <span class="badge badge-sky">Stashy.Events.js</span>\r\n        <span class="badge badge-sky">Stashy.Modernizr.js</span> \r\n        <span class="badge badge-sky">Stashy.Slider.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/slider/slider.html',[],function () { return '<div id="slider" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'slider/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/sticky/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn badge-strawberry h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn badge-strawberry h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n\r\n<div>\t\r\n    <div class="hero-unit badge-strawberry h-big-top-margin h-inverse-color">\r\n        <h1>Sticky</h1>\r\n        <p class="lead h-big-top-margin">Structure your content to ensure footer at bottom</p>\r\n        <a class="btn badge-strawberry-light btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n        <a class="btn badge-strawberry-light btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                                \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>I read about this CSS technique for the first time reading <a href="http://ryanfait.com/resources/footer-stick-to-bottom-of-page/" target="_blank">this post from Ryan Fait</a>.</p>\r\n        <p>After that, I have seen it has been used in many places and even included in <a href="http://twitter.github.io/bootstrap/examples/sticky-footer.html" target="_blank">major frameworks</a>.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n        <p>You only need to structure you page as follow</p>\r\n<pre class="prettyprint linenums">\r\n&lthtml&gt\r\n    &ltbody&gt\r\n        &ltdiv class="st-sticky-wrap"&gt\r\n            // You content here\r\n            &ltdiv class="st-sticky-push"&gt&lt/div&gt\r\n        &lt/div&gt\r\n        &ltdiv class="st-sticky-footer"&gt&lt/div&gt\r\n    &lt/body&gt\r\n&lt/html&gt</pre>\r\n        <p>You can give to the sticky footer the height you need. This height can be expressed in px, ems or% as convenience. For doing that, you need to edit the <span class="badge badge-strawberry">Stasht.Sticky.css</span> file and change the height in the right places.</p>\r\n        <p>A media-query is included for change the height in tablet and desktop devices.</p>\r\n        <p>The defaults included are <span class="badge badge-strawberry">20em</span> for mobile devices (&lt768px) and <span class="badge badge-strawberry">10em</span> for tablet and desktop (&gt=768).</p>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <p>No necessary any Javascript</p>\r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-strawberry">Stashy.Sticky.less</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t                            \r\n</div>';});

define('text!views/sticky/sticky.html',[],function () { return '<div id="sticky" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'sticky/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('text!views/table/main.html',[],function () { return '<div>\r\n    <div class="hero-unit badge-table h-inverse-color" style="margin-top:30px;">\r\n        <h1>Table</h1>\r\n        <p class="lead h-big-top-margin">Work with responsive tables enhanced with priority columns</p>\r\n        <a class="btn badge-table-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\r\n        <a class="btn badge-table-dark btn-large h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>  \t\r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>\r\n        <p>Lot of times our table size is too much bigger for display columns in the right way.</p>\r\n        <p>Using this component you can <span class="badge-table">make your table responsive</span> and <span class="badge-table">show only the columns you want to.</span></p>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n<pre class="prettyprint linenums">\r\n&ltdiv class="st-table-container"&gt\r\n    &lttable cellspacing="0" class="st-table" id="tbl-id"&gt\r\n        &ltthead&gt\r\n          &lttr&gt\r\n             &ltth class="not-selectable always"&gtColumn header 1&lt/th&gt\r\n             &ltth class="always"&gtColumn header 2&lt/th&gt\r\n             &ltth class="ontablet"&gtColumn header 3&lt/th&gt\r\n             &ltth class="ondesktop"&gtColumn header 4&lt/th&gt\r\n             ... More headers ...\r\n          &lt/tr&gt\r\n       &lt/thead&gt\r\n       &lttbody&gt\r\n          &lttr&gt\r\n             &ltth&gtTitle &ltspan class="subtitle"&gtSubtitle&lt/span&gt&lt/th&gt\r\n             &lttd&gtLorem ipsum&lt/td&gt\r\n             &lttd&gt01.01.2013&lt/td&gt\r\n             &lttd&gt20$&lt/td&gt\r\n             ... More columns ...\r\n          &lt/tr&gt      \r\n          &lttr&gt\r\n             &ltth&gtAAPL &ltspan class="subtitle"&gtSubtitle&lt/span&gt&lt/th&gt\r\n             &lttd&gtLorem ipsum&lt/td&gt\r\n             &lttd&gt01.01.2012&lt/td&gt\r\n             &lttd&gt50$&lt/td&gt\r\n             ... More columns ...\r\n          &lt/tr&gt\r\n          .... More rows ...\r\n       &lt/tbody&gt\r\n    &lt/table&gt\r\n&lt/div&gt</pre>\r\n        <div>\r\n            <p>The required HTML has a couple of classes helping you to build the responsive table.</p>\r\n            <p><span class="bagde badge-table">.not-selectable</span> When you apply this class the column won´t be selectable in the dropdown menu. In another words, the column will be always visible and can´t be removed by the user.</p>\r\n            <p><span class="bagde badge-table">.always</span> The same as .not-selectable but a checkbox will be showed in the dropdown allowing the user to unselect the column.</p>\r\n            <p><span class="bagde badge-table">.onmobile</span> The column will be displayed only on mobile device sizes (< 768px).</p>\r\n            <p><span class="bagde badge-table">.ontablet</span> The column will be displayed only on tablet device sizes (>= 768px and < 978px).</p>\r\n            <p><span class="bagde badge-table">.ondesktop</span> The column will be displayed only on desktop sizes (>= 978px).</p>\r\n            <p>There is another class to improve showing titles ans subtitles. The class is <span class="bagde badge-table">.subtitle</span> and when you apply it using span tags (or similar) you can get a nice subtitle effect in your column cells</p>\r\n        </div>\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Table(selector, options)\r\n</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>.st-table</td>\r\n                    <td>CSS selector for your table</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>\r\n                    <td>You can pass the options to the table instance</td>\r\n                </tr>\t\t\t\t\t\t\t\t\t\t\r\n            </tbody>\r\n        </table>    \r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>idpreffix</strong></td>\r\n                    <td>string</td>\r\n                    <td>null</td>\r\n                    <td>Prefix for the id/headers values</td>\r\n                </tr> \r\n                <tr>\r\n                    <td><strong>notSelectable</strong></td>\r\n                    <td>string</td>\r\n                    <td>not-selectable</td>\r\n                    <td>Class assigned to column headers (th) that should always be present; the script not create a checkbox for these columns</td>\r\n                </tr>  \r\n                <tr>\r\n                    <td><strong>checkContainer</strong></td>\r\n                    <td>string</td>\r\n                    <td>null</td>\r\n                    <td>Container element where the hide/show checkboxes will be inserted; if none specified, the script creates a menu</td>\r\n                </tr>                  \r\n                <tr>\r\n                    <td><strong>menuClass</strong></td>\r\n                    <td>string</td>\r\n                    <td>null</td>\r\n                    <td>Specify the menu classes you want to add to style the menu button</td>\r\n                </tr>                   \r\n            </tbody>\r\n        </table> \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>on()</strong></td>\r\n                    <td>Starts table styling and event binding</td>\r\n                </tr>\r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar table1 = new Stashy.Table("#id1",{\r\n    \t        idprefix: "prforid2",\r\n\t\t        notSelectable: "forbidden",\r\n                menuClass : "btn btn-primary"\r\n\t        }).on();           \r\nvar table2 = new Stashy.Table("#id2",{\r\n\t\t        idprefix: "prforid2-",\r\n                checkContainer: "mymenu"\r\n\t        }).on();            \r\n</pre>\t\t\r\n    </section>\r\n    \r\n    <section id="playground">\r\n        <div class="page-header">\r\n            <h1>Playground</h1>\r\n        </div>\r\n        <h3>Responsive table styled with bootstrap</h3>\r\n        <div class="st-table-container">\r\n    \t\t<table cellspacing="0" class="st-table table table-striped" id="laptops-styled">\r\n    \t\t   <thead>\r\n    \t\t\t  <tr>\r\n        \t\t\t <th class="not-selectable always">Laptop</th>\r\n    \t\t\t\t <th class="always">Procesor</th>\r\n    \t\t\t\t <th class="always">Speed</th>\r\n    \t\t\t\t <th class="ontablet">Graphics card</th>\r\n    \t\t\t\t <th class="ontablet">Resolution</th>\r\n    \t\t\t\t <th class="always">Screen Size</th>\r\n    \t\t\t\t <th class="ontablet">Memory</th>\r\n                     <th class="ontablet">Storage</th>\r\n                     <th class="ondesktop">Battery lifez</th>\r\n                     <th class="ondesktop">Warranty</th>\r\n                     <th class="ondesktop">Price</th>                  \r\n    \t\t\t  </tr>\r\n    \t\t   </thead>\r\n    \t\t   <tbody>\r\n    \t\t\t  <tr>\r\n    \t\t\t\t <td>Portege<span class="subtitle">Toshiba</span></td>\r\n    \t\t\t\t <td>i5</td>\r\n    \t\t\t\t <td>1.6 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>1600x900</td>\r\n    \t\t\t\t <td>14\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>128 SSD</td>\r\n                     <td>6h</td>\r\n                     <td>1 year</td>\r\n                     <td>1500 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>X1<span class="subtitle">Lenovo</span></td>\r\n    \t\t\t\t <td>i7</td>\r\n    \t\t\t\t <td>2.1 Mhz</td>\r\n    \t\t\t\t <td>NVIDIA 635</td>\r\n    \t\t\t\t <td>1980x1080</td>\r\n    \t\t\t\t <td>13.3\'\'</td>\r\n    \t\t\t\t <td>8Gb</td>\r\n                     <td>256 SSD</td>\r\n                     <td>7h</td>\r\n                     <td>2 year</td>\r\n                     <td>1799 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>Vaio Pro<span class="subtitle">Sony</span></td>\r\n    \t\t\t\t <td>i5</td>\r\n    \t\t\t\t <td>1.7 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>1366x780</td>\r\n    \t\t\t\t <td>13.3\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>500 Gb</td>\r\n                     <td>6.5h</td>\r\n                     <td>2 year</td>\r\n                     <td>1250 $</td>\r\n    \t\t\t  </tr>       \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>MacBook Air<span class="subtitle">Apple</span></td>\r\n    \t\t\t\t <td>i7</td>\r\n    \t\t\t\t <td>1.8 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>2048x1536</td>\r\n    \t\t\t\t <td>13.1\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>128 SSD</td>\r\n                     <td>6h</td>\r\n                     <td>1 year</td>\r\n                     <td>1600 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>Zenbook U32VD<span class="subtitle">Asus</span></td>\r\n    \t\t\t\t <td>i3</td>\r\n    \t\t\t\t <td>1.5 Mhz</td>\r\n    \t\t\t\t <td>NVIDIA 650</td>\r\n    \t\t\t\t <td>1366x768</td>\r\n    \t\t\t\t <td>14\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>400 Gb</td>\r\n                     <td>4h</td>\r\n                     <td>2 year</td>\r\n                     <td>800 $</td>\r\n    \t\t\t  </tr>\r\n    \t\t\t  <tr>\r\n        \t\t\t <td>Spectre XT<span class="subtitle">HP</span></td>\r\n    \t\t\t\t <td>i5</td>\r\n    \t\t\t\t <td>1.6 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>1600x900</td>\r\n    \t\t\t\t <td>15\'\'</td>\r\n    \t\t\t\t <td>8Gb</td>\r\n                     <td>128 SSD</td>\r\n                     <td>6h</td>\r\n                     <td>1 year</td>\r\n                     <td>1300 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>U500VZ<span class="subtitle">Asus</span></td>\r\n    \t\t\t\t <td>i7</td>\r\n    \t\t\t\t <td>3.3 Mhz</td>\r\n    \t\t\t\t <td>NVIDIA 735M</td>\r\n    \t\t\t\t <td>1980x1080</td>\r\n    \t\t\t\t <td>15.6\'\'</td>\r\n    \t\t\t\t <td>8Gb</td>\r\n                     <td>512 SSD</td>\r\n                     <td>5h</td>\r\n                     <td>2 year</td>\r\n                     <td>1999 $</td>\r\n    \t\t\t  </tr>\r\n    \t\t   </tbody>\r\n    \t\t</table>\r\n    \t</div>\r\n    \t\r\n        <h3>Responsive table styled with Stashy default theme</h3>\r\n        <div class="st-table-container">\r\n    \t\t<table cellspacing="0" class="st-table" id="laptops-default">\r\n    \t\t   <thead>\r\n    \t\t\t  <tr>\r\n        \t\t\t <th class="not-selectable always">Laptop</th>\r\n    \t\t\t\t <th class="always">Procesor</th>\r\n    \t\t\t\t <th class="always">Speed</th>\r\n    \t\t\t\t <th class="ontablet">Graphics card</th>\r\n    \t\t\t\t <th class="ontablet">Resolution</th>\r\n    \t\t\t\t <th class="always">Screen Size</th>\r\n    \t\t\t\t <th class="ontablet">Memory</th>\r\n                     <th class="ontablet">Storage</th>\r\n                     <th class="ondesktop">Battery life</th>\r\n                     <th class="ondesktop">Warranty</th>\r\n                     <th class="ondesktop">Price</th>    \t\t\t  </tr>\r\n    \t\t   </thead>\r\n    \t\t   <tbody>\r\n    \t\t\t  <tr>\r\n    \t\t\t\t <td>Portege<span class="subtitle">Toshiba</span></td>\r\n    \t\t\t\t <td>i5</td>\r\n    \t\t\t\t <td>1.6 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>1600x900</td>\r\n    \t\t\t\t <td>14\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>128 SSD</td>\r\n                     <td>6h</td>\r\n                     <td>1 year</td>\r\n                     <td>1500 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>X1<span class="subtitle">Lenovo</span></td>\r\n    \t\t\t\t <td>i7</td>\r\n    \t\t\t\t <td>2.1 Mhz</td>\r\n    \t\t\t\t <td>NVIDIA 635</td>\r\n    \t\t\t\t <td>1980x1080</td>\r\n    \t\t\t\t <td>13.3\'\'</td>\r\n    \t\t\t\t <td>8Gb</td>\r\n                     <td>256 SSD</td>\r\n                     <td>7h</td>\r\n                     <td>2 year</td>\r\n                     <td>1799 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>Vaio Pro<span class="subtitle">Sony</span></td>\r\n    \t\t\t\t <td>i5</td>\r\n    \t\t\t\t <td>1.7 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>1366x780</td>\r\n    \t\t\t\t <td>13.3\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>500 Gb</td>\r\n                     <td>6.5h</td>\r\n                     <td>2 year</td>\r\n                     <td>1250 $</td>\r\n    \t\t\t  </tr>       \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>MacBook Air<span class="subtitle">Apple</span></th>\r\n    \t\t\t\t <td>i7</td>\r\n    \t\t\t\t <td>1.8 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>2048x1536</td>\r\n    \t\t\t\t <td>13.1\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>128 SSD</td>\r\n                     <td>6h</td>\r\n                     <td>1 year</td>\r\n                     <td>1600 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>Zenbook U32VD<span class="subtitle">Asus</span></td>\r\n    \t\t\t\t <td>i3</td>\r\n    \t\t\t\t <td>1.5 Mhz</td>\r\n    \t\t\t\t <td>NVIDIA 650</td>\r\n    \t\t\t\t <td>1366x768</td>\r\n    \t\t\t\t <td>14\'\'</td>\r\n    \t\t\t\t <td>4Gb</td>\r\n                     <td>400 Gb</td>\r\n                     <td>4h</td>\r\n                     <td>2 year</td>\r\n                     <td>800 $</td>\r\n    \t\t\t  </tr>\r\n    \t\t\t  <tr>\r\n        \t\t\t <td>Spectre XT<span class="subtitle">HP</span></td>\r\n    \t\t\t\t <td>i5</td>\r\n    \t\t\t\t <td>1.6 Mhz</td>\r\n    \t\t\t\t <td>Intel HD-4000</td>\r\n    \t\t\t\t <td>1600x900</td>\r\n    \t\t\t\t <td>15\'\'</td>\r\n    \t\t\t\t <td>8Gb</td>\r\n                     <td>128 SSD</td>\r\n                     <td>6h</td>\r\n                     <td>1 year</td>\r\n                     <td>1300 $</td>\r\n    \t\t\t  </tr>      \r\n    \t\t\t  <tr>\r\n        \t\t\t <td>U500VZ<span class="subtitle">Asus</span></td>\r\n    \t\t\t\t <td>i7</td>\r\n    \t\t\t\t <td>3.3 Mhz</td>\r\n    \t\t\t\t <td>NVIDIA 735M</td>\r\n    \t\t\t\t <td>1980x1080</td>\r\n    \t\t\t\t <td>15.6\'\'</td>\r\n    \t\t\t\t <td>8Gb</td>\r\n                     <td>512 SSD</td>\r\n                     <td>5h</td>\r\n                     <td>2 year</td>\r\n                     <td>1999 $</td>\r\n    \t\t\t  </tr>\r\n    \t\t   </tbody>\r\n    \t\t</table>\r\n    \t</div>        \r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-table">Stashy.Table.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span>         \r\n        <span class="badge badge-table">Stashy.Table.js</span>\r\n    </section>\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\r\n</div>\t\t                    \r\n    ';});

define('text!views/table/menu.html',[],function () { return '<div class="subnav" style="margin-top:0 !important;">\r\n    <ul class="nav nav-pills">\r\n        <li><a href="#" class="st-flyout-toggle"><i class="icon-reorder icon-large"></i></a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/table/description\') }">Description</a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/table/html\') }">HTML</a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/table/javascript\') }">Javascript</a></li>\r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/table/playground\') }">Playground</a></li>        \r\n        <li><a data-bind="attr : { href : router.convertRouteToHash(\'/table/dependencies\') }">Dependencies</a></li>\r\n    </ul>\r\n</div>\t ';});

define('text!views/table/table.html',[],function () { return '<div id="table" class="st-flyout">\r\n    <div class="st-flyout-container">\r\n\t    <div class="st-flyout-menu" data-bind="compose : \'viewmodels/common/additional\',visible : fladdvisible"></div>\r\n\t    <div class="st-flyout-main">\t\t\r\n            <div id="menu" data-bind="compose : \'table/menu.html\'"></div>   \r\n            <div id="content" data-bind="compose : \'table/main.html\'"></div>\t\t\t\t\t\t                        \r\n        </div>                 \r\n    </div>\t\t\t\t\t\t\r\n</div>';});

define('text!views/toggle/main.html',[],function () { return '<div id="offcanvas-navigation">\r\n    <a href="#" class="showmenubutton btn btn-success h-add-padding"><i class="icon-reorder icon-large no-ajaxy"></i></a>\r\n    <a href="#" class="showadditionalbutton btn btn-success h-add-padding" style="float:right;"><i class="icon-reorder icon-large"></i></a>\r\n    <div class="h-clear"></div>\r\n</div>\r\n    \r\n<div>\r\n    <div class="hero-unit badge-success h-big-top-margin h-inverse-color">\r\n            <h1>Toggle</h1>\r\n            <p class="lead h-big-top-margin">Create beautiful top responsive navigation menu in your pages</p>\r\n                <a class="btn btn-large badge-success-light h-top-margin" href="https://github.com/yagopv/Stashy/archive/master.zip"  target="_blank"><i class="icon-download icon-2x"></i>&nbsp; Download</a>\t\t\t\t\t\t\t\r\n                 <a class="btn btn-large badge-success-light h-top-margin" href="https://github.com/yagopv/Stashy"  target="_blank"><i class="icon-github icon-2x"></i>&nbsp; View project on Github</a>                              \r\n    </div>\r\n    \r\n    <section id="description">\r\n        <div class="page-header">\r\n            <h1>Description</h1>\r\n        </div>                        \r\n        <p>Top responsive menus are very used in web development. With this component you can create one of them.</p>\r\n        <p>When you resize your browser, the navigation options will be hide and a link will be showed instead. Clicking that link the menu will slide down.</p>\r\n    </section>\r\n    \r\n    <section id="html">\r\n        <div class="page-header">\r\n            <h1>HTML</h1>                        \r\n        </div>\r\n<pre class="prettyprint linenums">\r\n&ltdiv class="st-toggle"&gt\r\n    &ltdiv class="st-toggle-brand"&gt\r\n        &lta href="#"&gtBrand&lt/a&gt  \r\n    &lt/div&gt\r\n    &lta href="#" class="st-toggle-menu-link"&gt&lt/a&gt\t\r\n    &ltnav class="st-toggle-navigation"&gt\r\n        &ltul&gt\r\n            ...\r\n            &ltli&gt&lta&gt&lt/a&gt&lt/li&gt\r\n            &ltli&gt&lta&gt&lt/a&gt&lt/li&gt\r\n            ...\r\n        &lt/ul&gt        \r\n    &lt/nav&gt\r\n&lt/div&gt</pre>\t\r\n    </section>\r\n    \r\n    <section id="javascript">\r\n        <div class="page-header">                        \r\n           <h1>Javascript</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\r\n        <h2>Constructor</h2>\r\n<pre class="prettyprint linenums">\r\nStashy.Toggle(selector, options)</pre>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Parameter</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>selector</strong></td>\r\n                    <td>string</td>\r\n                    <td>.st-toggle</td>\r\n                    <td>CSS selector for your toggle menu</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>options</strong></td>\r\n                    <td>object</td>\r\n                    <td>See options</td>                    \r\n                    <td>You can pass the options to the offcanvas instance</td>\r\n                </tr>\r\n            </tbody>\r\n        </table>    \r\n        <h2 id="options">Options</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Option</strong></th>\r\n                    <th>Type</th>\r\n                    <th>Default</th>\r\n                    <th>Description</th>\t\t\t\t\t\t\t\t\t\t\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>closeOnClickOutside</strong></td>\r\n                    <td>bool</td>\r\n                    <td>true</td>\r\n                    <td>Close Toggle on click outside the element area</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>closeOnClick</strong></td>\r\n                    <td>bool</td>\r\n                    <td>true</td>\r\n                    <td>Close Toggle when click on any link inside the element area</td>\r\n                </tr>\r\n                <tr>\r\n                    <td><strong>fixed</strong></td>\r\n                    <td>bool</td>\r\n                    <td>false</td>\r\n                    <td>You can make the toggle fixed top by setting this option to true. Remember to add some paddding (>=50px) to your main container if you don´t want the toggle to hide your upmost content. Toggle component is going to stick fixed at top only on desktop measures (>= 768px)</td>\r\n                </tr>                \r\n            </tbody>\r\n        </table>   \r\n        <h2>Methods</h2>\r\n        <table class="table table-bordered table-striped table-hover">\r\n            <thead>\r\n                <tr>\r\n                    <th><strong>Name</strong></th>                                            \r\n                    <th>Description</th>\r\n                </tr>                                \r\n            </thead>\r\n            <tbody>\r\n                <tr>\r\n                    <td><strong>layout()</strong></td>\r\n                    <td>Start the toggle menu layout</td>\r\n                </tr>\r\n            </tbody>\r\n        </table> \t\t\t\t\t\t\t\r\n        <h2>Sample</h2>\r\n<pre class="prettyprint linenums">\r\nvar toggle = new Stashy.Toggle().layout();</pre>\r\n    </section>\r\n    \r\n    <section id="dependencies">\r\n        <div class="page-header">                        \r\n           <h1>Dependencies</h1>\t\t\t\t\t\t\r\n        </div>\t\t\t\t\r\n        <p class="lead">less</p>\r\n        <p>For using just this component, create a .less file similar to Stashy.less, include in order the following imports and compile:</p>\r\n        <span class="badge badge-info">Stashy.Variables.less</span>\r\n        <span class="badge badge-info">Stashy.Mixins.less</span>\r\n        <span class="badge badge-success">Stashy.Toggle.less</span>\r\n        <p class="lead">JS</p>\r\n        <span class="badge badge-info">jQuery.js</span> <span class="badge badge-success">Stashy.Toggle.js</span>\r\n    </section> \r\n</div>\t\t                ';});

define('text!views/toggle/toggle.html',[],function () { return '<div id="toggle" class="st-offcanvas">\r\n    <div class="st-offcanvas-menu" data-bind="compose : \'viewmodels/common/menu\'"></div>\r\n    <div class="st-offcanvas-main" id="content" data-bind="compose : \'toggle/main.html\'"></div>\r\n    <div class="st-offcanvas-additional" data-bind="compose : \'viewmodels/common/additional\'"></div>\r\n</div>';});

define('plugins/dialog',["durandal/system","durandal/app","durandal/composition","durandal/activator","durandal/viewEngine","jquery","knockout"],function(e,t,n,i,a,o,r){function s(t){return e.defer(function(n){e.isString(t)?e.acquire(t).then(function(t){n.resolve(e.resolveObject(t))}).fail(function(n){e.error("Failed to load dialog module ("+t+"). Details: "+n.message)}):n.resolve(t)}).promise()}var l,c={},u=0,d=function(e,t,n){this.message=e,this.title=t||d.defaultTitle,this.options=n||d.defaultOptions};return d.prototype.selectOption=function(e){l.close(this,e)},d.prototype.getView=function(){return a.processMarkup(d.defaultViewMarkup)},d.setViewUrl=function(e){delete d.prototype.getView,d.prototype.viewUrl=e},d.defaultTitle=t.title||"Application",d.defaultOptions=["Ok"],d.defaultViewMarkup=['<div data-view="plugins/messageBox" class="messageBox">','<div class="modal-header">','<h3 data-bind="text: title"></h3>',"</div>",'<div class="modal-body">','<p class="message" data-bind="text: message"></p>',"</div>",'<div class="modal-footer" data-bind="foreach: options">','<button class="btn" data-bind="click: function () { $parent.selectOption($data); }, text: $data, css: { \'btn-primary\': $index() == 0, autofocus: $index() == 0 }"></button>',"</div>","</div>"].join("\n"),l={MessageBox:d,currentZIndex:1050,getNextZIndex:function(){return++this.currentZIndex},isOpen:function(){return u>0},getContext:function(e){return c[e||"default"]},addContext:function(e,t){t.name=e,c[e]=t;var n="show"+e.substr(0,1).toUpperCase()+e.substr(1);this[n]=function(t,n){return this.show(t,n,e)}},createCompositionSettings:function(e,t){var n={model:e,activate:!1};return t.attached&&(n.attached=t.attached),t.compositionComplete&&(n.compositionComplete=t.compositionComplete),n},getDialog:function(e){return e?e.__dialog__:void 0},close:function(e){var t=this.getDialog(e);if(t){var n=Array.prototype.slice.call(arguments,1);t.close.apply(t,n)}},show:function(t,a,o){var r=this,l=c[o||"default"];return e.defer(function(e){s(t).then(function(t){var o=i.create();o.activateItem(t,a).then(function(i){if(i){var a=t.__dialog__={owner:t,context:l,activator:o,close:function(){var n=arguments;o.deactivateItem(t,!0).then(function(i){i&&(u--,l.removeHost(a),delete t.__dialog__,0==n.length?e.resolve():1==n.length?e.resolve(n[0]):e.resolve.apply(e,n))})}};a.settings=r.createCompositionSettings(t,l),l.addHost(a),u++,n.compose(a.host,a.settings)}else e.resolve(!1)})})}).promise()},showMessage:function(t,n,i){return e.isString(this.MessageBox)?l.show(this.MessageBox,[t,n||d.defaultTitle,i||d.defaultOptions]):l.show(new this.MessageBox(t,n,i))},install:function(e){t.showDialog=function(e,t,n){return l.show(e,t,n)},t.showMessage=function(e,t,n){return l.showMessage(e,t,n)},e.messageBox&&(l.MessageBox=e.messageBox),e.messageBoxView&&(l.MessageBox.prototype.getView=function(){return e.messageBoxView})}},l.addContext("default",{blockoutOpacity:.2,removeDelay:200,addHost:function(e){var t=o("body"),n=o('<div class="modalBlockout"></div>').css({"z-index":l.getNextZIndex(),opacity:this.blockoutOpacity}).appendTo(t),i=o('<div class="modalHost"></div>').css({"z-index":l.getNextZIndex()}).appendTo(t);if(e.host=i.get(0),e.blockout=n.get(0),!l.isOpen()){e.oldBodyMarginRight=t.css("margin-right"),e.oldInlineMarginRight=t.get(0).style.marginRight;var a=o("html"),r=t.outerWidth(!0),s=a.scrollTop();o("html").css("overflow-y","hidden");var c=o("body").outerWidth(!0);t.css("margin-right",c-r+parseInt(e.oldBodyMarginRight)+"px"),a.scrollTop(s)}},removeHost:function(e){if(o(e.host).css("opacity",0),o(e.blockout).css("opacity",0),setTimeout(function(){r.removeNode(e.host),r.removeNode(e.blockout)},this.removeDelay),!l.isOpen()){var t=o("html"),n=t.scrollTop();t.css("overflow-y","").scrollTop(n),e.oldInlineMarginRight?o("body").css("margin-right",e.oldBodyMarginRight):o("body").css("margin-right","")}},compositionComplete:function(e,t,n){var i=o(e),a=i.width(),r=i.height(),s=l.getDialog(n.model);i.css({"margin-top":(-r/2).toString()+"px","margin-left":(-a/2).toString()+"px"}),o(s.host).css("opacity",1),o(e).hasClass("autoclose")&&o(s.blockout).click(function(){s.close()}),o(".autofocus",e).each(function(){o(this).focus()})}}),l});
define('plugins/http',["jquery","knockout"],function(e,t){return{callbackParam:"callback",get:function(t,n){return e.ajax(t,{data:n})},jsonp:function(t,n,a){return-1==t.indexOf("=?")&&(a=a||this.callbackParam,t+=-1==t.indexOf("?")?"?":"&",t+=a+"=?"),e.ajax({url:t,dataType:"jsonp",data:n})},post:function(n,a){return e.ajax({url:n,data:t.toJSON(a),type:"POST",contentType:"application/json",dataType:"json"})}}});
define('plugins/observable',["durandal/system","durandal/binder","knockout"],function(e,t,n){function a(e){var t=e[0];return"_"===t||"$"===t}function i(t){if(!t||e.isElement(t)||t.ko===n||t.jquery)return!1;var a=d.call(t);return-1==p.indexOf(a)&&!(t===!0||t===!1)}function o(e,t){var n=e.__observable__,a=!0;if(!n||!n.__full__){n=n||(e.__observable__={}),n.__full__=!0,f.forEach(function(n){e[n]=function(){a=!1;var e=g[n].apply(t,arguments);return a=!0,e}}),h.forEach(function(n){e[n]=function(){a&&t.valueWillMutate();var i=m[n].apply(e,arguments);return a&&t.valueHasMutated(),i}}),v.forEach(function(n){e[n]=function(){for(var i=0,o=arguments.length;o>i;i++)r(arguments[i]);a&&t.valueWillMutate();var s=m[n].apply(e,arguments);return a&&t.valueHasMutated(),s}}),e.splice=function(){for(var n=2,i=arguments.length;i>n;n++)r(arguments[n]);a&&t.valueWillMutate();var o=m.splice.apply(e,arguments);return a&&t.valueHasMutated(),o};for(var i=0,o=e.length;o>i;i++)r(e[i])}}function r(t){var r,s;if(i(t)&&(r=t.__observable__,!r||!r.__full__)){if(r=r||(t.__observable__={}),r.__full__=!0,e.isArray(t)){var c=n.observableArray(t);o(t,c)}else for(var u in t)a(u)||r[u]||(s=t[u],e.isFunction(s)||l(t,u,s));y&&e.log("Converted",t)}}function s(e,t,n){var a;e(t),a=e.peek(),n?a.destroyAll||(a||(a=[],e(a)),o(a,e)):r(a)}function l(t,a,i){var l,c,u=t.__observable__||(t.__observable__={});if(void 0===i&&(i=t[a]),e.isArray(i))l=n.observableArray(i),o(i,l),c=!0;else if("function"==typeof i){if(!n.isObservable(i))return null;l=i}else e.isPromise(i)?(l=n.observable(),i.then(function(t){if(e.isArray(t)){var a=n.observableArray(t);o(t,a),t=a}l(t)})):(l=n.observable(i),r(i));return Object.defineProperty(t,a,{configurable:!0,enumerable:!0,get:l,set:n.isWriteableObservable(l)?function(t){t&&e.isPromise(t)?t.then(function(t){s(l,t,e.isArray(t))}):s(l,t,c)}:void 0}),u[a]=l,l}function c(t,n,a){var i,o=this,r={owner:t,deferEvaluation:!0};return"function"==typeof a?r.read=a:("value"in a&&e.error('For ko.defineProperty, you must not specify a "value" for the property. You must provide a "get" function.'),"function"!=typeof a.get&&e.error('For ko.defineProperty, the third parameter must be either an evaluator function, or an options object containing a function called "get".'),r.read=a.get,r.write=a.set),i=o.computed(r),t[n]=i,l(t,n,i)}var u,d=Object.prototype.toString,p=["[object Function]","[object String]","[object Boolean]","[object Number]","[object Date]","[object RegExp]"],f=["remove","removeAll","destroy","destroyAll","replace"],h=["pop","reverse","sort","shift","splice"],v=["push","unshift"],m=Array.prototype,g=n.observableArray.fn,y=!1;return u=function(e,t){var a,i,o;return e?(a=e.__observable__,a&&(i=a[t])?i:(o=e[t],n.isObservable(o)?o:l(e,t,o))):null},u.defineProperty=c,u.convertProperty=l,u.convertObject=r,u.install=function(e){var n=t.binding;t.binding=function(e,t,a){a.applyBindings&&!a.skipConversion&&r(e),n(e,t)},y=e.logConversion},u});
define('plugins/serializer',["durandal/system"],function(e){return{typeAttribute:"type",space:void 0,replacer:function(e,t){if(e){var n=e[0];if("_"===n||"$"===n)return void 0}return t},serialize:function(t,n){return n=void 0===n?{}:n,(e.isString(n)||e.isNumber(n))&&(n={space:n}),JSON.stringify(t,n.replacer||this.replacer,n.space||this.space)},getTypeId:function(e){return e?e[this.typeAttribute]:void 0},typeMap:{},registerType:function(){var t=arguments[0];if(1==arguments.length){var n=t[this.typeAttribute]||e.getModuleId(t);this.typeMap[n]=t}else this.typeMap[t]=arguments[1]},reviver:function(e,t,n,i){var a=n(t);if(a){var o=i(a);if(o)return o.fromJSON?o.fromJSON(t):new o(t)}return t},deserialize:function(e,t){var n=this;t=t||{};var i=t.getTypeId||function(e){return n.getTypeId(e)},a=t.getConstructor||function(e){return n.typeMap[e]},o=t.reviver||function(e,t){return n.reviver(e,t,i,a)};return JSON.parse(e,o)}}});
define('plugins/widget',["durandal/system","durandal/composition","jquery","knockout"],function(e,t,n,i){function a(e,n){var a=i.utils.domData.get(e,l);a||(a={parts:t.cloneNodes(i.virtualElements.childNodes(e))},i.virtualElements.emptyNode(e),i.utils.domData.set(e,l,a)),n.parts=a.parts}var o={},r={},s=["model","view","kind"],l="durandal-widget-data",c={getSettings:function(t){var n=i.utils.unwrapObservable(t())||{};if(e.isString(n))return{kind:n};for(var a in n)n[a]=-1!=i.utils.arrayIndexOf(s,a)?i.utils.unwrapObservable(n[a]):n[a];return n},registerKind:function(e){i.bindingHandlers[e]={init:function(){return{controlsDescendantBindings:!0}},update:function(t,n,i,o,r){var s=c.getSettings(n);s.kind=e,a(t,s),c.create(t,s,r,!0)}},i.virtualElements.allowedBindings[e]=!0},mapKind:function(e,t,n){t&&(r[e]=t),n&&(o[e]=n)},mapKindToModuleId:function(e){return o[e]||c.convertKindToModulePath(e)},convertKindToModulePath:function(e){return"widgets/"+e+"/viewmodel"},mapKindToViewId:function(e){return r[e]||c.convertKindToViewPath(e)},convertKindToViewPath:function(e){return"widgets/"+e+"/view"},createCompositionSettings:function(e,t){return t.model||(t.model=this.mapKindToModuleId(t.kind)),t.view||(t.view=this.mapKindToViewId(t.kind)),t.preserveContext=!0,t.activate=!0,t.activationData=t,t.mode="templated",t},create:function(e,n,i,a){a||(n=c.getSettings(function(){return n},e));var o=c.createCompositionSettings(e,n);t.compose(e,o,i)},install:function(e){if(e.bindingName=e.bindingName||"widget",e.kinds)for(var t=e.kinds,n=0;n<t.length;n++)c.registerKind(t[n]);i.bindingHandlers[e.bindingName]={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,i,o){var r=c.getSettings(t);a(e,r),c.create(e,r,o,!0)}},i.virtualElements.allowedBindings[e.bindingName]=!0}};return c});
define('transitions/entrance',["durandal/system","durandal/composition","jquery"],function(e,t,n){var i=100,o={marginRight:0,marginLeft:0,opacity:1},a={marginLeft:"",marginRight:"",opacity:"",display:""},r=function(t){return e.defer(function(e){function r(){e.resolve()}function s(){t.keepScrollPosition||n(document).scrollTop(0)}function l(){s(),t.triggerAttach();var e={marginLeft:u?"0":"20px",marginRight:u?"0":"-20px",opacity:0,display:"block"},i=n(t.child);i.css(e),i.animate(o,c,"swing",function(){i.css(a),r()})}if(t.child){var c=t.duration||500,u=!!t.fadeOnly;t.activeView?n(t.activeView).fadeOut(i,l):l()}else n(t.activeView).fadeOut(i,r)}).promise()};return r});
require(["main"]);
}());